@@ -25,7 +25,8 @@ $conf['allowdebug']  = 0;                 //allow debug output, enable if needed
 
 $conf['start']       = 'start';           //name of start page
 $conf['title']       = 'DokuWiki';        //what to show in the title
-$conf['template']    = 'default';         //see tpl directory
+$conf['template']    = 'default';         //see lib/tpl directory
+$conf['license']     = 'cc-by-nc-sa';     //see conf/license.php
 $conf['fullpath']    = 0;                 //show full path of the document or relative to datadir only? 0|1
 $conf['recent']      = 20;                //how many entries to show in recent
 $conf['breadcrumbs'] = 10;                //how many recent visited pages to show
@@ -36,6 +37,7 @@ $conf['phpok']       = 0;                 //may PHP code be embedded? Never do t
 $conf['dformat']     = '%Y/%m/%d %H:%M';  //dateformat accepted by PHPs strftime() function
 $conf['signature']   = ' --- //[[@MAIL@|@NAME@]] @DATE@//'; //signature see wiki:config for details
 $conf['toptoclevel'] = 1;                 //Level starting with and below to include in AutoTOC (max. 5)
+$conf['tocminheads'] = 3;                 //Minimum amount of headlines that determines if a TOC is built
 $conf['maxtoclevel'] = 3;                 //Up to which level include into AutoTOC (max. 5)
 $conf['maxseclevel'] = 3;                 //Up to which level create editable sections (max. 5)
 $conf['camelcase']   = 0;                 //Use CamelCase for linking? (I don't like it) 0|1
@@ -43,6 +45,10 @@ $conf['deaccent']    = 1;                 //deaccented chars in pagenames (1) or
 $conf['useheading']  = 0;                 //use the first heading in a page as its name
 $conf['refcheck']    = 1;                 //check for references before deleting media files
 $conf['refshow']     = 0;                 //how many references should be shown, 5 is a good value
+$conf['showuseras']  = 'loginname';       // 'loginname' users login name 
+                                          // 'username' users full name
+                                          // 'email' e-mail address (will be obfuscated as per mailguard)
+                                          // 'email_link' e-mail address as a mailto: link (obfuscated)
 
 /* Antispam Features */
 
@@ -65,10 +71,11 @@ $conf['passcrypt']   = 'smd5';           //Used crypt method (smd5,md5,sha1,ssha
 $conf['defaultgroup']= 'user';           //Default groups new Users are added to
 $conf['superuser']   = '!!not set!!';    //The admin can be user or @group or comma separated list user1,@group1,user2
 $conf['manager']     = '!!not set!!';    //The manager can be user or @group or comma separated list user1,@group1,user2
-$conf['profileconfirm'] = '1';           //Require current password to confirm changes to user profile
+$conf['profileconfirm'] = 1;             //Require current password to confirm changes to user profile
 $conf['disableactions'] = '';            //comma separated list of actions to disable
 $conf['sneaky_index']   = 0;             //check for namespace read permission in index view (0|1) (1 might cause unexpected behavior)
 $conf['auth_security_timeout'] = 900;    //time (seconds) auth data is considered valid, set to 0 to recheck on every page view
+$conf['securecookie'] = 1;               //never send HTTPS cookies via HTTP
 
 /* Advanced Options */
 
@@ -120,6 +127,7 @@ $conf['broken_iua']  = 0;                //Platform with broken ignore_user_abor
 $conf['xsendfile']   = 0;                //Use X-Sendfile (1 = lighttpd, 2 = standard)
 $conf['xmlrpc'] = 0;                     //Enable/disable XML-RPC interface
 $conf['renderer_xhtml'] = 'xhtml';       //renderer to use for main page generation
+$conf['rememberme'] = 1;                 //Enable/disable remember me on login
 
 //Set target to use when creating links - leave empty for same window
 $conf['target']['wiki']      = '';
@@ -137,7 +145,7 @@ $conf['proxy']['ssl']  = 0;
 
 /* Safemode Hack */
 
-$conf['safemodehack'] = 0;               //read http://wiki.splitbrain.org/wiki:safemodehack !
+$conf['safemodehack'] = 0;               //read http://www.dokuwiki.org/config:safemodehack !
 $conf['ftp']['host'] = 'localhost';
 $conf['ftp']['port'] = '21';
 $conf['ftp']['user'] = 'user';
