@@ -55,10 +55,10 @@
     exit;
   }
 
-  //send 404 for missing pages if configured
-  if($conf['send404'] &&
-     ($ACT == 'show' || substr($ACT,0,7) == 'export_') &&
-     !$INFO['exists']){
+  //send 404 for missing pages if configured or ID has special meaning to bots
+  if(!$INFO['exists'] &&
+     ($conf['send404'] || preg_match('/^(robots\.txt|sitemap\.xml(\.gz)?|favicon\.ico|crossdomain\.xml)$/',$ID)) &&
+     ($ACT == 'show' || substr($ACT,0,7) == 'export_') ){
     header('HTTP/1.0 404 Not Found');
   }
 
