@@ -6,8 +6,6 @@
  * @author     Andreas Goetz <cpuidle@gmx.de>
  */
 
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
-require_once(DOKU_CONF.'dokuwiki.php');
 
 define('HTTP_NL',"\r\n");
 
@@ -34,7 +32,7 @@ class DokuHTTPClient extends HTTPClient {
         $this->proxy_host = $conf['proxy']['host'];
         $this->proxy_port = $conf['proxy']['port'];
         $this->proxy_user = $conf['proxy']['user'];
-        $this->proxy_pass = $conf['proxy']['pass'];
+        $this->proxy_pass = conf_decodeString($conf['proxy']['pass']);
         $this->proxy_ssl  = $conf['proxy']['ssl'];
     }
 }
@@ -58,7 +56,8 @@ class HTTPClient {
     var $cookies;
     var $referer;
     var $max_redirect;
-    var $max_bodysize;  // abort if the response body is bigger than this
+    var $max_bodysize;
+    var $max_bodysize_abort = true;  // if set, abort if the response body is bigger than max_bodysize
     var $header_regexp; // if set this RE must match against the headers, else abort
     var $headers;
     var $debug;
@@ -121,7 +120,7 @@ class HTTPClient {
     function get($url,$sloppy304=false){
         if(!$this->sendRequest($url)) return false;
         if($this->status == 304 && $sloppy304) return $this->resp_body;
-        if($this->status != 200) return false;
+        if($this->status < 200 || $this->status > 206) return false;
         return $this->resp_body;
     }
 
@@ -134,7 +133,7 @@ class HTTPClient {
      */
     function post($url,$data){
         if(!$this->sendRequest($url,$data,'POST')) return false;
-        if($this->status != 200) return false;
+        if($this->status < 200 || $this->status > 206) return false;
         return $this->resp_body;
     }
 
@@ -230,7 +229,19 @@ class HTTPClient {
         $this->_debug('request',$request);
 
         // send request
-        fputs($socket, $request);
+        $towrite = strlen($request);
+        $written = 0;
+        while($written < $towrite){
+            $ret = fwrite($socket, substr($request,$written));
+            if($ret === false){
+                $this->status = -100;
+                $this->error = 'Failed writing to socket';
+                return false;
+            }
+            $written += $ret;
+        }
+
+
         // read headers from socket
         $r_headers = '';
         do{
@@ -252,7 +263,8 @@ class HTTPClient {
         if($this->max_bodysize && preg_match('/\r?\nContent-Length:\s*(\d+)\r?\n/i',$r_headers,$match)){
             if($match[1] > $this->max_bodysize){
                 $this->error = 'Reported content length exceeds allowed response size';
-                return false;
+                if ($this->max_bodysize_abort)
+                    return false;
             }
         }
 
@@ -321,13 +333,18 @@ class HTTPClient {
 
                 $byte = fread($socket,1);     // readtrailing \n
                 $chunk_size = hexdec($chunk_size);
-                $this_chunk = fread($socket,$chunk_size);
-                $r_body    .= $this_chunk;
-                if ($chunk_size) $byte = fread($socket,2); // read trailing \r\n
+                if ($chunk_size) {
+                    $this_chunk = fread($socket,$chunk_size);
+                    $r_body    .= $this_chunk;
+                    $byte = fread($socket,2); // read trailing \r\n
+                }
 
                 if($this->max_bodysize && strlen($r_body) > $this->max_bodysize){
                     $this->error = 'Allowed response size exceeded';
-                    return false;
+                    if ($this->max_bodysize_abort)
+                        return false;
+                    else
+                        break;
                 }
             } while ($chunk_size);
         }else{
@@ -342,7 +359,10 @@ class HTTPClient {
                 $r_size = strlen($r_body);
                 if($this->max_bodysize && $r_size > $this->max_bodysize){
                     $this->error = 'Allowed response size exceeded';
-                    return false;
+                    if ($this->max_bodysize_abort)
+                        return false;
+                    else
+                        break;
                 }
                 if($this->resp_headers['content-length'] && !$this->resp_headers['transfer-encoding'] &&
                    $this->resp_headers['content-length'] == $r_size){
@@ -459,7 +479,7 @@ class HTTPClient {
     function _postEncode($data){
         foreach($data as $key => $val){
             if($url) $url .= '&';
-            $url .= $key.'='.urlencode($val);
+            $url .= urlencode($key).'='.urlencode($val);
         }
         return $url;
     }
