@@ -144,6 +144,12 @@ class IXR_Message {
     function parse() {
         // first remove the XML declaration
         $this->message = preg_replace('/<\?xml(.*)?\?'.'>/', '', $this->message);
+        // workaround for a bug in PHP/libxml2, see http://bugs.php.net/bug.php?id=45996
+        $this->message = str_replace('&lt;', '&#60;', $this->message);
+        $this->message = str_replace('&gt;', '&#62;', $this->message);
+        $this->message = str_replace('&amp;', '&#38;', $this->message);
+        $this->message = str_replace('&apos;', '&#39;', $this->message);
+        $this->message = str_replace('&quot;', '&#34;', $this->message);
         if (trim($this->message) == '') {
             return false;
         }
@@ -354,6 +360,15 @@ EOD;
             // Call the method
             #$result = $this->$method($args);
             $result = call_user_func_array(array(&$this,$method),$args);
+		} elseif (substr($method, 0, 7) == 'plugin:') {
+			require_once(DOKU_INC.'inc/pluginutils.php');
+			list($pluginname, $callback) = explode(':', substr($method, 7), 2);
+			if(!plugin_isdisabled($pluginname)) {
+				$plugin = plugin_load('action', $pluginname);
+				return call_user_func_array(array($plugin, $callback), $args);
+			} else {
+				return new IXR_Error(-99999, 'server error');
+			}
         } else {
             // It's a function - does it exist?
             if (!function_exists($method)) {
