@@ -58,7 +58,7 @@
  */
 
 // for DokuWiki
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
+if(!defined('DOKU_INC')) die('meh.');
 require_once(DOKU_INC.'inc/utf8.php');
 
 /**
