@@ -6,7 +6,7 @@
  * @author     Tom N Harris <tnharris@whoopdedo.org>
  */
 
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
+if(!defined('DOKU_INC')) die('meh.');
 if(!defined('NL')) define('NL',"\n");
 require_once(DOKU_INC.'inc/html.php');
 
@@ -243,12 +243,10 @@ class Doku_Form {
     print '<form action="'.$this->action.'" method="'.$this->method.'" accept-charset="'.$lang['encoding'].'"';
     if (!empty($this->id)) print ' id="'.$this->id.'"';
     if (!empty($this->enctype)) print ' enctype="'.$this->enctype.'"';
-    print '>'.NL;
+    print '><div class="no">'.NL;
     if (!empty($this->_hidden)) {
-      print '<div class="no">';
       foreach ($this->_hidden as $name=>$value)
         print form_hidden(array('name'=>$name, 'value'=>$value));
-      print '</div>'.NL;
     }
     foreach ($this->_content as $element) {
       if (is_array($element)) {
@@ -261,7 +259,7 @@ class Doku_Form {
       }
     }
     if ($this->_infieldset) print form_closefieldset().NL;
-    print '</form>'.NL;
+    print '</div></form>'.NL;
   }
 
 }
@@ -350,7 +348,7 @@ function form_makeButton($type, $act, $value='', $attrs=array()) {
   $elem = array('_elem'=>'button', 'type'=>$type, '_action'=>$act, 
                 'value'=>$value, 'class'=>'button');
   if (!empty($attrs['accesskey']) && empty($attrs['title'])) {
-    $attrs['title'] = $value . ' [ALT+'.strtoupper($attrs['accesskey']).']';
+    $attrs['title'] = $value . ' ['.strtoupper($attrs['accesskey']).']';
   }
   return array_merge($elem, $attrs);
 }
@@ -557,7 +555,7 @@ function form_makeListboxField($name, $values, $selected='', $label=null, $id=''
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_tag($attrs) {
-  return '<'.$attrs['_tag'].' '.buildAttributes($attrs,true).'/>';
+  return '<'.$attrs['_tag'].' '.buildAttributes($attrs).'/>';
 }
 
 /**
@@ -670,7 +668,8 @@ function form_button($attrs) {
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_field($attrs) {
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><span>'.$attrs['_text'].'</span>';
   $s .= ' <input '.buildAttributes($attrs,true).'/></label>';
@@ -690,7 +689,8 @@ function form_field($attrs) {
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_fieldright($attrs) {
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><input '.buildAttributes($attrs,true).'/>';
   $s .= ' <span>'.$attrs['_text'].'</span></label>';
@@ -712,7 +712,8 @@ function form_fieldright($attrs) {
 function form_textfield($attrs) {
   // mandatory attributes
   unset($attrs['type']);
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><span>'.$attrs['_text'].'</span> ';
   $s .= '<input type="text" '.buildAttributes($attrs,true).'/></label>';
@@ -734,7 +735,8 @@ function form_textfield($attrs) {
 function form_passwordfield($attrs) {
   // mandatory attributes
   unset($attrs['type']);
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><span>'.$attrs['_text'].'</span> ';
   $s .= '<input type="password" '.buildAttributes($attrs,true).'/></label>';
@@ -756,7 +758,8 @@ function form_passwordfield($attrs) {
  * @author  Michael Klier <chi@chimeric.de>
  */
 function form_filefield($attrs) {
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><span>'.$attrs['_text'].'</span> ';
   $s .= '<input type="file" '.buildAttributes($attrs,true);
@@ -781,7 +784,8 @@ function form_filefield($attrs) {
 function form_checkboxfield($attrs) {
   // mandatory attributes
   unset($attrs['type']);
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><input type="checkbox" '.buildAttributes($attrs,true).'/>';
   $s .= ' <span>'.$attrs['_text'].'</span></label>';
@@ -803,7 +807,8 @@ function form_checkboxfield($attrs) {
 function form_radiofield($attrs) {
   // mandatory attributes
   unset($attrs['type']);
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><input type="radio" '.buildAttributes($attrs,true).'/>';
   $s .= ' <span>'.$attrs['_text'].'</span></label>';
@@ -827,7 +832,8 @@ function form_radiofield($attrs) {
  */
 function form_menufield($attrs) {
   $attrs['size'] = '1';
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><span>'.$attrs['_text'].'</span>';
   $s .= ' <select '.buildAttributes($attrs,true).'>'.NL;
@@ -868,7 +874,8 @@ function form_menufield($attrs) {
  * @author  Tom N Harris <tnharris@whoopdedo.org>
  */
 function form_listboxfield($attrs) {
-  $s = '<label class="'.$attrs['_class'].'"';
+  $s = '<label';
+  if ($attrs['_class']) $s .= ' class="'.$attrs['_class'].'"';
   if (!empty($attrs['id'])) $s .= ' for="'.$attrs['id'].'"';
   $s .= '><span>'.$attrs['_text'].'</span> ';
   $s .= '<select '.buildAttributes($attrs,true).'>'.NL;
