@@ -6,7 +6,7 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
+if(!defined('DOKU_INC')) die('meh.');
 if(!defined('NL')) define('NL',"\n");
 require_once(DOKU_INC.'inc/parserutils.php');
 require_once(DOKU_INC.'inc/form.php');
@@ -23,7 +23,7 @@ function html_wikilink($id,$name=NULL,$search=''){
     $xhtml_renderer = new Doku_Renderer_xhtml();
   }
 
-  return $xhtml_renderer->internallink($id,$name,$search,true);
+  return $xhtml_renderer->internallink($id,$name,$search,true,'navigation');
 }
 
 /**
@@ -56,9 +56,11 @@ function html_login(){
   $form->startFieldset($lang['btn_login']);
   $form->addHidden('id', $ID);
   $form->addHidden('do', 'login');
-  $form->addElement(form_makeTextField('u', $_REQUEST['u'], $lang['user'], 'focus__this', 'block'));
+  $form->addElement(form_makeTextField('u', ((!$_REQUEST['http_credentials']) ? $_REQUEST['u'] : ''), $lang['user'], 'focus__this', 'block'));
   $form->addElement(form_makePasswordField('p', $lang['pass'], '', 'block'));
-  $form->addElement(form_makeCheckboxField('r', '1', $lang['remember'], 'remember__me', 'simple'));
+  if($conf['rememberme']) {
+      $form->addElement(form_makeCheckboxField('r', '1', $lang['remember'], 'remember__me', 'simple'));
+  }
   $form->addElement(form_makeButton('submit', '', $lang['btn_login']));
   $form->endFieldset();
   html_form('login', $form);
@@ -181,7 +183,7 @@ function html_btn($name,$id,$akey,$params,$method='get',$tooltip=''){
 
   $ret .= '<input type="submit" value="'.htmlspecialchars($label).'" class="button" ';
   if($akey){
-    $tip .= ' [ALT+'.strtoupper($akey).']';
+    $tip .= ' ['.strtoupper($akey).']';
     $ret .= 'accesskey="'.$akey.'" ';
   }
   $ret .= 'title="'.$tip.'" ';
@@ -324,13 +326,18 @@ function html_search(){
 
   $data = ft_pageLookup($id);
   if(count($data)){
-    sort($data);
     print '<div class="search_quickresult">';
     print '<h3>'.$lang['quickhits'].':</h3>';
     print '<ul class="search_quickhits">';
     foreach($data as $id){
       print '<li> ';
-      print html_wikilink(':'.$id,noNS($id));
+      $ns = getNS($id);
+      if($ns){
+        $name = shorten(noNS($id), ' ('.$ns.')',30);
+      }else{
+        $name = $id;
+      }
+      print html_wikilink(':'.$id,$name);
       print '</li> ';
     }
     print '</ul> ';
@@ -346,7 +353,7 @@ function html_search(){
     $num = 1;
     foreach($data as $id => $cnt){
       print '<div class="search_result">';
-      print html_wikilink(':'.$id,$conf['useheading']?NULL:$id,$regex);
+      print html_wikilink(':'.$id,useHeading('navigation')?NULL:$id,$regex);
       print ': <span class="search_cnt">'.$cnt.' '.$lang['hits'].'</span><br />';
       if($num < 15){ // create snippets for the first number of matches only #FIXME add to conf ?
         print '<div class="search_snippet">'.ft_snippet($id,$regex).'</div>';
@@ -383,7 +390,7 @@ function html_locked(){
 
   print p_locale_xhtml('locked');
   print '<ul>';
-  print '<li><div class="li"><strong>'.$lang['lockedby'].':</strong> '.$INFO['locked'].'</li>';
+  print '<li><div class="li"><strong>'.$lang['lockedby'].':</strong> '.$INFO['locked'].'</div></li>';
   print '<li><div class="li"><strong>'.$lang['lockexpire'].':</strong> '.$expire.' ('.$min.' min)</div></li>';
   print '</ul>';
 }
@@ -417,28 +424,48 @@ function html_revisions($first=0){
   $date = @strftime($conf['dformat'],$INFO['lastmod']);
 
   print p_locale_xhtml('revisions');
-  print '<form action="'.wl($ID).'" method="post" id="page__revisions">';
-  print '<ul>';
+
+  $form = new Doku_Form('page__revisions', wl($ID));
+  $form->addElement(form_makeOpenTag('ul'));
   if($INFO['exists'] && $first==0){
-    print (isset($INFO['meta']) && isset($INFO['meta']['last_change']) && $INFO['meta']['last_change']['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) ? '<li class="minor">' : '<li>';
-    print '<div class="li">';
-    print '<input type="checkbox" name="rev2[]" value="current" /> ';
+    if (isset($INFO['meta']) && isset($INFO['meta']['last_change']) && $INFO['meta']['last_change']['type']===DOKU_CHANGE_TYPE_MINOR_EDIT)
+      $form->addElement(form_makeOpenTag('li', array('class' => 'minor')));
+    else
+      $form->addElement(form_makeOpenTag('li'));
+    $form->addElement(form_makeOpenTag('div', array('class' => 'li')));
+    $form->addElement(form_makeTag('input', array(
+      'type' => 'checkbox',
+      'name' => 'rev2[]',
+      'value' => 'current')));
 
-    print $date;
+    $form->addElement(form_makeOpenTag('span', array('class' => 'date')));
+    $form->addElement($date);
+    $form->addElement(form_makeCloseTag('span'));
 
-    print ' <img src="'.DOKU_BASE.'lib/images/blank.gif" width="15" height="11" alt="" /> ';
+    $form->addElement(form_makeTag('img', array(
+      'src' =>  DOKU_BASE.'lib/images/blank.gif',
+      'width' => '15',
+      'height' => '11',
+      'alt'    => '')));
 
-    print '<a class="wikilink1" href="'.wl($ID).'">'.$ID.'</a> ';
+    $form->addElement(form_makeOpenTag('a', array(
+      'class' => 'wikilink1',
+      'href'  => wl($ID))));
+    $form->addElement($ID);
+    $form->addElement(form_makeCloseTag('a'));
 
-    print ' &ndash; ';
-    print htmlspecialchars($INFO['sum']);
-    print ' <span class="user">';
-    print (empty($INFO['editor']))?('('.$lang['external_edit'].')'):htmlspecialchars($INFO['editor']);
-    print '</span> ';
+    $form->addElement(form_makeOpenTag('span', array('class' => 'sum')));
+    $form->addElement(' &ndash; ');
+    $form->addElement(htmlspecialchars($INFO['sum']));
+    $form->addElement(form_makeCloseTag('span'));
 
-    print '('.$lang['current'].')';
-    print '</div>';
-    print '</li>';
+    $form->addElement(form_makeOpenTag('span', array('class' => 'user')));
+    $form->addElement((empty($INFO['editor']))?('('.$lang['external_edit'].')'):editorinfo($INFO['editor']));
+    $form->addElement(form_makeCloseTag('span'));
+
+    $form->addElement('('.$lang['current'].')');
+    $form->addElement(form_makeCloseTag('div'));
+    $form->addElement(form_makeCloseTag('li'));
   }
 
   foreach($revisions as $rev){
@@ -446,49 +473,72 @@ function html_revisions($first=0){
     $info   = getRevisionInfo($ID,$rev,true);
     $exists = page_exists($ID,$rev);
 
-    print ($info['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) ? '<li class="minor">' : '<li>';
-    print '<div class="li">';
+    if ($info['type']===DOKU_CHANGE_TYPE_MINOR_EDIT)
+      $form->addElement(form_makeOpenTag('li', array('class' => 'minor')));
+    else
+      $form->addElement(form_makeOpenTag('li'));
+    $form->addElement(form_makeOpenTag('div', array('class' => 'li')));
     if($exists){
-      print '<input type="checkbox" name="rev2[]" value="'.$rev.'" /> ';
+      $form->addElement(form_makeTag('input', array(
+        'type' => 'checkbox',
+        'name' => 'rev2[]',
+        'value' => $rev)));
     }else{
-      print '<img src="'.DOKU_BASE.'lib/images/blank.gif" width="14" height="11" alt="" /> ';
-    }
-    print $date;
-
-    if($exists){
-      print ' <a href="'.wl($ID,"rev=$rev,do=diff").'">';
-      $p = array();
-      $p['src']    = DOKU_BASE.'lib/images/diff.png';
-      $p['width']  = 15;
-      $p['height'] = 11;
-      $p['title']  = $lang['diff'];
-      $p['alt']    = $lang['diff'];
-      $att = buildAttributes($p);
-      print "<img $att />";
-      print '</a> ';
-
-      print '<a class="wikilink1" href="'.wl($ID,"rev=$rev").'">'.$ID.'</a>';
-    }else{
-      print ' <img src="'.DOKU_BASE.'lib/images/blank.gif" width="15" height="11" alt="" /> ';
-      print $ID;
+      $form->addElement(form_makeTag('img', array(
+        'src' => DOKU_BASE.'lib/images/blank.gif',
+        'width' => 14,
+        'height' => 11,
+        'alt' => '')));
     }
 
-    print ' &ndash; ';
-    print htmlspecialchars($info['sum']);
-    print ' <span class="user">';
+    $form->addElement(form_makeOpenTag('span', array('class' => 'date')));
+    $form->addElement($date);
+    $form->addElement(form_makeCloseTag('span'));
+
+    if($exists){
+      $form->addElement(form_makeOpenTag('a', array('href' => wl($ID,"rev=$rev,do=diff", false, '&'), 'class' => 'diff_link')));
+      $form->addElement(form_makeTag('img', array(
+        'src'    => DOKU_BASE.'lib/images/diff.png',
+        'width'  => 15,
+        'height' => 11,
+        'title'  => $lang['diff'],
+        'alt'    => $lang['diff'])));
+      $form->addElement(form_makeCloseTag('a'));
+
+      $form->addElement(form_makeOpenTag('a', array('href' => wl($ID,"rev=$rev",false,'&'), 'class' => 'wikilink1')));
+      $form->addElement($ID);
+      $form->addElement(form_makeCloseTag('a'));
+    }else{
+      $form->addElement(form_makeTag('img', array(
+        'src' => DOKU_BASE.'lib/images/blank.gif',
+        'width' => '15',
+        'height' => '11',
+        'alt'   => '')));
+      $form->addElement($ID);
+    }
+
+    $form->addElement(form_makeOpenTag('span', array('class' => 'sum')));
+    $form->addElement(' &ndash; ');
+    $form->addElement(htmlspecialchars($info['sum']));
+    $form->addElement(form_makeCloseTag('span'));
+
+    $form->addElement(form_makeOpenTag('span', array('class' => 'user')));
     if($info['user']){
-      print htmlspecialchars($info['user']);
+      $form->addElement(editorinfo($info['user']));
+      if(auth_ismanager()){
+        $form->addElement(' ('.$info['ip'].')');
+      }
     }else{
-      print $info['ip'];
+      $form->addElement($info['ip']);
     }
-    print '</span>';
+    $form->addElement(form_makeCloseTag('span'));
 
-    print '</div>';
-    print '</li>';
+    $form->addElement(form_makeCloseTag('div'));
+    $form->addElement(form_makeCloseTag('li'));
   }
-  print '</ul>';
-  print '<input name="do[diff]" type="submit" value="'.$lang['diff2'].'" class="button" />';
-  print '</form>';
+  $form->addElement(form_makeCloseTag('ul'));
+  $form->addElement(form_makeButton('submit', 'diff', $lang['diff2']));
+  html_form('revisions', $form);
 
   print '<div class="pagenav">';
   $last = $first + $conf['recent'];
@@ -535,68 +585,101 @@ function html_recent($first=0){
   }
 
   print p_locale_xhtml('recent');
-  print '<ul>';
+
+  if (getNS($ID) != '')
+    print '<div class="level1"><p>' . sprintf($lang['recent_global'], getNS($ID), wl('', 'do=recent')) . '</p></div>';
+
+  $form = new Doku_Form('dw__recent', script(), 'get');
+  $form->addHidden('sectok', null);
+  $form->addHidden('do', 'recent');
+  $form->addHidden('id', $ID);
+  $form->addElement(form_makeOpenTag('ul'));
 
   foreach($recents as $recent){
     $date = strftime($conf['dformat'],$recent['date']);
-    print ($recent['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) ? '<li class="minor">' : '<li>';
-    print '<div class="li">';
+    if ($recent['type']===DOKU_CHANGE_TYPE_MINOR_EDIT)
+      $form->addElement(form_makeOpenTag('li', array('class' => 'minor')));
+    else
+      $form->addElement(form_makeOpenTag('li'));
 
-    print $date.' ';
+    $form->addElement(form_makeOpenTag('div', array('class' => 'li')));
 
-    print '<a href="'.wl($recent['id'],"do=diff").'">';
-    $p = array();
-    $p['src']    = DOKU_BASE.'lib/images/diff.png';
-    $p['width']  = 15;
-    $p['height'] = 11;
-    $p['title']  = $lang['diff'];
-    $p['alt']    = $lang['diff'];
-    $att = buildAttributes($p);
-    print "<img $att />";
-    print '</a> ';
+    $form->addElement(form_makeOpenTag('span', array('class' => 'date')));
+    $form->addElement($date);
+    $form->addElement(form_makeCloseTag('span'));
 
-    print '<a href="'.wl($recent['id'],"do=revisions").'">';
-    $p = array();
-    $p['src']    = DOKU_BASE.'lib/images/history.png';
-    $p['width']  = 12;
-    $p['height'] = 14;
-    $p['title']  = $lang['btn_revs'];
-    $p['alt']    = $lang['btn_revs'];
-    $att = buildAttributes($p);
-    print "<img $att />";
-    print '</a> ';
+    $form->addElement(form_makeOpenTag('a', array('class' => 'diff_link', 'href' => wl($recent['id'],"do=diff", false, '&'))));
+    $form->addElement(form_makeTag('img', array(
+      'src'   => DOKU_BASE.'lib/images/diff.png',
+      'width' => 15,
+      'height'=> 11,
+      'title' => $lang['diff'],
+      'alt'   => $lang['diff']
+    )));
+    $form->addElement(form_makeCloseTag('a'));
 
-    print html_wikilink(':'.$recent['id'],$conf['useheading']?NULL:$recent['id']);
-    print ' &ndash; '.htmlspecialchars($recent['sum']);
+    $form->addElement(form_makeOpenTag('a', array('class' => 'revisions_link', 'href' => wl($recent['id'],"do=revisions",false,'&'))));
+    $form->addElement(form_makeTag('img', array(
+      'src'   => DOKU_BASE.'lib/images/history.png',
+      'width' => 12,
+      'height'=> 14,
+      'title' => $lang['btn_revs'],
+      'alt'   => $lang['btn_revs']
+    )));
+    $form->addElement(form_makeCloseTag('a'));
 
-    print ' <span class="user">';
+    $form->addElement(html_wikilink(':'.$recent['id'],useHeading('navigation')?NULL:$recent['id']));
+
+    $form->addElement(form_makeOpenTag('span', array('class' => 'sum')));
+    $form->addElement(' &ndash; '.htmlspecialchars($recent['sum']));
+    $form->addElement(form_makeCloseTag('span'));
+
+    $form->addElement(form_makeOpenTag('span', array('class' => 'user')));
     if($recent['user']){
-      print htmlspecialchars($recent['user']);
+      $form->addElement(editorinfo($recent['user']));
+      if(auth_ismanager()){
+        $form->addElement(' ('.$recent['ip'].')');
+      }
     }else{
-      print $recent['ip'];
+      $form->addElement($recent['ip']);
     }
-    print '</span>';
+    $form->addElement(form_makeCloseTag('span'));
 
-    print '</div>';
-    print '</li>';
+    $form->addElement(form_makeCloseTag('div'));
+    $form->addElement(form_makeCloseTag('li'));
   }
-  print '</ul>';
+  $form->addElement(form_makeCloseTag('ul'));
 
-  print '<div class="pagenav">';
+  $form->addElement(form_makeOpenTag('div', array('class' => 'pagenav')));
   $last = $first + $conf['recent'];
   if ($first > 0) {
     $first -= $conf['recent'];
     if ($first < 0) $first = 0;
-    print '<div class="pagenav-prev">';
-    print html_btn('newer','',"p",array('do' => 'recent', 'first' => $first));
-    print '</div>';
+    $form->addElement(form_makeOpenTag('div', array('class' => 'pagenav-prev')));
+    $form->addElement(form_makeTag('input', array(
+      'type'  => 'submit',
+      'name'  => 'first['.$first.']',
+      'value' => $lang['btn_newer'],
+      'accesskey' => 'n',
+      'title' => $lang['btn_newer'].' [N]',
+      'class' => 'button'
+    )));
+    $form->addElement(form_makeCloseTag('div'));
   }
   if ($hasNext) {
-    print '<div class="pagenav-next">';
-    print html_btn('older','',"n",array('do' => 'recent', 'first' => $last));
-    print '</div>';
+    $form->addElement(form_makeOpenTag('div', array('class' => 'pagenav-next')));
+    $form->addElement(form_makeTag('input', array(
+      'type'  => 'submit',
+      'name'  => 'first['.$last.']',
+      'value' => $lang['btn_older'],
+      'accesskey' => 'p',
+      'title' => $lang['btn_older'].' [P]',
+      'class' => 'button'
+    )));
+    $form->addElement(form_makeCloseTag('div'));
   }
-  print '</div>';
+  $form->addElement(form_makeCloseTag('div'));
+  html_form('recent', $form);
 }
 
 /**
@@ -756,7 +839,7 @@ function html_backlinks(){
       print '<ul class="idx">';
       foreach($data as $blink){
         print '<li><div class="li">';
-        print html_wikilink(':'.$blink,$conf['useheading']?NULL:$blink);
+        print html_wikilink(':'.$blink,useHeading('navigation')?NULL:$blink);
         print '</div></li>';
       }
       print '</ul>';
@@ -835,19 +918,46 @@ function html_diff($text='',$intro=true){
     if(!$l_rev){
       $l_head = '&mdash;';
     }else{
+      $l_info   = getRevisionInfo($ID,$l_rev,true);
+      if($l_info['user']){ $l_user = editorinfo($l_info['user']);
+        if(auth_ismanager()) $l_user .= ' ('.$l_info['ip'].')';
+      } else { $l_user = $l_info['ip']; }
+      $l_user  = '<span class="user">'.$l_user.'</span>';
+      $l_sum   = ($l_info['sum']) ? '<span class="sum">'.hsc($l_info['sum']).'</span>' : '';
+      if ($l_info['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) $l_minor = 'class="minor"';
+
       $l_head = '<a class="wikilink1" href="'.wl($ID,"rev=$l_rev").'">'.
-                $ID.' '.strftime($conf['dformat'],$l_rev).'</a>';
+                $ID.' ['.strftime($conf['dformat'],$l_rev).']</a>'.
+                '<br />'.$l_user.' '.$l_sum;
     }
 
     if($r_rev){
+      $r_info   = getRevisionInfo($ID,$r_rev,true);
+      if($r_info['user']){ $r_user = editorinfo($r_info['user']);
+        if(auth_ismanager()) $r_user .= ' ('.$r_info['ip'].')';
+      } else { $r_user = $r_info['ip']; }
+      $r_user = '<span class="user">'.$r_user.'</span>';
+      $r_sum  = ($r_info['sum']) ? '<span class="sum">'.hsc($r_info['sum']).'</span>' : '';
+      if ($r_info['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) $r_minor = 'class="minor"';
+
       $r_head = '<a class="wikilink1" href="'.wl($ID,"rev=$r_rev").'">'.
-                $ID.' '.strftime($conf['dformat'],$r_rev).'</a>';
+                $ID.' ['.strftime($conf['dformat'],$r_rev).']</a>'.
+                '<br />'.$r_user.' '.$r_sum;
     }elseif($_rev = @filemtime(wikiFN($ID))){
+      $_info   = getRevisionInfo($ID,$_rev,true);
+      if($_info['user']){ $_user = editorinfo($_info['user']);
+        if(auth_ismanager()) $_user .= ' ('.$_info['ip'].')';
+      } else { $_user = $_info['ip']; }
+      $_user = '<span class="user">'.$_user.'</span>';
+      $_sum  = ($_info['sum']) ? '<span class="sum">'.hsc($_info['sum']).'</span>' : '';
+      if ($_info['type']===DOKU_CHANGE_TYPE_MINOR_EDIT) $r_minor = 'class="minor"';
+
       $r_head  = '<a class="wikilink1" href="'.wl($ID).'">'.
-               $ID.' '.strftime($conf['dformat'],$_rev).'</a> '.
-               $lang['current'];
+               $ID.' ['.strftime($conf['dformat'],$_rev).']</a> '.
+               '('.$lang['current'].')'.
+                '<br />'.$_user.' '.$_sum;
     }else{
-      $r_head = '&mdash; '.$lang['current'];
+      $r_head = '&mdash; ('.$lang['current'].')';
     }
   }
 
@@ -859,10 +969,10 @@ function html_diff($text='',$intro=true){
   ?>
     <table class="diff">
       <tr>
-        <th colspan="2">
+        <th colspan="2" <?php echo $l_minor?>>
           <?php echo $l_head?>
         </th>
-        <th colspan="2">
+        <th colspan="2" <?php echo $r_minor?>>
           <?php echo $r_head?>
         </th>
       </tr>
@@ -897,15 +1007,18 @@ function html_conflict($text,$summary){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function html_msgarea(){
-  global $MSG;
+    global $MSG;
+    if(!isset($MSG)) return;
 
-  if(!isset($MSG)) return;
-
-  foreach($MSG as $msg){
-    print '<div class="'.$msg['lvl'].'">';
-    print $msg['msg'];
-    print '</div>';
-  }
+    $shown = array();
+    foreach($MSG as $msg){
+        $hash = md5($msg['msg']);
+        if(isset($shown[$hash])) continue; // skip double messages
+        print '<div class="'.$msg['lvl'].'">';
+        print $msg['msg'];
+        print '</div>';
+        $shown[$hash] = 1;
+    }
 }
 
 /**
@@ -1002,6 +1115,7 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
   global $SUM;
   global $lang;
   global $conf;
+  global $license;
 
   //set summary default
   if(!$SUM){
@@ -1042,7 +1156,7 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
     }
   }
 
-  $wr = $INFO['writable'];
+  $wr = $INFO['writable'] && !$INFO['locked'];
   if($wr){
     if ($REV) print p_locale_xhtml('editrev');
     print p_locale_xhtml($include);
@@ -1102,6 +1216,15 @@ function html_edit($text=null,$include='edit'){ //FIXME: include needed?
     $form->addElement(form_makeCloseTag('div'));
   }
   $form->addElement(form_makeCloseTag('div'));
+  if($conf['license']){
+    $form->addElement(form_makeOpenTag('div', array('class'=>'license')));
+    $out  = $lang['licenseok'];
+    $out .= '<a href="'.$license[$conf['license']]['url'].'" rel="license" class="urlextern"';
+    if($conf['target']['external']) $out .= ' target="'.$conf['target']['external'].'"';
+    $out .= '> '.$license[$conf['license']]['name'].'</a>';
+    $form->addElement($out);
+    $form->addElement(form_makeCloseTag('div'));
+  }
   html_form('edit', $form);
   print '</div>'.NL;
 }
@@ -1138,13 +1261,11 @@ function html_debug(){
 
   //remove sensitive data
   $cnf = $conf;
-  $cnf['auth']='***';
-  $cnf['notify']='***';
-  $cnf['ftp']='***';
+  debug_guard($cnf);
   $nfo = $INFO;
-  $nfo['userinfo'] = '***';
+  debug_guard($nfo);
   $ses = $_SESSION;
-  $ses[$conf['title']]['auth'] = '***';
+  debug_guard($ses);
 
   print '<html><body>';
 
@@ -1343,4 +1464,81 @@ function html_form_output($data) {
   $data->printForm();
 }
 
+/**
+ * Embed a flash object in HTML
+ *
+ * This will create the needed HTML to embed a flash movie in a cross browser
+ * compatble way using valid XHTML
+ *
+ * The parameters $params, $flashvars and $atts need to be associative arrays.
+ * No escaping needs to be done for them. The alternative content *has* to be
+ * escaped because it is used as is. If no alternative content is given
+ * $lang['noflash'] is used.
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ * @link   http://latrine.dgx.cz/how-to-correctly-insert-a-flash-into-xhtml
+ *
+ * @param string $swf      - the SWF movie to embed
+ * @param int $width       - width of the flash movie in pixels
+ * @param int $height      - height of the flash movie in pixels
+ * @param array $params    - additional parameters (<param>)
+ * @param array $flashvars - parameters to be passed in the flashvar parameter
+ * @param array $atts      - additional attributes for the <object> tag
+ * @param string $alt      - alternative content (is NOT automatically escaped!)
+ * @returns string         - the XHTML markup
+ */
+function html_flashobject($swf,$width,$height,$params=null,$flashvars=null,$atts=null,$alt=''){
+    global $lang;
+
+    $out = '';
+
+    // prepare the object attributes
+    if(is_null($atts)) $atts = array();
+    $atts['width']  = (int) $width;
+    $atts['height'] = (int) $height;
+    if(!$atts['width'])  $atts['width']  = 425;
+    if(!$atts['height']) $atts['height'] = 350;
+
+    // add object attributes for standard compliant browsers
+    $std = $atts;
+    $std['type'] = 'application/x-shockwave-flash';
+    $std['data'] = $swf;
+
+    // add object attributes for IE
+    $ie  = $atts;
+    $ie['classid'] = 'clsid:D27CDB6E-AE6D-11cf-96B8-444553540000';
+
+    // open object (with conditional comments)
+    $out .= '<!--[if !IE]> -->'.NL;
+    $out .= '<object '.buildAttributes($std).'>'.NL;
+    $out .= '<!-- <![endif]-->'.NL;
+    $out .= '<!--[if IE]>'.NL;
+    $out .= '<object '.buildAttributes($ie).'>'.NL;
+    $out .= '    <param name="movie" value="'.hsc($swf).'" />'.NL;
+    $out .= '<!--><!-- -->'.NL;
+
+    // print params
+    if(is_array($params)) foreach($params as $key => $val){
+        $out .= '  <param name="'.hsc($key).'" value="'.hsc($val).'" />'.NL;
+    }
+
+    // add flashvars
+    if(is_array($flashvars)){
+        $out .= '  <param name="FlashVars" value="'.buildURLparams($flashvars).'" />'.NL;
+    }
+
+    // alternative content
+    if($alt){
+        $out .= $alt.NL;
+    }else{
+        $out .= $lang['noflash'].NL;
+    }
+
+    // finish
+    $out .= '</object>'.NL;
+    $out .= '<!-- <![endif]-->'.NL;
+
+    return $out;
+}
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
