@@ -6,11 +6,13 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-  if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
-  require_once(DOKU_CONF.'dokuwiki.php');
-  require_once(DOKU_INC.'inc/io.php');
-  require_once(DOKU_INC.'inc/utf8.php');
-  require_once(DOKU_INC.'inc/parserutils.php');
+if(!defined('DOKU_INC')) die('meh.');
+require_once(DOKU_INC.'inc/io.php');
+require_once(DOKU_INC.'inc/utf8.php');
+require_once(DOKU_INC.'inc/parserutils.php');
+
+// set the minimum token length to use in the index (note, this doesn't apply to numeric tokens)
+if (!defined('IDX_MINWORDLENGTH')) define('IDX_MINWORDLENGTH',2);
 
 // Asian characters are handled as words. The following regexp defines the
 // Unicode-Ranges for Asian characters
@@ -77,6 +79,21 @@ function idx_saveIndex($pre, $wlen, &$idx){
     return true;
 }
 
+/**
+ * Append a given line to an index file.
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function idx_appendIndex($pre, $wlen, $line){
+    global $conf;
+    $fn = $conf['indexdir'].'/'.$pre.$wlen;
+    $fh = @fopen($fn.'.idx','a');
+    if(!$fh) return false;
+    fwrite($fh,$line);
+    fclose($fh);
+    return true;
+}
+
 /**
  * Read the list of words in an index (if it exists).
  *
@@ -202,7 +219,7 @@ function idx_getPageWords($page){
     unset($evt);
 
     list($page,$body) = $data;
-    
+
     $body   = strtr($body, "\r\n\t", '   ');
     $tokens = explode(' ', $body);
     $tokens = array_count_values($tokens);   // count the frequency of each token
@@ -282,14 +299,14 @@ function idx_addPage($page){
     // get page id (this is the linenumber in page.idx)
     $pid = array_search("$page\n",$page_idx);
     if(!is_int($pid)){
-        $page_idx[] = "$page\n";
-        $pid = count($page_idx)-1;
+        $pid = count($page_idx);
         // page was new - write back
-        if (!idx_saveIndex('page','',$page_idx)){
+        if (!idx_appendIndex('page','',"$page\n")){
             trigger_error("Failed to write page index", E_USER_ERROR);
             return false;
         }
     }
+    unset($page_idx); // free memory
 
     $pagewords = array();
     // get word usage in page
@@ -318,7 +335,7 @@ function idx_addPage($page){
             }
         }
     }
-    
+
     // Remove obsolete index entries
     $pageword_idx = trim(idx_getIndexLine('pageword','',$pid));
     if ($pageword_idx !== '') {
@@ -472,7 +489,7 @@ function idx_getIndexWordsSorted($words,&$result){
             $wild |= 2;
             $wlen -= 1;
         }
-        if ($wlen < 3 && $wild == 0 && !is_numeric($xword)) continue;
+        if ($wlen < IDX_MINWORDLENGTH && $wild == 0 && !is_numeric($xword)) continue;
         if(!isset($tokens[$xword])){
             $tokenlength[$wlen][] = $xword;
         }
@@ -620,14 +637,14 @@ function idx_tokenizer($string,&$stopwords,$wc=false){
 
         $arr = explode(' ', utf8_stripspecials($string,' ','\._\-:'.$wc));
         foreach ($arr as $w) {
-            if (!is_numeric($w) && strlen($w) < 3) continue;
+            if (!is_numeric($w) && strlen($w) < IDX_MINWORDLENGTH) continue;
             $w = utf8_strtolower($w);
             if($stopwords && is_int(array_search("$w\n",$stopwords))) continue;
             $words[] = $w;
         }
     }else{
         $w = $string;
-        if (!is_numeric($w) && strlen($w) < 3) return $words;
+        if (!is_numeric($w) && strlen($w) < IDX_MINWORDLENGTH) return $words;
         $w = strtolower($w);
         if(is_int(array_search("$w\n",$stopwords))) return $words;
         $words[] = $w;
@@ -646,13 +663,15 @@ function idx_upgradePageWords(){
     $page_idx = idx_getIndex('page','');
     if (empty($page_idx)) return;
     $pagewords = array();
-    for ($n=0;$n<count($page_idx);$n++) $pagewords[] = array();
+    $len = count($page_idx);
+    for ($n=0;$n<$len;$n++) $pagewords[] = array();
     unset($page_idx);
 
     $n=0;
     foreach (idx_indexLengths($n) as $wlen) {
         $lines = idx_getIndex('i',$wlen);
-        for ($wid=0;$wid<count($lines);$wid++) {
+        $len = count($lines);
+        for ($wid=0;$wid<$len;$wid++) {
             $wkey = "$wlen*$wid";
             foreach (explode(':',trim($lines[$wid])) as $part) {
                 if($part == '') continue;
