@@ -6,11 +6,11 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-  if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
-  require_once(DOKU_INC.'inc/common.php');
-  require_once(DOKU_INC.'inc/HTTPClient.php');
-  require_once(DOKU_INC.'inc/events.php');
-  require_once(DOKU_INC.'inc/utf8.php');
+if(!defined('DOKU_INC')) die('meh.');
+require_once(DOKU_INC.'inc/common.php');
+require_once(DOKU_INC.'inc/HTTPClient.php');
+require_once(DOKU_INC.'inc/events.php');
+require_once(DOKU_INC.'inc/utf8.php');
 
 /**
  * Removes empty directories
@@ -424,7 +424,7 @@ function io_mkdir_ftp($dir){
     return false;
   }
 
-  if(!@ftp_login($conn, $conf['ftp']['user'], $conf['ftp']['pass'])){
+  if(!@ftp_login($conn, $conf['ftp']['user'], conf_decodeString($conf['ftp']['pass']))){
     msg("FTP login failed",-1);
     return false;
   }
@@ -449,7 +449,7 @@ function io_mktmpdir() {
 
     $base = $conf['tmpdir'];
     $dir  = md5(uniqid(mt_rand(), true));
-    $tmpdir = $base.$dir;
+    $tmpdir = $base.'/'.$dir;
 
     if(io_mkdir_p($tmpdir)) {
         return($tmpdir);
