@@ -131,7 +131,7 @@ $lang['mail_newpage']            = 'dobavena stranica:';
 $lang['mail_changed']            = 'promenenta stranica:';
 $lang['mail_new_user']           = 'Nov potrebitel:';
 $lang['mail_upload']             = 'kachen fail:';
-$lang['nosmblinks']              = 'Връзките към Windows shares работят само под Internet Explorer.\nМожете да копирате и поставите връзката.';
+$lang['js']['nosmblinks']              = "Връзките към Windows shares работят само под Internet Explorer.\nМожете да копирате и поставите връзката.";
 $lang['qb_alert']                = 'Моля въведете текст за форматиране.\nЩе бъде добавен в края на документа.';
 $lang['qb_bold']                 = 'Получер текст';
 $lang['qb_italic']               = 'Курсив текст';
@@ -183,7 +183,7 @@ $lang['i_superuser']             = 'Суперпотребител';
 $lang['i_problems']              = 'Инсталатора намери проблеми указани по-долу. Не може да продължите докато не ги оправите';
 $lang['i_modified']              = 'Поради мерки за сигурност този скрипт ще работи само с нова и непроменена Dokuwiki инсталация.
                          Трябва или да разархивирате отново файловете от дръпнатия пакет или да се посъветвате с пълните
-                         <a href="http://wiki.splitbrain.org/wiki:install">Инструкции за инсталация на Dokuwiki </a>';
+                         <a href="http://dokuwiki.org/install">Инструкции за инсталация на Dokuwiki </a>';
 $lang['i_funcna']                = 'PHP функцията <code>%s</code> не е достъпна. Може би доставчика на хостинг я е изключил';
 $lang['i_phpver']                = 'Вашата PHP версия <code>%s</code> е по-стара от нужната <code>%s</code>. Трябва да обновите вашата PHP инсталация.';
 $lang['i_permfail']              = '<code>%s</code> не е достъпна за писане от DokuWiki. Трябва да промените настройките за достъп до директорията!';
