@@ -63,6 +63,7 @@ $lang['profile']               = 'Perfil d\'usuari';
 $lang['badlogin']              = 'Nom d\'usuari o contrasenya incorrectes.';
 $lang['minoredit']             = 'Canvis menors';
 $lang['draftdate']             = 'L\'esborrany s\'ha desat automàticament';
+$lang['nosecedit']             = 'Mentrestant la pàgina ha estat modificada. La informació de seccions estava obsoleta i ha calgut carregar la pàgina sencera.';
 $lang['regmissing']            = 'Heu d\'omplir tots els camps.';
 $lang['reguexists']            = 'Ja existeix un altre usuari amb aquest nom.';
 $lang['regsuccess']            = 'S\'ha creat l\'usuari. La contrasenya s\'ha enviat per correu.';
@@ -84,6 +85,8 @@ $lang['resendpwdnouser']       = 'No s\'ha pogut trobar aquest usuari a la base
 $lang['resendpwdbadauth']      = 'Aquest codi d\'autenticació no és vàlid. Assegureu-vos d\'utilitzar l\'enllaç de confirmació complet.';
 $lang['resendpwdconfirm']      = 'Se us ha enviat per correu electrònic un enllaç de confirmació.';
 $lang['resendpwdsuccess']      = 'Se us ha enviat la nova contrasenya per correu electrònic.';
+$lang['license']               = 'Excepte on es digui una altra cosa, el contingut d\'aquest wiki està subjecte a la llicència següent:';
+$lang['licenseok']             = 'Nota. En editar aquesta pàgina esteu acceptant que el vostre contingut estigui subjecte a la llicència següent:';
 $lang['txt_upload']            = 'Trieu el fitxer que voleu penjar';
 $lang['txt_filename']          = 'Introduïu el nom wiki (opcional)';
 $lang['txt_overwrt']           = 'Sobreescriu el fitxer actual';
@@ -102,6 +105,7 @@ $lang['uploadexist']           = 'El fitxer ja existeix. No s\'ha penjat.';
 $lang['uploadbadcontent']      = 'El contingut que heu penjat coincideix amb l\'extensió de fitxer %s.';
 $lang['uploadspam']            = 'La càrrega ha estat blocada per la llista negra de brossa.';
 $lang['uploadxss']             = 'La càrrega ha estat blocada perquè podria ser un contingut maligne.';
+$lang['uploadsize']            = 'El fitxer que voleu penjar és massa gran (màxim %s)';
 $lang['deletesucc']            = 'S\'ha suprimit el fitxer "%s".';
 $lang['deletefail']            = 'No s\'ha pogut suprimir el fitxer "%s". Comproveu els permisos.';
 $lang['mediainuse']            = 'No s\'ha pogut suprimir el fitxer "%s". Encara s\'està utilitzant.';
@@ -109,6 +113,9 @@ $lang['namespaces']            = 'Espais';
 $lang['mediafiles']            = 'Fitxers disponibles en';
 $lang['js']['keepopen']        = 'Manté la finestra oberta';
 $lang['js']['hidedetails']     = 'Oculta detalls';
+$lang['js']['nosmblinks']      = 'Els enllaços amb recursos compartits de Windows només funcionen amb el Microsoft Internet Explorer.
+Si voleu podeu copiar i enganxar l\'enllaç.';
+$lang['js']['mu_btn']          = 'Penja múltiples fitxers';
 $lang['mediausage']            = 'Utilitzeu la sintaxi següent per referir-vos a aquest enllaç:';
 $lang['mediaview']             = 'Mostra el fitxer original';
 $lang['mediaroot']             = 'arrel';
@@ -134,11 +141,11 @@ $lang['created']               = 'creat';
 $lang['restored']              = 's\'ha restaurat una versió anterior';
 $lang['external_edit']         = 'edició externa';
 $lang['summary']               = 'Resum d\'edició';
+$lang['noflash']               = 'Per a visualitzar aquest contingut necessiteu el <a href="http://www.adobe.com/products/flashplayer/">connector d\'Adobe Flash</a>.';
 $lang['mail_newpage']          = 'pàgina afegida:';
 $lang['mail_changed']          = 'pàgina modificada:';
 $lang['mail_new_user']         = 'nou usuari:';
 $lang['mail_upload']           = 'fitxer penjat:';
-$lang['nosmblinks']            = 'Els enllaços amb recursos compartits de Windows només funcionen amb el Microsoft Internet Explorer.\nSi voleu podeu copiar i enganxar l\'enllaç.';
 $lang['qb_alert']              = 'Introduïu el text que voleu formatar.\nS\'afegirà al final del document.';
 $lang['qb_bold']               = 'Negreta';
 $lang['qb_italic']             = 'Cursiva';
@@ -188,7 +195,7 @@ $lang['i_wikiname']            = 'Nom del wiki';
 $lang['i_enableacl']           = 'Habilita ACL (recomanat)';
 $lang['i_superuser']           = 'Superusuari';
 $lang['i_problems']            = 'L\'instal·lador ha trobat alguns problemes, que s\'indiquen més avall. No podeu continuar fins que no els hàgiu solucionat.';
-$lang['i_modified']            = 'Per raons de seguretat aquesta seqüència només funciona amb una instal·lació nova i no modificada de Dokuwiki. Hauríeu de tornar a baixar el paquet i/o descomprimir-lo o consultar les <a href="http://wiki.splitbrain.org/wiki:install">instruccions d\'instal·lació de Dokuwiki</a> completes';
+$lang['i_modified']            = 'Per raons de seguretat aquesta seqüència només funciona amb una instal·lació nova i no modificada de Dokuwiki. Hauríeu de tornar a baixar el paquet i/o descomprimir-lo o consultar les <a href="http://dokuwiki.org/install">instruccions d\'instal·lació de Dokuwiki</a> completes';
 $lang['i_funcna']              = 'La funció PHP <code>%s</code> no està disponible. Potser el vostre proveïdor de serveis l\'ha inhabilitada per alguna raó';
 $lang['i_phpver']              = 'La vostra versió de PHP <code>%s</code> és inferior a la requerida <code>%s</code>. Necessiteu actualitzar la vostra instal·lació de PHP.';
 $lang['i_permfail']            = 'DokuWiki no pot escriure <code>%s</code>. Heu d\'arreglar els permisos d\'aquest directori';
@@ -203,3 +210,17 @@ $lang['i_pol0']                = 'Wiki obert (tothom pot llegir, escriure i penj
 $lang['i_pol1']                = 'Wiki públic (tothom pot llegir, els usuaris registrats poden escriure i penjar fitxers)';
 $lang['i_pol2']                = 'Wiki tancat (només els usuaris registrats poden llegir, escriure i penjar fitxers)';
 $lang['i_retry']               = 'Reintenta';
+$lang['mu_intro']              = 'Aquí podeu penjar múltiples fitxers d\'una vegada. Feu clic en el botó Explora per afegir els fitxers a la cua. Després, premeu Penja.';
+$lang['mu_gridname']           = 'Nom del fitxer';
+$lang['mu_gridsize']           = 'Mida';
+$lang['mu_gridstat']           = 'Estat';
+$lang['mu_namespace']          = 'Espai';
+$lang['mu_browse']             = 'Explora';
+$lang['mu_toobig']             = 'massa gran';
+$lang['mu_ready']              = 'llest per a penjar';
+$lang['mu_done']               = 'complet';
+$lang['mu_fail']               = 'error';
+$lang['mu_authfail']           = 'la sessió ha vençut';
+$lang['mu_progress']           = 'càrrega @PCT@%';
+$lang['mu_filetypes']          = 'Tipus de fitxer permesos';
+$lang['recent_global']         = 'Esteu veient els canvis recents de l\'espai <strong>%s</strong>. També podeu veure els <a href="%s">canvis recents de tot el wiki</a>.';
