@@ -134,7 +134,7 @@ $lang['mail_newpage']          = 'σελίδα προστέθηκε:';
 $lang['mail_changed']          = 'σελίδα τροποποιήθηκε:';
 $lang['mail_new_user']         = 'νέος χρήστης:';
 $lang['mail_upload']           = 'αρχείο φορτώθηκε:';
-$lang['nosmblinks']            = 'Οι σύνδεσμοι προς Windows shares δουλεύουν μόνο στον Microsoft Internet Explorer.\nΜπορείτε πάντα να κάνετε αντιγραφή και επικόλληση του συνδέσμου.';
+$lang['js']['nosmblinks']            = "Οι σύνδεσμοι προς Windows shares δουλεύουν μόνο στον Microsoft Internet Explorer.\nΜπορείτε πάντα να κάνετε αντιγραφή και επικόλληση του συνδέσμου.";
 $lang['qb_alert']              = 'Προσθέσετε το κείμενο που θέλετε να μορφοποιήσετε.\nΘα προστεθεί στο τέλος του εγγράφου.';
 $lang['qb_bold']               = 'Έντονο Κείμενο';
 $lang['qb_italic']             = 'Πλάγιο Κείμενο';
@@ -186,7 +186,7 @@ $lang['i_superuser']           = 'Διαχειριστής';
 $lang['i_problems']            = 'Ο οδηγός εγκατάστασης συνάντησε τα προβλήματα που αναφέρονται παρακάτω. Η εγκατάσταση δεν θα ολοκληρωθεί επιτυχώς μέχρι να επιλυθούν αυτά τα προβλήματα.';
 $lang['i_modified']            = 'Για λόγους ασφαλείας, ο οδηγός εγκατάστασης λειτουργεί μόνο με νέες και μη τροποποιημένες εγκαταστάσεις Dokuwiki.
                                       Πρέπει είτε να κάνετε νέα εγκατάσταση, χρησιμοποιώντας το αρχικό πακέτο εγκατάστασης, ή να
-                                      συμβουλευτείτε τις <a href="http://wiki.splitbrain.org/wiki:install">οδηγίες εγκατάστασης της εφαρμογής.</a>';
+                                      συμβουλευτείτε τις <a href="http://dokuwiki.org/install">οδηγίες εγκατάστασης της εφαρμογής.</a>';
 $lang['i_funcna']              = 'Η λειτουργία <code>%s</code> της PHP δεν είναι διαθέσιμη. Πιθανόν να είναι απενεργοποιημένη στις ρυθμίσεις έναρξης της PHP';
 $lang['i_phpver']              = 'Η έκδοση <code>%s</code> της PHP που έχετε είναι παλαιότερη της απαιτούμενης <code>%s</code>. Πρέπει να αναβαθμίσετε την PHP.';
 $lang['i_permfail']            = 'Ο φάκελος <code>%s</code> δεν είναι εγγράψιμος από την εφαρμογή DokuWiki. Πρέπει να διορθώσετε τα δικαιώματα πρόσβασης αυτού του φακέλου!';
