@@ -4,7 +4,7 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author     Andreas Gohr <andi@splitbrain.org>
- * @author     Anika Henke <henke@cosmocode.de>
+ * @author     Anika Henke <anika@selfthinker.org>
  * @author     Matthias Grimm <matthiasgrimm@users.sourceforge.net>
  */
 $lang['encoding']   = 'utf-8';
@@ -57,13 +57,14 @@ $lang['newpass']    = 'New password';
 $lang['oldpass']    = 'Confirm current password';
 $lang['passchk']    = 'once again';
 $lang['remember']   = 'Remember me';
-$lang['fullname']   = 'Full name';
+$lang['fullname']   = 'Real name';
 $lang['email']      = 'E-Mail';
 $lang['register']   = 'Register';
 $lang['profile']    = 'User Profile';
 $lang['badlogin']   = 'Sorry, username or password was wrong.';
 $lang['minoredit']  = 'Minor Changes';
 $lang['draftdate']  = 'Draft autosaved on'; // full dformat date will be added
+$lang['nosecedit']  = 'The page was changed in the meantime, section info was out of date loaded full page instead.';
 
 $lang['regmissing'] = 'Sorry, you must fill in all fields.';
 $lang['reguexists'] = 'Sorry, a user with this login already exists.';
@@ -78,7 +79,7 @@ $lang['reghere']    = 'You don\'t have an account yet? Just get one';
 $lang['profna']       = 'This wiki does not support profile modification';
 $lang['profnochange'] = 'No changes, nothing to do.';
 $lang['profnoempty']  = 'An empty name or email address is not allowed.';
-$lang['profchanged']  = 'User profile sucessfully updated.';
+$lang['profchanged']  = 'User profile successfully updated.';
 
 $lang['pwdforget'] = 'Forgotten your password? Get a new one';
 $lang['resendna']  = 'This wiki does not support password resending.';
@@ -89,6 +90,9 @@ $lang['resendpwdbadauth'] = 'Sorry, this auth code is not valid. Make sure you u
 $lang['resendpwdconfirm'] = 'A confirmation link has been sent by email.';
 $lang['resendpwdsuccess'] = 'Your new password has been sent by email.';
 
+$lang['license']   = 'Except where otherwise noted, content on this wiki is licensed under the following license:';
+$lang['licenseok'] = 'Note: By editing this page you agree to license your content under the following license:';
+
 $lang['txt_upload']   = 'Select file to upload';
 $lang['txt_filename'] = 'Upload as (optional)';
 $lang['txt_overwrt']  = 'Overwrite existing file';
@@ -109,6 +113,7 @@ $lang['uploadexist'] = 'File already exists. Nothing done.';
 $lang['uploadbadcontent'] = 'The uploaded content did not match the %s file extension.';
 $lang['uploadspam']  = 'The upload was blocked by the spam blacklist.';
 $lang['uploadxss']   = 'The upload was blocked for possibly malicious content.';
+$lang['uploadsize']  = 'The uploaded file was too big. (max. %s)';
 $lang['deletesucc']  = 'The file "%s" has been deleted.';
 $lang['deletefail']  = '"%s" couldn\'t be deleted - check permissions.';
 $lang['mediainuse']  = 'The file "%s" hasn\'t been deleted - it is still in use.';
@@ -144,13 +149,14 @@ $lang['created']    = 'created';
 $lang['restored']   = 'old revision restored';
 $lang['external_edit'] = 'external edit';
 $lang['summary']    = 'Edit summary';
+$lang['noflash']    = 'The <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> is needed to display this content.';
 
 $lang['mail_newpage']  = 'page added:';
 $lang['mail_changed']  = 'page changed:';
 $lang['mail_new_user'] = 'new user:';
 $lang['mail_upload']   = 'file uploaded:';
 
-$lang['nosmblinks'] = 'Linking to Windows shares only works in Microsoft Internet Explorer.\nYou still can copy and paste the link.';
+$lang['js']['nosmblinks'] = "Linking to Windows shares only works in Microsoft Internet Explorer.\nYou still can copy and paste the link.";
 
 $lang['qb_alert']   = 'Please enter the text you want to format.\nIt will be appended to the end of the document.';
 $lang['qb_bold']    = 'Bold Text';
@@ -210,7 +216,7 @@ $lang['i_superuser']  = 'Superuser';
 $lang['i_problems']   = 'The installer found some problems, indicated below. You can not continue until you have fixed them.';
 $lang['i_modified']   = 'For security reasons this script will only work with a new and unmodified Dokuwiki installation.
                          You should either re-extract the files from the downloaded package or consult the complete
-                         <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki installation instructions</a>';
+                         <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a>';
 $lang['i_funcna']     = 'PHP function <code>%s</code> is not available. Maybe your hosting provider disabled it for some reason?';
 $lang['i_phpver']     = 'Your PHP version <code>%s</code> is lower than the needed <code>%s</code>. You need to upgrade your PHP install.';
 $lang['i_permfail']   = '<code>%s</code> is not writable by DokuWiki. You need to fix the permission settings of this directory!';
@@ -229,4 +235,21 @@ $lang['i_pol2']       = 'Closed Wiki (read, write, upload for registered users o
 
 $lang['i_retry']      = 'Retry';
 
+$lang['mu_intro']     = 'Here you can upload multiple files at once. Click the browse button to add them to the queue. Press upload when done.';
+$lang['js']['mu_btn'] = 'Upload multiple files at once';
+$lang['mu_gridname']  = 'Filename';
+$lang['mu_gridsize']  = 'Size';
+$lang['mu_gridstat']  = 'Status';
+$lang['mu_namespace'] = 'Namespace';
+$lang['mu_browse']    = 'Browse';
+$lang['mu_toobig']    = 'too big';
+$lang['mu_ready']     = 'ready for upload';
+$lang['mu_done']      = 'complete';
+$lang['mu_fail']      = 'failed';
+$lang['mu_authfail']  = 'session expired';
+$lang['mu_progress']  = '@PCT@% uploaded';
+$lang['mu_filetypes'] = 'Allowed Filetypes';
+
+$lang['recent_global'] = 'You\'re currently watching the changes inside the <b>%s</b> namespace. You can also <a href="%s">view the recent changes of the whole wiki</a>.';
+
 //Setup VIM: ex: et ts=2 enc=utf-8 :
