@@ -12,6 +12,10 @@
  * @author Oscar M. Lage <r0sk10@gmail.com>
  * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
  * @author oliver@samera.com.py
+ * @author Enrico Nicoletto <liverig@gmail.com>
+ * @author Manuel Meco <manuel.meco@gmail.com>
+ * @author VictorCastelan <victorcastelan@gmail.com>
+ * @author Jordan Mero  hack.jord@gmail.com
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -36,24 +40,24 @@ $lang['btn_upload']            = 'Cargar';
 $lang['btn_cancel']            = 'Cancelar';
 $lang['btn_index']             = 'Indice';
 $lang['btn_secedit']           = 'Editar';
-$lang['btn_login']             = 'Ingresar';
+$lang['btn_login']             = 'Entrar';
 $lang['btn_logout']            = 'Salir';
 $lang['btn_admin']             = 'Administrar';
 $lang['btn_update']            = 'Actualizar';
 $lang['btn_delete']            = 'Borrar';
 $lang['btn_back']              = 'Atrás';
-$lang['btn_backlink']          = 'Backlinks';
+$lang['btn_backlink']          = 'Enlaces anteriores';
 $lang['btn_backtomedia']       = 'Vuelta a la selección de medios';
 $lang['btn_subscribe']         = 'Subscribirse a la notificación de cambios';
 $lang['btn_unsubscribe']       = 'Desubscribirse a la notificación de cambios';
 $lang['btn_subscribens']       = 'Subscribirse a cambios de un directorio';
-$lang['btn_unsubscribens']     = 'Desubscribirse de cambios de un directorio';
+$lang['btn_unsubscribens']     = 'Borrarse de cambios de un directorio';
 $lang['btn_profile']           = 'Actualizar datos del usuario';
 $lang['btn_reset']             = 'Deshacer cambios';
 $lang['btn_resendpwd']         = 'Enviar nueva contraseña';
 $lang['btn_draft']             = 'Editar borrador';
 $lang['btn_recover']           = 'Recuperar borrador';
-$lang['btn_draftdel']          = 'Borrar borrador';
+$lang['btn_draftdel']          = 'Eliminar borrador';
 $lang['loggedinas']            = 'Conectado como ';
 $lang['user']                  = 'Usuario';
 $lang['pass']                  = 'Contraseña';
@@ -68,6 +72,7 @@ $lang['profile']               = 'Datos del usuario';
 $lang['badlogin']              = 'El usuario o contraseña ingresados son incorrectos.';
 $lang['minoredit']             = 'Cambios menores';
 $lang['draftdate']             = 'Borrador guardado automáticamente en';
+$lang['nosecedit']             = 'La página ha cambiado en el lapso, información de sección estuvo fuera de tiempo, en su lugar se cargó la página completa.';
 $lang['regmissing']            = 'Lo siento, tienes que completar todos los campos.';
 $lang['reguexists']            = 'Lo siento, el nombre de usuario ya existe.';
 $lang['regsuccess']            = 'El usuario ha sido creado. La contraseña se ha enviado por correo.';
@@ -79,8 +84,8 @@ $lang['regpwmail']             = 'Tu contraseña del DokuWiki';
 $lang['reghere']               = '¿No tienes cuenta todavía? Consigue una';
 $lang['profna']                = 'Este wiki no permite la modificación de datos de usuarios';
 $lang['profnochange']          = 'Sin cambios, nada que hacer.';
-$lang['profnoempty']           = 'No se permiten que el nombre o la dirección de correo electrónico estén vacios.';
-$lang['profchanged']           = 'Se actualizaron exitosamente los datos del usuario.';
+$lang['profnoempty']           = 'No se permite que el nombre o la dirección de correo electrónico estén vacíos.';
+$lang['profchanged']           = 'Se actualizaron correctamente los datos del usuario.';
 $lang['pwdforget']             = '¿Has olvidado tu contraseña? Consigue una nueva.';
 $lang['resendna']              = 'Este wiki no brinda la posibilidad de reenvío de contraseña.';
 $lang['resendpwd']             = 'Enviar una nueva contraseña para';
@@ -89,12 +94,14 @@ $lang['resendpwdnouser']       = 'Lo siento, no se encuentra este usuario en nue
 $lang['resendpwdbadauth']      = 'Lo siento, este código de autenticación no es válido. Asegúrate de haber usado el enlace de confirmación entero.';
 $lang['resendpwdconfirm']      = 'Un enlace para confirmación ha sido enviado por correo electrónico.';
 $lang['resendpwdsuccess']      = 'Tu nueva contraseña ha sido enviada por correo electrónico.';
+$lang['license']               = 'Excepto donde se indique lo contrario, el contenido de esta wiki se autoriza bajo la siguiente licencia:';
+$lang['licenseok']             = 'Nota: Al editar esta página, estás de acuerdo en autorizar su contenido bajo la siguiente licencia:';
 $lang['txt_upload']            = 'Selecciona el fichero a cargar';
 $lang['txt_filename']          = 'Subir como (opcional)';
 $lang['txt_overwrt']           = 'Sobreescribe el fichero existente';
 $lang['lockedby']              = 'Actualmente bloqueado por';
 $lang['lockexpire']            = 'El bloqueo expira en';
-$lang['willexpire']            = 'Tu bloqueo para editar esta página expira en un minuto.\nPara evitar confictos usa el botón previsualizar para reiniciar el contador de tiempo.';
+$lang['willexpire']            = 'Tu bloqueo para editar esta página expira en un minuto.\nPara evitar conflictos usa el botón previsualizar para reiniciar el contador de tiempo.';
 $lang['notsavedyet']           = 'Hay cambios que no se han guardado que se perderán.\n¿Quieres continuar?';
 $lang['rssfailed']             = 'Se ha producido un error leyendo datos (feed): ';
 $lang['nothingfound']          = 'No se ha encontrado nada.';
@@ -107,6 +114,7 @@ $lang['uploadexist']           = 'El fichero ya existe. No se ha hecho nada.';
 $lang['uploadbadcontent']      = 'El contenido de la subida no coincide con la extensión de fichero %s';
 $lang['uploadspam']            = 'La subida ha sido bloqueada por una lista negra de spam';
 $lang['uploadxss']             = 'La subida ha sido bloqueada por contenido posiblemente malicioso';
+$lang['uploadsize']            = 'El fichero subido es demasiado grande. (max. %s)';
 $lang['deletesucc']            = 'El fichero "%s" ha sido borrado.';
 $lang['deletefail']            = '"%s" no pudo ser borrado, verifique los permisos.';
 $lang['mediainuse']            = 'El fichero %s no ha sido borrado, aun está en uso.';
@@ -114,6 +122,9 @@ $lang['namespaces']            = 'Espacios de nombres';
 $lang['mediafiles']            = 'Ficheros disponibles en';
 $lang['js']['keepopen']        = 'Mantener esta ventana abierta durante la selección';
 $lang['js']['hidedetails']     = 'Ocultar detalles';
+$lang['js']['nosmblinks']      = 'Enlazar a recursos compartidos de Windows sólo funciona en Microsoft Internet Explorer.
+Lo que si puedes hacer es copiar y pegar el enlace.';
+$lang['js']['mu_btn']          = 'Subir varios archivos a la vez';
 $lang['mediausage']            = 'Use la siguiente sintaxis para hacer referencia a este fichero:';
 $lang['mediaview']             = 'Ver el fichero original';
 $lang['mediaroot']             = 'root';
@@ -122,7 +133,7 @@ $lang['mediaextchange']        = 'Extensión del fichero cambiada de .%s a .%s!'
 $lang['reference']             = 'Referencias para';
 $lang['ref_inuse']             = 'El fichero no ha podido ser borrado, porque se está usando en las siguientes páginas:';
 $lang['ref_hidden']            = 'Algunas referencias están en páginas en las que no tienes permisos para leer';
-$lang['hits']                  = 'Hits';
+$lang['hits']                  = 'Entradas';
 $lang['quickhits']             = 'Páginas que coinciden';
 $lang['toc']                   = 'Tabla de Contenidos';
 $lang['current']               = 'actual';
@@ -139,17 +150,17 @@ $lang['created']               = 'creado';
 $lang['restored']              = 'Se ha restaurado la vieja versión';
 $lang['external_edit']         = 'editor externo';
 $lang['summary']               = 'Edita el resumen';
+$lang['noflash']               = 'El <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a> es necesario para exibir este contenido.';
 $lang['mail_newpage']          = 'página añadida:';
 $lang['mail_changed']          = 'página cambiada:';
 $lang['mail_new_user']         = 'Nuevo usuario:';
 $lang['mail_upload']           = 'archivo subido:';
-$lang['nosmblinks']            = 'Enlazar a recursos compartidos de Windows sólo funciona en Microsoft Internet Explorer.\nTu puedes copiar y pegar el enlace.';
-$lang['qb_alert']              = 'Por favor, pega el texto al que quieres dar formato.\n Será agregado al final del documento.';
-$lang['qb_bold']               = 'Texto Negrita';
-$lang['qb_italic']             = 'Texto Itálica';
-$lang['qb_underl']             = 'Texto Subrayado';
-$lang['qb_code']               = 'Texto de Código';
-$lang['qb_strike']             = 'Texto tachado';
+$lang['qb_alert']              = 'Por favor, pega el texto al que quieres dar formato.\n Será añadido al final del documento.';
+$lang['qb_bold']               = 'Negrita';
+$lang['qb_italic']             = 'Itálica';
+$lang['qb_underl']             = 'Subrayado';
+$lang['qb_code']               = 'Código';
+$lang['qb_strike']             = 'tachado';
 $lang['qb_h1']                 = 'Título 1';
 $lang['qb_h2']                 = 'Título 2';
 $lang['qb_h3']                 = 'Título 3';
@@ -161,10 +172,10 @@ $lang['qb_hr']                 = 'Línea horizontal';
 $lang['qb_ol']                 = 'Ítem de Lista Ordenada';
 $lang['qb_ul']                 = 'Ítem de Lista Desordenada';
 $lang['qb_media']              = 'Añadir Imágenes u otros ficheros';
-$lang['qb_sig']                = 'Pon tu firma';
+$lang['qb_sig']                = 'Firmar';
 $lang['qb_smileys']            = 'Sonrisas';
 $lang['qb_chars']              = 'Caracteres especiales';
-$lang['del_confirm']           = '¿Quieres realmente borrar los ítem seleccionados?';
+$lang['del_confirm']           = '¿Quieres realmente borrar lo seleccionado?';
 $lang['admin_register']        = 'Añadir nuevo usuario...';
 $lang['metaedit']              = 'Editar los metadatos';
 $lang['metasaveerr']           = 'La escritura de los metadatos ha fallado';
@@ -175,36 +186,50 @@ $lang['img_caption']           = 'Epígrafe';
 $lang['img_date']              = 'Fecha';
 $lang['img_fname']             = 'Nombre de fichero';
 $lang['img_fsize']             = 'Tamaño';
-$lang['img_artist']            = 'Fotógrafo/Artista';
+$lang['img_artist']            = 'Fotógrafo';
 $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Cámara';
 $lang['img_keywords']          = 'Palabras claves';
-$lang['subscribe_success']     = '%s ha sido agregado a la lista de notificación de cambios de %s';
-$lang['subscribe_error']       = 'Ha habido un error al agregar a %s a la lista de notificación de cambios de %s';
+$lang['subscribe_success']     = '%s ha sido añadido a la lista de notificación de cambios de %s';
+$lang['subscribe_error']       = 'Ha habido un error al agregar %s a la lista de notificación de cambios de %s';
 $lang['subscribe_noaddress']   = 'No hay ninguna dirección de correo electrónico asociada con tu nombre de usuario, no puedes agregarte a la lista de notificación de cambios';
 $lang['unsubscribe_success']   = '%s ha sido eliminado a la lista de notificación de cambios de %s';
 $lang['unsubscribe_error']     = 'Ha habido un error al eliminar %s de la lista de notificación de cambios de %s';
-$lang['authmodfailed']         = 'Está mal configurada la autenticación de usuarios. Por favor, avisale al administrador del wiki.';
-$lang['authtempfail']          = 'La autenticación de usuarios no está disponible temporalmente. Si esta situación persiste, por favor, avisale al administrador del wiki.';
+$lang['authmodfailed']         = 'Está mal configurada la autenticación de usuarios. Por favor, avisa al administrador del wiki.';
+$lang['authtempfail']          = 'La autenticación de usuarios no está disponible temporalmente. Si esta situación persiste, por favor, avisa al administrador del wiki.';
 $lang['i_chooselang']          = 'Elija su idioma';
 $lang['i_installer']           = 'Instalador de DokuWiki';
 $lang['i_wikiname']            = 'Nombre del Wiki';
 $lang['i_enableacl']           = 'Habilitar ACL (recomendado) (ACL: lista de control de acceso)';
 $lang['i_superuser']           = 'Super-usuario';
 $lang['i_problems']            = 'El instalador encontró algunos problemas, se muestran abajo. No se puede continuar la instalación hasta que usted no los corrija.';
-$lang['i_modified']            = 'Por razones de seguridad este script sólo funcionará con una instalación nueva y no modificada de Dokuwiki. Usted deberá o bien extraer nuevamente los ficheros del paquete bajado o bien consultar las <a href="http://wiki.splitbrain.org/wiki:install">instrucciones de instalación de Dokuwiki</a> completas.';
+$lang['i_modified']            = 'Por razones de seguridad este script sólo funcionará con una instalación nueva y no modificada de Dokuwiki. Usted debe extraer nuevamente los ficheros del paquete bajado, o bien consultar las <a href="http://dokuwiki.org/install">instrucciones de instalación de Dokuwiki</a> completas.';
 $lang['i_funcna']              = 'La función de PHP <code>%s</code> no está disponible. Tal vez su proveedor de hosting la ha deshabilitado por alguna razón?';
 $lang['i_phpver']              = 'Su versión de PHP <code>%s</code> es menor que la necesaria <code>%s</code>. Es necesario que actualice su instalación de PHP.';
-$lang['i_permfail']            = '<code>%s</code> no es escribible por DokuWiki. Es necesario que usted establezca correctamente los permisos de este directorio!';
+$lang['i_permfail']            = 'DokuWili no puede escribir <code>%s</code>. Es necesario establecer  correctamente los permisos de este directorio!';
 $lang['i_confexists']          = '<code>%s</code> ya existe';
 $lang['i_writeerr']            = 'Imposible crear <code>%s</code>. Se necesita que usted controle los permisos del fichero/directorio y que cree el fichero manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php no reconocido o modificado (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - ilegal o valor vacío';
-$lang['i_success']             = 'La configuración ha concluido exitosamente. Usted ahora puede eliminar el archivo install.php. Siga a su <a href="doku.php">nueva instalación de DokuWiki</a>.';
+$lang['i_success']             = 'La configuración ha concluido correctamente. Usted ahora puede eliminar el archivo install.php. Continue con su <a href="doku.php">nueva instalación de DokuWiki</a>.';
 $lang['i_failure']             = 'Han ocurrido algunos errores durante la escritura de los ficheros de configuración. Usted puede corregirlos manualmente antes de poder usar su <a href="doku.php">nueva instalación de DokuWiki</a>.';
 $lang['i_policy']              = 'Política de ACL inicial';
 $lang['i_pol0']                = 'Wiki abierta (leer, escribir y subir archivos para todos)';
 $lang['i_pol1']                = 'Wiki pública (leer para todos, escribir y subir archivos para usuarios registrados únicamente)';
 $lang['i_pol2']                = 'Wiki cerrada (leer, escribir y subir archivos para usuarios registrados únicamente)';
 $lang['i_retry']               = 'Reintentar';
+$lang['mu_intro']              = 'Puedes subir varios archivos a la vez desde aquí. Pulsa el botón del navegador para agregarlos a la cola. Pulsa subir archivo para proceder.';
+$lang['mu_gridname']           = 'Nombre de archivo';
+$lang['mu_gridsize']           = 'Tamaño';
+$lang['mu_gridstat']           = 'Estado';
+$lang['mu_namespace']          = 'Espacio de nombres';
+$lang['mu_browse']             = 'Buscar';
+$lang['mu_toobig']             = 'demasiado grande';
+$lang['mu_ready']              = 'listo para subir';
+$lang['mu_done']               = 'completado';
+$lang['mu_fail']               = 'falló';
+$lang['mu_authfail']           = 'sesión caducada';
+$lang['mu_progress']           = '@PCT@% transferido';
+$lang['mu_filetypes']          = 'Tipos de archivos permitidos';
+$lang['recent_global']         = 'Actualmente estás viendo los cambios dentro del namespace <b>%s</b>. También puedes <a href="%s">ver los cambios recientes en la wiki completa</a>.';
