@@ -60,6 +60,7 @@ $lang['profile']               = 'Perfil de Usuario';
 $lang['badlogin']              = 'Sentímolo, pero o nome de usuario ou o contrasinal non son correctos.';
 $lang['minoredit']             = 'Trocos Menores';
 $lang['draftdate']             = 'Borrador gardado automaticamente en';
+$lang['nosecedit']             = 'A páxina mudou no entanto, a información da sección estaba desfasada polo que se cargou a páxina completa no seu lugar.';
 $lang['regmissing']            = 'Sentímolo, pero tes que cubrir todos os campos.';
 $lang['reguexists']            = 'Sentímolo, pero xa existe un usuario con ese nome.';
 $lang['regsuccess']            = 'O usuario foi creado e o contrasinal enviado por correo-e.';
@@ -81,6 +82,8 @@ $lang['resendpwdnouser']       = 'Sentímolo, non atopamos este usuario no noso
 $lang['resendpwdbadauth']      = 'Sentímolo, pero este código de autorización non é válido. Asegúrate de que usaches a ligazón completa de confirmación.';
 $lang['resendpwdconfirm']      = 'Enviouse unha ligazón de confirmación por correo-e.';
 $lang['resendpwdsuccess']      = 'O teu novo contrasinal foi enviado por correo-e.';
+$lang['license']               = 'O contido deste wiki, agás onde se indique o contrario, ofrécese baixo da seguinte licenza:';
+$lang['licenseok']             = 'Nota: Ao editares esta páxina aceptas licenciar o teu contido baixo da seguinte licenza:';
 $lang['txt_upload']            = 'Selecciona o arquivo a subir';
 $lang['txt_filename']          = 'Subir como (opcional)';
 $lang['txt_overwrt']           = 'Sobrescribir arquivo existente';
@@ -99,6 +102,7 @@ $lang['uploadexist']           = 'Xa existe o arquivo. Non se fixo nada.';
 $lang['uploadbadcontent']      = 'O contido subido non concorda coa extensión do arquivo %s.';
 $lang['uploadspam']            = 'A subida foi bloqueada pola lista negra de spam.';
 $lang['uploadxss']             = 'A subida foi bloqueada por posible contido malicioso.';
+$lang['uploadsize']            = 'O arquivo subido é grande de máis. (max %s)';
 $lang['deletesucc']            = 'O arquivo "%s" foi eliminado.';
 $lang['deletefail']            = '"%s" non puido ser eliminado - comproba os permisos.';
 $lang['mediainuse']            = 'O arquivo "%s" non foi eliminado - aínda está en uso.';
@@ -106,6 +110,9 @@ $lang['namespaces']            = 'Nomes de espazos';
 $lang['mediafiles']            = 'Arquivos dispoñibles en';
 $lang['js']['keepopen']        = 'Manter a xanela aberta na selección';
 $lang['js']['hidedetails']     = 'Agochar Pormenores';
+$lang['js']['nosmblinks']      = 'A ligazón aos compartidos do Windows só funciona no Microsoft Internet Explorer.
+Sempre podes copiar e colar a ligazón.';
+$lang['js']['mu_btn']          = 'Subir varios arquivos dunha vez';
 $lang['mediausage']            = 'Utilizar a seguinte sintaxe para referenciar este arquivo:';
 $lang['mediaview']             = 'Ver arquivo orixinal';
 $lang['mediaroot']             = 'raigaña';
@@ -131,11 +138,11 @@ $lang['created']               = 'creado';
 $lang['restored']              = 'revisión antiga restaurada';
 $lang['external_edit']         = 'edición externa';
 $lang['summary']               = 'Resumo da edición';
+$lang['noflash']               = 'Precísase o <a href="http://www.adobe.com/products/flashplayer/">Complemento Adobe Flash</a> para amosar este contido.';
 $lang['mail_newpage']          = 'páxina engadida:';
 $lang['mail_changed']          = 'páxina mudada:';
 $lang['mail_new_user']         = 'Novo usuario:';
 $lang['mail_upload']           = 'arquivo subido:';
-$lang['nosmblinks']            = 'A ligazón aos compartidos do Windows só funciona no Microsoft Internet Explorer.\nSempre podes copiar e colar a ligazón.';
 $lang['qb_alert']              = 'Por favor, insire o texto que queres formatear.\nSerá engadido ao remate do documento.';
 $lang['qb_bold']               = 'Texto Resaltado';
 $lang['qb_italic']             = 'Texto en Cursiva';
@@ -187,7 +194,7 @@ $lang['i_superuser']           = 'Super-usuario';
 $lang['i_problems']            = 'O instalador atopou algúns problemas amosados de seguido. Non poderás continuar ata que os soluciones.';
 $lang['i_modified']            = 'Por razóns de seguridade este script só funcionará cunha instalación nova e sen modificar do Dokuwiki.
                          Podes ou ben re-extraer os arquivos dende o paquete descargado ou consultar as
-                         <a href="http://wiki.splitbrain.org/wiki:install">instruccións completas de instalación do Dokuwiki</a>';
+                         <a href="http://dokuwiki.org/install">instruccións completas de instalación do Dokuwiki</a>';
 $lang['i_funcna']              = 'A función <code>%s</code> do PHP non está dispoñible. Pode que o teu provedor de hospedaxe a desactivase por algún motivo?';
 $lang['i_phpver']              = 'A túa versión <code>%s</code> do PHP é inferior á <code>%s</code> precisa. Debes actualizar a túa instalación do PHP.';
 $lang['i_permfail']            = '<code>%s</code> non é escribible polo DokuWiki. Debes corrixir a configuración de permisos deste directorio!';
@@ -204,3 +211,17 @@ $lang['i_pol0']                = 'Wiki Aberto (lectura, escritura, subida de arq
 $lang['i_pol1']                = 'Wiki Público (lectura para todo o mundo, escritura e subida de arquivos para usuarios rexistrados)';
 $lang['i_pol2']                = 'Wiki Pechado (lectura, escritura, subida de arquivos só para usuarios rexistrados)';
 $lang['i_retry']               = 'Probar de novo';
+$lang['mu_intro']              = 'Aquí podes subir varios arquivos dunha vez. Preme o botón navegar para engadilos á cola. Preme subir cando remates.';
+$lang['mu_gridname']           = 'Nome de arquivo';
+$lang['mu_gridsize']           = 'Tamaño';
+$lang['mu_gridstat']           = 'Estado';
+$lang['mu_namespace']          = 'Nome de espazo';
+$lang['mu_browse']             = 'Navegar';
+$lang['mu_toobig']             = 'demasiado grande';
+$lang['mu_ready']              = 'listo para subir';
+$lang['mu_done']               = 'completo';
+$lang['mu_fail']               = 'fallou';
+$lang['mu_authfail']           = 'sesión expirada';
+$lang['mu_progress']           = '@PCT@% subido';
+$lang['mu_filetypes']          = 'Tipos de arquivo Permitidos';
+$lang['recent_global']         = 'Agora mesmo estás a ver os trocos no nome de espazo <b>%s</b>. Tamén podes <a href="%s">ver os trocos recentes no wiki enteiro</a>.';
