@@ -8,6 +8,8 @@
  * @author Silvia Sargentoni <polinnia@tin.it>
  * @author Diego Pierotto <ita.translations@tiscali.it>
  * @author Diego Pierotto ita.translations@tiscali.it
+ * @author ita.translations@tiscali.it
+ * @author Lorenzo Breda <lbreda@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -64,6 +66,7 @@ $lang['profile']               = 'Profilo utente';
 $lang['badlogin']              = 'Il nome utente o la password non sono validi.';
 $lang['minoredit']             = 'Modifiche minori';
 $lang['draftdate']             = 'Bozza salvata in automatico il';
+$lang['nosecedit']             = 'La pagina nel frattempo è cambiata, la sezione info è scaduta, caricata invece la pagina intera.';
 $lang['regmissing']            = 'Devi riempire tutti i campi.';
 $lang['reguexists']            = 'Il nome utente inserito esiste già .';
 $lang['regsuccess']            = 'L\'utente è stato creato. La password è stata spedita via e-mail.';
@@ -85,6 +88,8 @@ $lang['resendpwdnouser']       = 'Impossibile trovare questo utente nel database
 $lang['resendpwdbadauth']      = 'Spiacente, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
 $lang['resendpwdconfirm']      = 'Un link di conferma è stato spedito via email.';
 $lang['resendpwdsuccess']      = 'La nuova password è stata spedita via email.';
+$lang['license']               = 'Ad eccezione da dove è diversamente indicato, il contenuto di questo wiki è sotto la seguente licenza:';
+$lang['licenseok']             = 'Nota: modificando questa pagina accetti di rilasciare il contenuto sotto la seguente licenza:';
 $lang['txt_upload']            = 'Seleziona un file da caricare';
 $lang['txt_filename']          = 'Inserisci un "wikiname" (opzionale)';
 $lang['txt_overwrt']           = 'Sovrascrivi file esistente';
@@ -103,6 +108,7 @@ $lang['uploadexist']           = 'Il file esiste già . Invio annullato.';
 $lang['uploadbadcontent']      = 'Il contenuto caricato non corrisponde all\'estensione del file %s.';
 $lang['uploadspam']            = 'Il caricamento è stato bloccato dalla lista nera di spam.';
 $lang['uploadxss']             = 'Il caricamento è stato bloccato perchè il contenuto potrebbe essere malizioso.';
+$lang['uploadsize']            = 'Il file caricato è troppo grande. (massimo %s)';
 $lang['deletesucc']            = 'Il file "%s" è stato cancellato.';
 $lang['deletefail']            = '"%s" non può essere cancellato - verifica i permessi.';
 $lang['mediainuse']            = 'Il file "%s" non è stato cancellato - è ancora in uso.';
@@ -110,6 +116,9 @@ $lang['namespaces']            = 'Categorie';
 $lang['mediafiles']            = 'File disponibili in';
 $lang['js']['keepopen']        = 'Tieni la finestra aperta durante la selezione';
 $lang['js']['hidedetails']     = 'Nascondi Dettagli';
+$lang['js']['nosmblinks']      = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.
+Puoi fare un copia/incolla di questo collegamento.';
+$lang['js']['mu_btn']          = 'Carica più di un file alla volta';
 $lang['mediausage']            = 'Usa la seguente sintassi per riferirti a questo file:';
 $lang['mediaview']             = 'Mostra file originale';
 $lang['mediaroot']             = 'directory principale';
@@ -135,11 +144,11 @@ $lang['created']               = 'creata';
 $lang['restored']              = 'versione precedente ripristinata';
 $lang['external_edit']         = 'modifica esterna';
 $lang['summary']               = 'Oggetto della modifica';
+$lang['noflash']               = 'E\' necessario <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> per visualizzare questo contenuto.';
 $lang['mail_newpage']          = 'pagina aggiunta:';
 $lang['mail_changed']          = 'pagina modificata:';
 $lang['mail_new_user']         = 'Nuovo utente:';
 $lang['mail_upload']           = 'file caricato:';
-$lang['nosmblinks']            = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.\nPuoi fare un copia/incolla di questo collegamento.';
 $lang['qb_alert']              = 'Puoi inserire il testo che vuoi formattare.\nSarà  aggiunto alla fine del documento.';
 $lang['qb_bold']               = 'Grassetto';
 $lang['qb_italic']             = 'Corsivo';
@@ -191,7 +200,7 @@ $lang['i_superuser']           = 'Amministratore';
 $lang['i_problems']            = 'Si sono verificati problemi durante l\'installazione, indicati di seguito. Non è possibile continuare finché non saranno risolti.';
 $lang['i_modified']            = 'Per motivi di sicurezza questa procedura funziona solamente con un\'installazione Dokuwiki nuova e non modificata.
                          Dovresti ri-estrarre i file dal pacchetto scaricato oppure consultare tutte le
-                         <a href="http://wiki.splitbrain.org/wiki:install">istruzioni per l\'installazione di Dokuwiki</a>';
+                         <a href="http://dokuwiki.org/install">istruzioni per l\'installazione di Dokuwiki</a>';
 $lang['i_funcna']              = 'La funzione PHP <code>%s</code> non è disponibile. Forse il tuo provider l\'ha disabilitata per qualche motivo?';
 $lang['i_phpver']              = 'La versione di PHP <code>%s</code> è inferiore a quella richiesta <code>%s</code>. Devi aggiornare l\'installazione di PHP.';
 $lang['i_permfail']            = 'DokuWiki non può scrivere <code>%s</code>. E\' necessario correggere i permessi per questa directory!';
@@ -207,3 +216,17 @@ $lang['i_pol0']                = 'Wiki Aperto (lettura, scrittura, caricamento f
 $lang['i_pol1']                = 'Wiki Pubblico (lettura per tutti, scrittura e caricamento file per gli utenti registrati)';
 $lang['i_pol2']                = 'Wiki Chiuso (lettura, scrittura, caricamento file solamente per gli utenti registrati)';
 $lang['i_retry']               = 'Riprova';
+$lang['mu_intro']              = 'Qui si possono caricare più di un file alla volta. Cliccare su "Sfoglia..." per aggiungere i file in coda. Cliccare "Carica" quando si è pronti.';
+$lang['mu_gridname']           = 'Nome del file';
+$lang['mu_gridsize']           = 'Dimensione';
+$lang['mu_gridstat']           = 'Stato';
+$lang['mu_namespace']          = 'Namespace';
+$lang['mu_browse']             = 'Sfoglia...';
+$lang['mu_toobig']             = 'troppo grande';
+$lang['mu_ready']              = 'pronto per l\'upload';
+$lang['mu_done']               = 'completo';
+$lang['mu_fail']               = 'fallito';
+$lang['mu_authfail']           = 'sessione scaduta';
+$lang['mu_progress']           = '@PCT@% caricato';
+$lang['mu_filetypes']          = 'Tipi di file permessi';
+$lang['recent_global']         = 'Stai attualmente vedendo le modifiche dentro l\'area <b>%s</b>. Puoi anche <a href="%s">vedere le modifiche recenti dell\'intero wiki</a>.';
