@@ -60,6 +60,7 @@ $lang['profile']               = 'Lietotāja vārds';
 $lang['badlogin']              = 'Atvaino, lietotājvārds vai parole aplama.';
 $lang['minoredit']             = 'Sīki labojumi';
 $lang['draftdate']             = 'Melnraksts automātiski saglabāts';
+$lang['nosecedit']             = 'Lapa pa šo laiku ir mainījusies, sekcijas informācija novecojusi. Ielādēta lapas  pilnās versija.';
 $lang['regmissing']            = 'Atvaino, jāaizpilda visas ailes.';
 $lang['reguexists']            = 'Atvaino, tāds lietotājs jau ir.';
 $lang['regsuccess']            = 'Lietotājs izveidots. Parole nosūtīta pa pastu.';
@@ -81,6 +82,8 @@ $lang['resendpwdnouser']       = 'Atvaino, tāda lietotāja nav.';
 $lang['resendpwdbadauth']      = 'Atvaino, šis autorizācijas kods nav derīgs. Pārliecinies, ka lietoji pilnu apstiprināšanas adresi.';
 $lang['resendpwdconfirm']      = 'Apstiprināšanas adrese nosūtīta pa epastu.';
 $lang['resendpwdsuccess']      = 'Jaunā parole nosūtīta pa e-pastu.';
+$lang['license']               = 'Ja nav norādīts citādi, viki saturs pieejams ar šādas licenzes  noteikumiem:';
+$lang['licenseok']             = 'Ievēro: Labojot lapu, tu piekrīti šādiem licenzes noteikumiem.';
 $lang['txt_upload']            = 'Norādi augšupielādējamo failu';
 $lang['txt_filename']          = 'Ievadi wikivārdu (nav obligāts)';
 $lang['txt_overwrt']           = 'Aizstāt esošo failu';
@@ -99,6 +102,7 @@ $lang['uploadexist']           = 'Neko nedarīju, jo fails jau ir.';
 $lang['uploadbadcontent']      = 'Augšupielādētā saturs neatbilst faila paplašinājumam %s.';
 $lang['uploadspam']            = 'Augšupielāde bloķēta ar melno sarakstu.';
 $lang['uploadxss']             = 'Augšupielāde bloķēta iespējama slikta satura dēļ.';
+$lang['uploadsize']            = 'Augšup lādētais fails pārāk liels. Maksimums ir  %s.';
 $lang['deletesucc']            = 'Fails "%s" dzēsts.';
 $lang['deletefail']            = 'Nevar dzēst "%s". Pārbaudi tiesības.';
 $lang['mediainuse']            = 'Fails "%s" nav izdzēsts, to lieto.';
@@ -106,10 +110,13 @@ $lang['namespaces']            = 'Nodaļas';
 $lang['mediafiles']            = 'Pieejamie faili';
 $lang['js']['keepopen']        = 'Pēc faila izvēles logu paturēt atvērtu';
 $lang['js']['hidedetails']     = 'Slēpt detaļas';
+$lang['js']['nosmblinks']      = 'Saites uz Windows resursiem darbojas tikai Microsoft Internet Explorer.
+Protams, ka vari saiti kopēt un iespraust citā programmā.';
+$lang['js']['mu_btn']          = 'Augšuplādēt uzreiz vairākus failus.';
 $lang['mediausage']            = 'Atsaucei uz failu lietot šādu sintaksi:';
 $lang['mediaview']             = 'Skatīt oriģinālo failu';
 $lang['mediaroot']             = 'sakne';
-$lang['mediaupload']           = 'Augšupielādēt failu patreizējā sadaļā. Lai izveidotu dziļāku sadaļu, pieraksti to, atdalot ar kolu, pirms augšupielādējamā faila vārda.';
+$lang['mediaupload']           = 'Augšupielādēt failu patreizējā nodaļā. Lai izveidotu apakšnodaļu, pieraksti to, atdalot ar kolu, pirms augšupielādējamā faila vārda.';
 $lang['mediaextchange']        = 'Faila paplašinājums mainīts no .%s uz .%s!';
 $lang['reference']             = 'Norādes uz failu';
 $lang['ref_inuse']             = 'Failu nevar dzēst, jo izmanto šādas lapas:';
@@ -131,11 +138,11 @@ $lang['created']               = 'izveidots';
 $lang['restored']              = 'vecā versija atjaunota';
 $lang['external_edit']         = 'ārpussistēmas labojums';
 $lang['summary']               = 'Anotācija';
+$lang['noflash']               = 'Lai attēlotu lapas saturu, vajag <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['mail_newpage']          = 'lapa pievienota:';
 $lang['mail_changed']          = 'lapa mainīta:';
 $lang['mail_new_user']         = 'Jauns lietotājs:';
 $lang['mail_upload']           = 'augšupielādētais fails:';
-$lang['nosmblinks']            = 'Saites uz Windows resursiem darbojas tikai Microsoft Internet Explorer.\nProtams, ka vari saiti kopēt un iespraust citā programmā.';
 $lang['qb_alert']              = 'Lūdzu ieraksti formatējamo teku.\nTo pievienos dokumenta galā.';
 $lang['qb_bold']               = 'Trekninājums';
 $lang['qb_italic']             = 'Kursīvs';
@@ -186,8 +193,8 @@ $lang['i_enableacl']           = 'Lietot ACL (ieteikts)';
 $lang['i_superuser']           = 'Superuser';
 $lang['i_problems']            = 'Instalētājs atrada zemāk minētās problēmas. Kamēr tās nenovērš, nav iespējam turpināt.';
 $lang['i_modified']            = 'Drošības nolūkos šis skripts darbosies tika ar jaunu nemodificētu Dokuwiki instalāciju.
-                         Vai nu no jauna jāatarhifē fail ino lejupielādētās pakas vai jāraugās pēc padoma pilnā Dokuwiki instalācijas instrukcijā 
-                         <a href="http://wiki.splitbrain.org/wiki:install"></a>';
+                         Vai nu no jauna jāatarhivē faili no lejupielādētās pakas vai jāraugās pēc padoma pilnā Dokuwiki instalācijas instrukcijā 
+                         <a href="http://dokuwiki.org/install"></a>';
 $lang['i_funcna']              = 'PHP funkcija <code>%s</code> nav pieejama. Varbūt jūsu servera īpašnieks to kāda iemesla dēļ atslēdzis?';
 $lang['i_phpver']              = 'Jūsu PHP versija <code>%s</code> ir par vecu. Vajag versiju <code>%s</code>. Atjaunojiet savu PHP instalāciju.';
 $lang['i_permfail']            = 'Dokuwiki nevar ierakstīt <code>%s</code>. Jālabo direktorijas tiesības!';
@@ -203,3 +210,17 @@ $lang['i_pol0']                = 'Atvērts Wiki (raksta, lasa un augšupielādē
 $lang['i_pol1']                = 'Publisks Wiki (lasa ikviens, raksta un augšupielādē reģistrēti lietotāji)';
 $lang['i_pol2']                = 'Slēgts Wiki (raksta, lasa un augšupielādē tikai reģistrēti lietotāji)';
 $lang['i_retry']               = 'Atkārtot';
+$lang['mu_intro']              = 'Šeit var augšupielādēt uzreiz vairāku failus. Uzklikšķini Pārlūkot pogai, lai tos ieliktu rindā. Nospied Augšupielādēt, kad rinda sastādīta.';
+$lang['mu_gridname']           = 'Faila vārds';
+$lang['mu_gridsize']           = 'Izmērs';
+$lang['mu_gridstat']           = 'Statuss';
+$lang['mu_namespace']          = 'Nodaļa';
+$lang['mu_browse']             = 'Pārlūkot';
+$lang['mu_toobig']             = 'par lielu';
+$lang['mu_ready']              = 'gatavs augšupielādei';
+$lang['mu_done']               = 'pabeigts';
+$lang['mu_fail']               = 'neizdevās';
+$lang['mu_authfail']           = 'sesijas laiks iztecējis';
+$lang['mu_progress']           = '@PCT@% augšupielādēts';
+$lang['mu_filetypes']          = 'Atļautie failu tipi';
+$lang['recent_global']         = 'Tu skati izmaiņas nodaļā <b>%s</b>. Ir iespējams <a href="%s">skatīt jaunākos grozījums visā viki</a>. ';
