@@ -9,6 +9,7 @@
  * @author Koen Huybrechts <huybkoen@gmail.com>
  * @author Wouter Schoot <wouter@schoot.org>
  * @author John de Graaff <john@de-graaff.net>
+ * @author Dion Nicolaas <dion@nicolaas.net>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -18,7 +19,7 @@ $lang['singlequoteopening']    = '‚';
 $lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '\'';
 $lang['btn_edit']              = 'Pagina aanpassen';
-$lang['btn_source']            = 'Toon pagina broncode';
+$lang['btn_source']            = 'Toon broncode';
 $lang['btn_show']              = 'Toon pagina';
 $lang['btn_create']            = 'Maak deze pagina aan';
 $lang['btn_search']            = 'Zoeken';
@@ -40,12 +41,12 @@ $lang['btn_update']            = 'Bijwerken';
 $lang['btn_delete']            = 'Verwijder';
 $lang['btn_back']              = 'Terug';
 $lang['btn_backlink']          = 'Referenties';
-$lang['btn_backtomedia']       = 'Terug naar Bestand selectie';
-$lang['btn_subscribe']         = 'Volg wijzigingen';
-$lang['btn_unsubscribe']       = 'Stop volgen wijzigingen';
-$lang['btn_subscribens']       = 'Inschrijven Namespace Veranderingen';
-$lang['btn_unsubscribens']     = 'Uitschrijven Namespace Veranderingen';
-$lang['btn_profile']           = 'Profiel Aanpassen';
+$lang['btn_backtomedia']       = 'Terug naar Bestandsselectie';
+$lang['btn_subscribe']         = 'Inschrijven wijzigingen';
+$lang['btn_unsubscribe']       = 'Opzeggen wijzigingen';
+$lang['btn_subscribens']       = 'Inschrijven namespace-wijzigingen';
+$lang['btn_unsubscribens']     = 'Opzeggen namespace-wijzigingen';
+$lang['btn_profile']           = 'Profiel aanpassen';
 $lang['btn_reset']             = 'Wissen';
 $lang['btn_resendpwd']         = 'Stuur een nieuw wachtwoord';
 $lang['btn_draft']             = 'Bewerk concept';
@@ -65,11 +66,12 @@ $lang['profile']               = 'Gebruikersprofiel';
 $lang['badlogin']              = 'Sorry, gebruikersnaam of wachtwoord onjuist';
 $lang['minoredit']             = 'Kleine wijziging';
 $lang['draftdate']             = 'Concept automatisch opgeslagen op';
-$lang['regmissing']            = 'Vul al de velden in';
+$lang['nosecedit']             = 'De pagina is tussentijds veranderd, sectie informatie was verouderd, volledige pagina geladen.';
+$lang['regmissing']            = 'Vul alle velden in';
 $lang['reguexists']            = 'Er bestaat al een gebruiker met deze loginnaam.';
 $lang['regsuccess']            = 'De gebruiker is aangemaakt. Het wachtwoord is per e-mail verzonden.';
 $lang['regsuccess2']           = 'De gebruiker is aangemaakt.';
-$lang['regmailfail']           = 'Het lijkt erop dat het sturen van de wachtwoordmail mislukt is. Neem a.u.b. contact op met de beheerder!';
+$lang['regmailfail']           = 'Het lijkt erop dat het sturen van de wachtwoordmail mislukt is. Neem contact op met de beheerder!';
 $lang['regbadmail']            = 'Het opgegeven e-mailadres lijkt ongeldig - als je denkt dat dit niet klopt neem dan contact op met de beheerder.';
 $lang['regbadpass']            = 'De twee ingevoerde wachtwoorden zijn niet identiek. Probeer het nog eens.';
 $lang['regpwmail']             = 'Je DokuWiki wachtwoord';
@@ -79,31 +81,34 @@ $lang['profnochange']          = 'Geen wijzigingen, niets gedaan';
 $lang['profnoempty']           = 'Een lege gebruikersnaam of e-mailadres is niet toegestaan';
 $lang['profchanged']           = 'Gebruikersprofiel succesvol aangepast';
 $lang['pwdforget']             = 'Je wachtwoord vergeten? Vraag een nieuw wachtwoord aan';
-$lang['resendna']              = 'Deze wiki ondersteunt niet het verzenden van wachtwoorden';
+$lang['resendna']              = 'Deze wiki ondersteunt het verzenden van wachtwoorden niet';
 $lang['resendpwd']             = 'Stuur een nieuw wachtwoord voor';
-$lang['resendpwdmissing']      = 'Sorry, je moet alle velden invullen';
-$lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vinden in onze database';
-$lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of u de volledige bevestigings-link gebruikt.';
-$lang['resendpwdconfirm']      = 'Een bevestigings-link is verzonden per e-mail';
-$lang['resendpwdsuccess']      = 'Je nieuwe wachtwoord is per e-mail verzonden';
+$lang['resendpwdmissing']      = 'Sorry, je moet alle velden invullen.';
+$lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vinden in onze database.';
+$lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of je de volledige bevestigings-link hebt gebruikt.';
+$lang['resendpwdconfirm']      = 'Een bevestigingslink is per e-mail verzonden.';
+$lang['resendpwdsuccess']      = 'Je nieuwe wachtwoord is per e-mail verzonden.';
+$lang['license']               = 'Tenzij anders vermeld, inhoud van deze wiki is voorzien van de volgende licentie:';
+$lang['licenseok']             = 'Let op: Door deze pagina aan te passen ga je akkoord met het licenseren van de inhoud onder de volgende licentie:';
 $lang['txt_upload']            = 'Selecteer een bestand om te uploaden';
-$lang['txt_filename']          = 'Vul wiki-naam in (optioneel)';
+$lang['txt_filename']          = 'Vul nieuwe naam in (optioneel)';
 $lang['txt_overwrt']           = 'Overschrijf bestaand bestand';
 $lang['lockedby']              = 'Momenteel in gebruik door';
 $lang['lockexpire']            = 'Exclusief gebruiksrecht vervalt op';
-$lang['willexpire']            = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nOm problemen te voorkomen klik op de Voorbeeld knop om de exclusieve gebruiksrechten te verlengen.';
-$lang['notsavedyet']           = 'Er zijn op dit moment wijzigingen die nog niet zijn opgeslagen, deze zullen verloren gaan.\nWeet je zeker dat je wilt doorgaan?';
+$lang['willexpire']            = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
+$lang['notsavedyet']           = 'Nog niet bewaarde wijzigingen zullen verloren gaan.\nWeet je zeker dat je wilt doorgaan?';
 $lang['rssfailed']             = 'Er is een fout opgetreden bij het ophalen van de feed: ';
 $lang['nothingfound']          = 'Er werd niets gevonden.';
-$lang['mediaselect']           = 'Bestand selectie';
-$lang['fileupload']            = 'Bestand upload';
+$lang['mediaselect']           = 'Bestandsselectie';
+$lang['fileupload']            = 'Bestandsupload';
 $lang['uploadsucc']            = 'Upload geslaagd';
 $lang['uploadfail']            = 'Upload mislukt. Misschien verkeerde permissies?';
-$lang['uploadwrong']           = 'Upload mislukt. Deze file-extensie is verboden';
+$lang['uploadwrong']           = 'Upload mislukt. Deze bestandsextensie is verboden!';
 $lang['uploadexist']           = 'Bestand bestaat reeds. Er is niets gewijzigd.';
-$lang['uploadbadcontent']      = 'Het geüploade bestand voldoet niet aan de %s bestandsextensie.';
+$lang['uploadbadcontent']      = 'Het geüploade bestand heeft niet de bestandsextensie %s.';
 $lang['uploadspam']            = 'De upload is geblokkeerd door de spam blacklist.';
 $lang['uploadxss']             = 'De upload is geblokkeerd wegens mogelijk onveilige inhoud.';
+$lang['uploadsize']            = 'Het geüploade bestand is te groot. (max. %s)';
 $lang['deletesucc']            = 'Het bestand "%s" is verwijderd.';
 $lang['deletefail']            = '"%s" kan niet worden verwijderd - controleer permissies.';
 $lang['mediainuse']            = 'Het bestand "%s" is niet verwijderd - het is nog in gebruik.';
@@ -111,23 +116,26 @@ $lang['namespaces']            = 'Namespaces';
 $lang['mediafiles']            = 'Beschikbare bestanden in';
 $lang['js']['keepopen']        = 'Houd scherm open bij selectie';
 $lang['js']['hidedetails']     = 'Verberg details';
-$lang['mediausage']            = 'Gebruik de volgende syntax om aan het bestand te refereren';
+$lang['js']['nosmblinks']      = 'Linken naar Windows shares werkt alleen in Microsoft Internet Explorer.
+Je kan de link wel kopiëren en plakken.';
+$lang['js']['mu_btn']          = 'Meerdere files tegelijk uploaden';
+$lang['mediausage']            = 'Gebruik de volgende syntax om aan het bestand te refereren:';
 $lang['mediaview']             = 'Bekijk het orginele bestand';
 $lang['mediaroot']             = 'root';
-$lang['mediaupload']           = 'Upload een bestand naar de huidige namespace. Om een subnamespace aan te maken, voegt u bij het "Upload als" veld een namespace in, gescheiden met dubbele-punten.';
+$lang['mediaupload']           = 'Upload een bestand naar de huidige namespace. Om een subnamespace aan te maken, laat je die voorafgaan aan de bestandsnaam bij "Upload als", gescheiden door een dubbele punt.';
 $lang['mediaextchange']        = 'Bestandsextensie veranderd van .%s naar .%s!';
 $lang['reference']             = 'Referenties voor';
-$lang['ref_inuse']             = 'Het bestand kan niet worden verwijderd, omdat het nog in gebruik is op de volgende pagina\'s:';
-$lang['ref_hidden']            = 'Enkele referenties staan op pagina\'s waarvoor je geen lees permissie hebt';
+$lang['ref_inuse']             = 'Het bestand kan niet worden verwijderd omdat het nog in gebruik is op de volgende pagina\'s:';
+$lang['ref_hidden']            = 'Enkele referenties staan op pagina\'s waarvoor je geen leesrechten hebt';
 $lang['hits']                  = 'Hits';
-$lang['quickhits']             = 'Overeenkomende pagina namen';
-$lang['toc']                   = 'Inhoudsopgave';
+$lang['quickhits']             = 'Overeenkomende paginanamen';
+$lang['toc']                   = 'Inhoud';
 $lang['current']               = 'huidige';
 $lang['yours']                 = 'Jouw versie';
 $lang['diff']                  = 'Toon verschillen met huidige revisie';
 $lang['diff2']                 = 'Toon verschillen tussen geselecteerde revisies';
 $lang['line']                  = 'Regel';
-$lang['breadcrumb']            = 'Pad historie';
+$lang['breadcrumb']            = 'Spoor';
 $lang['youarehere']            = 'Je bent hier';
 $lang['lastmod']               = 'Laatst gewijzigd';
 $lang['by']                    = 'door';
@@ -135,12 +143,12 @@ $lang['deleted']               = 'verwijderd';
 $lang['created']               = 'aangemaakt';
 $lang['restored']              = 'oude revisie hersteld';
 $lang['external_edit']         = 'Externe bewerking';
-$lang['summary']               = 'Samenvatting aanpassen';
+$lang['summary']               = 'Samenvatting wijziging';
+$lang['noflash']               = 'De <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> is vereist om de pagina te kunnen weergeven.';
 $lang['mail_newpage']          = 'pagina toegevoegd:';
 $lang['mail_changed']          = 'pagina aangepast:';
 $lang['mail_new_user']         = 'nieuwe gebruiker:';
 $lang['mail_upload']           = 'bestand geüpload:';
-$lang['nosmblinks']            = 'Linken naar Windows shares werkt alleen in Microsoft Internet Explorer.\nJe kan de link wel kopiëren en plakken.';
 $lang['qb_alert']              = 'Voer de tekst in die je wilt opmaken.\nDe tekst wordt toegevoegd aan het eind van het document.';
 $lang['qb_bold']               = 'Vette tekst';
 $lang['qb_italic']             = 'Cursieve tekst';
@@ -155,17 +163,17 @@ $lang['qb_h5']                 = 'Niveau 5 kop';
 $lang['qb_link']               = 'Interne link';
 $lang['qb_extlink']            = 'Externe link';
 $lang['qb_hr']                 = 'Horizontale lijn';
-$lang['qb_ol']                 = 'Geordende lijst item';
-$lang['qb_ul']                 = 'Ongeordende lijst item';
+$lang['qb_ol']                 = 'Geordende lijst';
+$lang['qb_ul']                 = 'Ongeordende lijst';
 $lang['qb_media']              = 'Voeg plaatjes en andere bestanden toe';
 $lang['qb_sig']                = 'Handtekening invoegen';
 $lang['qb_smileys']            = 'Smileys';
 $lang['qb_chars']              = 'Speciale tekens';
-$lang['del_confirm']           = 'Dit item verwijderen?';
+$lang['del_confirm']           = 'Item(s) verwijderen?';
 $lang['admin_register']        = 'Nieuwe gebruiker toevoegen';
-$lang['metaedit']              = 'Edit Metadata';
-$lang['metasaveerr']           = 'Writing metadata failed';
-$lang['metasaveok']            = 'Metadata saved';
+$lang['metaedit']              = 'Metadata wijzigen';
+$lang['metasaveerr']           = 'Schrijven van metadata mislukt';
+$lang['metasaveok']            = 'Metadata bewaard';
 $lang['img_backto']            = 'Terug naar';
 $lang['img_title']             = 'Titel';
 $lang['img_caption']           = 'Bijschrift';
@@ -179,29 +187,43 @@ $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Trefwoorden';
 $lang['subscribe_success']     = '%s toegevoegd aan de lijst voor %s';
 $lang['subscribe_error']       = 'Fout bij toevoegen van %s aan de lijst voor %s';
-$lang['subscribe_noaddress']   = 'Er is geen adres dat overeenkomt met uw login, u kan niet toegevoegd worden aan de lijst';
+$lang['subscribe_noaddress']   = 'Er is geen adres dat overeenkomt met je login, je kan niet toegevoegd worden aan de lijst';
 $lang['unsubscribe_success']   = '%s verwijderd van de lijst voor %s';
 $lang['unsubscribe_error']     = 'Fout bij verwijderen van %s van de lijst voor %s';
-$lang['authmodfailed']         = 'Ongeldige gebruikers authenticatie configuratie. Informeer uw Wiki Beheerder.';
-$lang['authtempfail']          = 'Gebruikers authenticatie is tijdelijk niet beschikbaar. Als deze situatie zich voort blijft doen, informeer dan uw Wiki Beheerder.';
-$lang['i_chooselang']          = 'Kies uw taal';
+$lang['authmodfailed']         = 'Ongeldige gebruikersauthenticatie-configuratie. Informeer de wikibeheerder.';
+$lang['authtempfail']          = 'Gebruikersauthenticatie is tijdelijk niet beschikbaar. Als deze situatie zich blijft voordoen, informeer dan de wikibeheerder.';
+$lang['i_chooselang']          = 'Kies je taal';
 $lang['i_installer']           = 'DokuWiki Installer';
-$lang['i_wikiname']            = 'Wiki naam';
+$lang['i_wikiname']            = 'Wikinaam';
 $lang['i_enableacl']           = 'ACLs inschakelen (aanbevolen)';
 $lang['i_superuser']           = 'Superuser';
-$lang['i_problems']            = 'De installer vond verscheidene problemen, hieronder aangegeven. U dient deze te verhelpen alvorens u door kunt gaan.';
-$lang['i_modified']            = 'Wegens veiligheidsoverwegingen werkt dit script alleen met nieuwe en onaangepaste Dokuwiki installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki installatie instructies</a>';
-$lang['i_funcna']              = 'PHP functie <code>%s</code> is niet beschikbaar. Wellicht heeft uw hosting provder deze uitgeschakeld?';
-$lang['i_phpver']              = 'Uw PHP versie <code>%s</code> is lager dan de vereiste <code>%s</code>. U dient PHP te upgraden.';
-$lang['i_permfail']            = '<code>%s</code> is niet schrijfbaar voor DokuWiki. U dient de permissieinstellingen van deze directory aan te passen.';
+$lang['i_problems']            = 'De installer vond problemen, hieronder aangegeven. Verhelp deze voor je doorgaat.';
+$lang['i_modified']            = 'Uit veiligheidsoverwegingen werkt dit script alleen met nieuwe en onveranderde DokuWiki-installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki installatie-instructies</a>';
+$lang['i_funcna']              = 'PHP functie <code>%s</code> is niet beschikbaar. Wellicht heeft je hosting provider deze uitgeschakeld?';
+$lang['i_phpver']              = 'PHP-versie <code>%s</code> is lager dan de vereiste <code>%s</code>. Upgrade PHP.';
+$lang['i_permfail']            = '<code>%s</code> is niet schrijfbaar voor DokuWiki. Pas de permissie-instellingen van deze directory aan.';
 $lang['i_confexists']          = '<code>%s</code> bestaat reeds';
-$lang['i_writeerr']            = 'Niet mogelijk om <code>%s</code> aante maken. U dient de directory/bestands permissies te controleren en de file handmatig aan te maken.';
+$lang['i_writeerr']            = 'Niet mogelijk om <code>%s</code> aan te maken. Controleer de directory/bestandspermissies en maak het bestand handmatig aan.';
 $lang['i_badhash']             = 'Onbekende of aangepaste dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - onjuiste of lege waarde';
-$lang['i_success']             = 'De configuratie is succesvol afgerond. U kunt nu het bestand install.php verwijderen. Ga naar <a href="doku.php">uw nieuwe DokuWiki</a>.';
-$lang['i_failure']             = 'Enkele fouten deden zich voor tijdens het schrijven naar de configuratie bestanden. U zult deze dienen aan te passen alvorens u gebruik kunt maken van <a href="doku.php">uw nieuwe DokuWiki</a>.';
-$lang['i_policy']              = 'Initieel ACL beleid';
-$lang['i_pol0']                = 'Open Wiki (lezen, schrijven, uploaden voor iedereen)';
-$lang['i_pol1']                = 'Publieke Wiki (lezen voor iedereen, schrijven en uploaden voor geregistreerde gebruikers)';
-$lang['i_pol2']                = 'Besloten Wiki (lezen, schrijven en uploaden alleen voor geregistreerde gebruikers)';
+$lang['i_success']             = 'De configuratie is succesvol afgerond. Je kunt nu het bestand install.php verwijderen. Ga naar <a href="doku.php">je nieuwe DokuWiki</a>.';
+$lang['i_failure']             = 'Fouten deden zich voor tijdens het schrijven naar de configuratiebestanden. Pas deze aan voor je gebruik kunt maken van <a href="doku.php">je nieuwe DokuWiki</a>.';
+$lang['i_policy']              = 'Initieel ACL-beleid';
+$lang['i_pol0']                = 'Open wiki (lezen, schrijven, uploaden voor iedereen)';
+$lang['i_pol1']                = 'Publieke wiki (lezen voor iedereen, schrijven en uploaden voor geregistreerde gebruikers)';
+$lang['i_pol2']                = 'Besloten wiki (lezen, schrijven en uploaden alleen voor geregistreerde gebruikers)';
 $lang['i_retry']               = 'Opnieuw';
+$lang['mu_intro']              = 'Hiier kun je meerdere bestanden tegelijk uploaden. Klik de blader-knop om ze aan de lijst toe te voegen. Klik Upload als je klaar bent.';
+$lang['mu_gridname']           = 'Bestandsnaam';
+$lang['mu_gridsize']           = 'Grootte';
+$lang['mu_gridstat']           = 'Status';
+$lang['mu_namespace']          = 'Namespace';
+$lang['mu_browse']             = 'Blader';
+$lang['mu_toobig']             = 'te groot';
+$lang['mu_ready']              = 'Klaar om te uploaden';
+$lang['mu_done']               = 'klaar';
+$lang['mu_fail']               = 'mislukt';
+$lang['mu_authfail']           = 'sessie beëindigd';
+$lang['mu_progress']           = '@PCT@% geüpload';
+$lang['mu_filetypes']          = 'Toegestane bestandstypes';
+$lang['recent_global']         = 'Je bekijkt momenteel de wijzigingen binnen de <b>%s</b> namespace. Je kunt ook de <a href="%s">recente wijzigingen van de hele wiki</a> bekijken.';
