@@ -10,6 +10,8 @@
  * @author Arild Burud <arildb@met.no>
  * @author Torkill Bruland <torkar-b@online.no>
  * @author Rune M. Andersen <rune.andersen@gmail.com>
+ * @author Jakob Vad Nielsen (me@jakobnielsen.net)
+ * @author Kjell Tore Næsgaard  <kjell.t.nasgaard@ntnu.no>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -66,6 +68,7 @@ $lang['profile']               = 'Brukerprofil';
 $lang['badlogin']              = 'Ugyldig brukernavn og/eller passord.';
 $lang['minoredit']             = 'Mindre endringer';
 $lang['draftdate']             = 'Kladd autolagret';
+$lang['nosecedit']             = 'Siden ble endret i mellomtiden, seksjonsinfo har blitt foreldet - lastet full side istedet.';
 $lang['regmissing']            = 'Vennligst fyll ut alle felt.';
 $lang['reguexists']            = 'Det finnes allerede en konto med dette brukernavnet.';
 $lang['regsuccess']            = 'Brukerkonto har blitt laget og passord har blitt sendt via e-post.';
@@ -87,6 +90,8 @@ $lang['resendpwdnouser']       = 'Beklager, vi kan ikke finne denne brukeren i v
 $lang['resendpwdbadauth']      = 'Beklager, denne autorisasjonskoden er ikke gyldig. Sjekk at du brukte hele bekreftelseslenken.';
 $lang['resendpwdconfirm']      = 'En bekreftelseslenke er blitt sendt på e-post.';
 $lang['resendpwdsuccess']      = 'Ditt nye passord er blitt sendt på e-post.';
+$lang['license']               = 'Der annet ikke er særskilt beskrevet, er innholdet på denne wiki regulert av følgende lisens:';
+$lang['licenseok']             = 'Merk: Ved å endre på denne siden godtar du at ditt innhold blir regulert av følgende lisens:';
 $lang['txt_upload']            = 'Velg fil som skal lastes opp';
 $lang['txt_filename']          = 'Skriv inn wikinavn (alternativt)';
 $lang['txt_overwrt']           = 'Overskriv eksisterende fil';
@@ -112,6 +117,9 @@ $lang['namespaces']            = 'Navnerom';
 $lang['mediafiles']            = 'Tilgjengelige filer i';
 $lang['js']['keepopen']        = 'Hold vindu åpent ved valg';
 $lang['js']['hidedetails']     = 'Skjul detaljer';
+$lang['js']['nosmblinks']      = 'Lenker til Windows-ressurser fungerer bare i Microsoft sin Internet Explorer.
+Du kan fortsatt kopiere og lime inn lenken.';
+$lang['js']['mu_btn']          = 'Last opp flere filer samtidig';
 $lang['mediausage']            = 'Bruk følgende syntaks til å refferer til denne filen:';
 $lang['mediaview']             = 'Vis original fil';
 $lang['mediaroot']             = 'rot';
@@ -141,7 +149,6 @@ $lang['mail_newpage']          = 'side lagt til:';
 $lang['mail_changed']          = 'side endret:';
 $lang['mail_new_user']         = 'ny bruker:';
 $lang['mail_upload']           = 'fil opplastet:';
-$lang['nosmblinks']            = 'Lenker til Windows-ressurser fungerer bare i Microsoft sin Internet Explorer.\nDu kan fortsatt kopiere og lime inn lenken.';
 $lang['qb_alert']              = 'Vennligst skriv inn teksten du ønsker å formatere.\nDen vil bli lagt til mot slutten av dokumentet.';
 $lang['qb_bold']               = 'Fet tekst';
 $lang['qb_italic']             = 'Kursiv tekst';
@@ -193,7 +200,7 @@ $lang['i_superuser']           = 'Superbruker';
 $lang['i_problems']            = 'Installasjonen oppdaget noen problemer, disse listes nedenfor. Du kan ikke fortsett før du har løst disse.';
 $lang['i_modified']            = 'For sikkerhets skyld vil dette skriptet bare virke med en ny og uendret Dokuwiki-installsjon.
                          Du bør enten pakke ut filene på nytt fra den nedlastede pakken, eller konsultere den komplette
-                         <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki-installasjonsinstruksen</a>';
+                         <a href="http://dokuwiki.org/install">Dokuwiki-installasjonsinstruksen</a>';
 $lang['i_funcna']              = 'PHP-funksjonen <code>%s</code> er ikke tilgjengelig. Kanskje din leverandør har deaktivert den av noen grunn?';
 $lang['i_phpver']              = 'Your PHP version <code>%s</code> is lower than the needed <code>%s</code>. You need to upgrade your PHP install.';
 $lang['i_permfail']            = '<code>%s</code> er ikke skrivbar for DokuWiki. Du må fikse rettighetene for denne mappen!';
@@ -210,3 +217,17 @@ $lang['i_pol0']                = 'Åpen Wiki (les, skriv og opplasting for alle)
 $lang['i_pol1']                = 'Offentlig Wiki (les for alle, skriving og opplasting bare for registrerte brukere)';
 $lang['i_pol2']                = 'Lukket Wiki (les, skriv og opplasting bare for registrerte brukere)';
 $lang['i_retry']               = 'Prøv igjen';
+$lang['mu_intro']              = 'Her kan du laste opp flere filer samtidig. Klikk på utforsk-knappen for å legge dem til i køen. Klikk på "last opp" når du er ferdig med å velge filene. ';
+$lang['mu_gridname']           = 'Filnavn';
+$lang['mu_gridsize']           = 'Størrelse';
+$lang['mu_gridstat']           = 'Status';
+$lang['mu_namespace']          = 'Navnerom (Namespace)';
+$lang['mu_browse']             = 'Utforsk';
+$lang['mu_toobig']             = 'for stor';
+$lang['mu_ready']              = 'klar for opplasting';
+$lang['mu_done']               = 'komplett';
+$lang['mu_fail']               = 'feilet';
+$lang['mu_authfail']           = 'sesjonen har utløpt';
+$lang['mu_progress']           = '@PCT@% lastet opp';
+$lang['mu_filetypes']          = 'Tillatte filtyper';
+$lang['recent_global']         = 'Du ser nå på endringene i navnerommet <b>%s</b>. Du kan også<a href="%s">se på nylig foretatte endringer for hele wikien</a>.';
