@@ -4,6 +4,8 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Grzegorz Żur <grzegorz.zur@gmail.com>
+ * @author Mariusz Kujawski <marinespl@gmail.com>
+ * @author Maciej Kurczewski <pipijajko@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -60,6 +62,7 @@ $lang['profile']               = 'Profil użytkownika';
 $lang['badlogin']              = 'Nazwa użytkownika lub hasło są nieprawidłowe.';
 $lang['minoredit']             = 'Mniejsze zmiany';
 $lang['draftdate']             = 'Czas zachowania szkicu';
+$lang['nosecedit']             = 'Strona została zmodyfikowana, sekcje zostały zmienione. Załadowano całą stronę.';
 $lang['regmissing']            = 'Wypełnij wszystkie pola.';
 $lang['reguexists']            = 'Użytkownik o tej nazwie już istnieje.';
 $lang['regsuccess']            = 'Utworzono użytkownika. Hasło zostało przesłane pocztą.';
@@ -81,6 +84,8 @@ $lang['resendpwdnouser']       = 'Nie można znaleźć tego użytkownika w bazie
 $lang['resendpwdbadauth']      = 'Błędny kod autoryzacji! Upewnij się, że użyłeś(aś) właściwego odnośnika.';
 $lang['resendpwdconfirm']      = 'Prośba o potwierdzenie została przesłana pocztą.';
 $lang['resendpwdsuccess']      = 'Nowe hasło zostało wysłane pocztą.';
+$lang['license']               = 'Wszystkie treści w tym wiki, którym nie przyporządkowano licencji, podlegają licencji:';
+$lang['licenseok']             = 'Uwaga: edytując tę stronę zgadzasz się na publikowanie jej treści pod licencją:';
 $lang['txt_upload']            = 'Wybierz plik do wysłania';
 $lang['txt_filename']          = 'Nazwa pliku (opcjonalnie)';
 $lang['txt_overwrt']           = 'Nadpisać istniejący plik?';
@@ -106,6 +111,9 @@ $lang['namespaces']            = 'Katalogi';
 $lang['mediafiles']            = 'Dostępne pliki';
 $lang['js']['keepopen']        = 'Nie zamykaj okna po wyborze';
 $lang['js']['hidedetails']     = 'Ukryj szczegóły';
+$lang['js']['nosmblinks']      = 'Odnośniki do zasobów sieci Windows działają tylko w przeglądarce Internet Explorer. 
+Możesz skopiować odnośnik.';
+$lang['js']['mu_btn']          = 'Wyślij wiele plików na raz';
 $lang['mediausage']            = 'Użyj następującej składni w odnośniku do tego pliku:';
 $lang['mediaview']             = 'Pokaż oryginalny plik';
 $lang['mediaroot']             = 'główny';
@@ -131,11 +139,11 @@ $lang['created']               = 'utworzono';
 $lang['restored']              = 'przywrócono poprzednią wersję';
 $lang['external_edit']         = 'edycja zewnętrzna';
 $lang['summary']               = 'Opis zmian';
+$lang['noflash']               = 'Plugin <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> jest niezbędny do obejrzenia tej zawartości.';
 $lang['mail_newpage']          = 'Strona dodana:';
 $lang['mail_changed']          = 'Strona zmieniona:';
 $lang['mail_new_user']         = 'Nowy użytkownik:';
 $lang['mail_upload']           = 'Umieszczono plik:';
-$lang['nosmblinks']            = 'Odnośniki do zasobów sieci Windows działają tylko w przeglądarce Internet Explorer. \nMożesz skopiować odnośnik.';
 $lang['qb_alert']              = 'Wpisz tekst, który chcesz sformatować. \nBędzie on dołączony na koniec strony.';
 $lang['qb_bold']               = 'Pogrubienie';
 $lang['qb_italic']             = 'Pochylenie';
@@ -186,7 +194,7 @@ $lang['i_enableacl']           = 'Włącz mechanizm uprawnień ACL (zalecane)';
 $lang['i_superuser']           = 'Administrator';
 $lang['i_problems']            = 'Instalator napotkał poniższe problemy. Nie można kontynuować póki nie zostaną usunięte.';
 $lang['i_modified']            = 'Ze względów bezpieczeństwa, ten skrypt działa tylko z nową i niezmodyfikowaną instalacją DokuWiki.
-Aby uruchomić instalator ponownie, rozpakuj archiwum DokuWiki lub zapoznaj się z <a href="http://wiki.splitbrain.org/wiki:install">instrukcją instalacji Dokuwiki</a>';
+Aby uruchomić instalator ponownie, rozpakuj archiwum DokuWiki lub zapoznaj się z <a href="http://dokuwiki.org/install">instrukcją instalacji Dokuwiki</a>';
 $lang['i_funcna']              = 'Funkcja PHP <code>%s</code> jest niedostępna.';
 $lang['i_phpver']              = 'Wersja PHP <code>%s</code> jest niższa od wymaganej <code>%s</code>. Zaktualizuj instalację PHP.';
 $lang['i_permfail']            = 'DokuWiki nie ma prawa zapisu w katalogu <code>%s</code>. Zmień uprawnienia zapisu dla tego katalogu!';
@@ -201,3 +209,17 @@ $lang['i_pol0']                = 'Otwarte Wiki (odczyt, zapis i dodawanie plikó
 $lang['i_pol1']                = 'Publiczne Wiki (odczyt dla wszystkich, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
 $lang['i_pol2']                = 'Zamknięte Wiki (odczyt, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
 $lang['i_retry']               = 'Spróbuj ponownie';
+$lang['mu_intro']              = 'Możesz tutaj wysłać wiele plików na raz. Kliknij przycisk "Przeglądaj" aby dodać je do kolejki. Kliknij "Wyślij" gdy skończysz.';
+$lang['mu_gridname']           = 'Nazwa pliku';
+$lang['mu_gridsize']           = 'Rozmiar';
+$lang['mu_gridstat']           = 'Stan';
+$lang['mu_namespace']          = 'Katalog';
+$lang['mu_browse']             = 'Przeglądaj';
+$lang['mu_toobig']             = 'za duży';
+$lang['mu_ready']              = 'gotowy do wysłania';
+$lang['mu_done']               = 'zakończono';
+$lang['mu_fail']               = 'nie powiodło się';
+$lang['mu_authfail']           = 'sesja wygasła';
+$lang['mu_progress']           = '@PCT@% wysłano';
+$lang['mu_filetypes']          = 'Dozwolone typy plików';
+$lang['recent_global']         = 'W tej chwili przeglądasz zmiany w katalogu <b>%s</b>. Możesz przejrzeć także <a href="%s">zmiany w całym wiki</a>.';
