@@ -7,6 +7,13 @@
  * @author Alauton/Loug
  * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
  * @author Felipe Castro <fefcas@gmail.com>
+ * @author Lucien Raven <lucienraven@yahoo.com.br>
+ * @author Enrico Nicoletto <liverig@gmail.com>
+ * @author Flávio Veras <flaviove@gmail.com>
+ * @author Jeferson Propheta <jeferson.propheta@gmail.com>
+ * @author jair.henrique@gmail.com
+ * @author Luis Dantas <luis@dantas.com>
+ * @author Frederico Guimarães <frederico@teia.bio.br>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -15,11 +22,11 @@ $lang['doublequoteclosing']    = '”';
 $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '’';
-$lang['btn_edit']              = 'Editar essa página';
+$lang['btn_edit']              = 'Editar esta página';
 $lang['btn_source']            = 'Mostrar código fonte';
 $lang['btn_show']              = 'Mostrar página';
-$lang['btn_create']            = 'Criar essa página';
-$lang['btn_search']            = 'Procurar';
+$lang['btn_create']            = 'Criar esta página';
+$lang['btn_search']            = 'Pesquisar';
 $lang['btn_save']              = 'Salvar';
 $lang['btn_preview']           = 'Visualizar';
 $lang['btn_top']               = 'Voltar ao topo';
@@ -37,32 +44,33 @@ $lang['btn_admin']             = 'Administrar';
 $lang['btn_update']            = 'Atualizar';
 $lang['btn_delete']            = 'Excluir';
 $lang['btn_back']              = 'Voltar';
-$lang['btn_backlink']          = 'Linques reversos';
+$lang['btn_backlink']          = 'Links reversos';
 $lang['btn_backtomedia']       = 'Voltar à seleção do arquivo de mídia';
-$lang['btn_subscribe']         = 'Monitorar alterações de páginas';
-$lang['btn_unsubscribe']       = 'Cancelar monitoramento de páginas';
-$lang['btn_subscribens']       = 'Monitorar alterações em Espaço-de-nomes';
-$lang['btn_unsubscribens']     = 'Cancelar monitoramento de Espaço-de-nomes';
-$lang['btn_profile']           = 'Atualizar perfil';
+$lang['btn_subscribe']         = 'Monitorar alterações na página';
+$lang['btn_unsubscribe']       = 'Cancelar monitoramento da página';
+$lang['btn_subscribens']       = 'Monitorar alterações no espaço de nomes';
+$lang['btn_unsubscribens']     = 'Cancelar monitoramento do espaço de nomes';
+$lang['btn_profile']           = 'Atualizar o perfil';
 $lang['btn_reset']             = 'Limpar';
-$lang['btn_resendpwd']         = 'Enviar nova senha';
-$lang['btn_draft']             = 'Editar rascunho';
-$lang['btn_recover']           = 'Recuperar rascunho';
-$lang['btn_draftdel']          = 'Excluir rascunho';
+$lang['btn_resendpwd']         = 'Enviar uma nova senha';
+$lang['btn_draft']             = 'Editar o rascunho';
+$lang['btn_recover']           = 'Recuperar o rascunho';
+$lang['btn_draftdel']          = 'Excluir o rascunho';
 $lang['loggedinas']            = 'Autenticado(a) como';
 $lang['user']                  = 'Nome de usuário';
 $lang['pass']                  = 'Senha';
 $lang['newpass']               = 'Nova senha';
 $lang['oldpass']               = 'Confirme a senha atual';
 $lang['passchk']               = 'mais uma vez';
-$lang['remember']              = 'Lembrar-se de mim';
+$lang['remember']              = 'Lembre-se de mim';
 $lang['fullname']              = 'Nome completo';
 $lang['email']                 = 'E-mail';
 $lang['register']              = 'Registrar';
-$lang['profile']               = 'Perfil de usuário';
+$lang['profile']               = 'Perfil do usuário';
 $lang['badlogin']              = 'Desculpe, mas o nome de usuário ou a senha estão incorretos.';
 $lang['minoredit']             = 'Alterações mínimas';
-$lang['draftdate']             = 'Rascunho salvo automaticamente em';
+$lang['draftdate']             = 'O rascunho foi salvo automaticamente em';
+$lang['nosecedit']             = 'A página foi modificada nesse intervalo de tempo. Como a informação da seção estava desatualizada, foi carregada a página inteira.';
 $lang['regmissing']            = 'Desculpe, mas você precisa preencher todos os campos.';
 $lang['reguexists']            = 'Desculpe, mas já existe um usuário com esse nome.';
 $lang['regsuccess']            = 'O usuário foi criado e a senha enviada para seu e-mail.';
@@ -77,52 +85,58 @@ $lang['profnochange']          = 'Sem alterações, nada para fazer.';
 $lang['profnoempty']           = 'Não são permitidos nomes ou endereços de e-mail em branco.';
 $lang['profchanged']           = 'O perfil do usuário foi atualizado com sucesso.';
 $lang['pwdforget']             = 'Esqueceu sua senha? Obtenha uma nova.';
-$lang['resendna']              = 'Esse wiki não suporta reenvio de senhas.';
+$lang['resendna']              = 'Esse wiki não tem suporte para o reenvio de senhas.';
 $lang['resendpwd']             = 'Enviar a nova senha para';
 $lang['resendpwdmissing']      = 'Desculpe, você deve preencher todos os campos.';
-$lang['resendpwdnouser']       = 'Desculpe, não foi possível encontrar esse usuário no banco de dados.';
+$lang['resendpwdnouser']       = 'Desculpe, não foi possível encontrar esse usuário no nosso banco de dados.';
 $lang['resendpwdbadauth']      = 'Desculpe, esse código de autorização é inválido. Certifique-se de que você usou o link de confirmação inteiro.';
-$lang['resendpwdconfirm']      = 'Um linque de confirmação foi enviado por e-mail.';
+$lang['resendpwdconfirm']      = 'Um link de confirmação foi enviado por e-mail.';
 $lang['resendpwdsuccess']      = 'Sua nova senha foi enviada por e-mail.';
+$lang['license']               = 'Exceto onde for informado ao contrário, o conteúdo neste wiki está sob a seguinte licença:';
+$lang['licenseok']             = 'Observe: editando esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
 $lang['txt_upload']            = 'Selecione o arquivo a ser enviado';
 $lang['txt_filename']          = 'Enviar como (opcional)';
 $lang['txt_overwrt']           = 'Substituir o arquivo existente';
-$lang['lockedby']              = 'Atualmente bloqueado por';
+$lang['lockedby']              = 'Atualmente bloqueada por';
 $lang['lockexpire']            = 'O bloqueio expira em';
-$lang['willexpire']            = 'O seu bloqueio de edição deste documento irá expirar em um minuto.\nPara evitar conflitos de edição, clique no botão de visualização para reiniciar o temporizador de bloqueio.';
+$lang['willexpire']            = 'O seu bloqueio de edição deste página irá expirar em um minuto.\nPara evitar conflitos de edição, clique no botão de visualização para reiniciar o temporizador de bloqueio.';
 $lang['notsavedyet']           = 'As alterações não salvas serão perdidas.\nDeseja realmente continuar?';
 $lang['rssfailed']             = 'Ocorreu um erro durante a atualização dessa fonte: ';
 $lang['nothingfound']          = 'Não foi encontrado nada.';
 $lang['mediaselect']           = 'Arquivos de mídia';
 $lang['fileupload']            = 'Envio de arquivo de mídia';
-$lang['uploadsucc']            = 'Envio efetuado com sucesso';
+$lang['uploadsucc']            = 'O envio foi efetuado com sucesso';
 $lang['uploadfail']            = 'Não foi possível enviar o arquivo. Será algum problema com as permissões?';
 $lang['uploadwrong']           = 'O envio foi bloqueado. Essa extensão de arquivo é proibida!';
 $lang['uploadexist']           = 'O arquivo já existe. Não foi feito nada.';
 $lang['uploadbadcontent']      = 'O conteúdo enviado não corresponde à extensão do arquivo %s.';
-$lang['uploadspam']            = 'O envio foi bloqueado pela lista negra de espams.';
-$lang['uploadxss']             = 'O envio foi bloqueado por conter conteúdo possivelmente malicioso.';
+$lang['uploadspam']            = 'O envio foi bloqueado pela lista negra de spams.';
+$lang['uploadxss']             = 'O envio foi bloqueado devido à possibilidade do seu conteúdo ser malicioso.';
+$lang['uploadsize']            = 'O arquivo transmitido era grande demais. (max. %s)';
 $lang['deletesucc']            = 'O arquivo "%s" foi excluído.';
 $lang['deletefail']            = 'Não foi possível excluir "%s" - verifique as permissões.';
 $lang['mediainuse']            = 'O arquivo "%s" não foi excluído - ele ainda está em uso.';
-$lang['namespaces']            = 'Ramos';
+$lang['namespaces']            = 'Espaços de nome';
 $lang['mediafiles']            = 'Arquivos disponíveis em';
 $lang['js']['keepopen']        = 'Manter a janela aberta na seleção';
 $lang['js']['hidedetails']     = 'Esconder detalhes';
-$lang['mediausage']            = 'Use a seguinte sintaxe para se referir a esse arquivo:';
-$lang['mediaview']             = 'Ver arquivo original';
+$lang['js']['nosmblinks']      = 'Atalhos para pastas compartilhadas do Windows funcionam apenas no Microsoft Internet Explorer.
+Entretanto, você ainda pode copiar e colar o atalho.';
+$lang['js']['mu_btn']          = 'Enviar vários arquivos de uma vez';
+$lang['mediausage']            = 'Use a seguinte sintaxe para referenciar esse arquivo:';
+$lang['mediaview']             = 'Ver o arquivo original';
 $lang['mediaroot']             = 'raiz';
-$lang['mediaupload']           = 'Envie um arquivo para o ramo atual aqui. Para criar sub-ramos, preponha-os ao nome do arquivo no parâmetro "Enviar como", separados por vírgulas.';
+$lang['mediaupload']           = 'Envie um arquivo para o espaço de nomes atual aqui. Para criar subespaços de nomes, preponha-os ao nome do arquivo no parâmetro "Enviar como", separados por vírgulas.';
 $lang['mediaextchange']        = 'A extensão do arquivo mudou de .%s para .%s!';
 $lang['reference']             = 'Referências para';
 $lang['ref_inuse']             = 'O arquivo não pode ser excluído, porque ele ainda está sendo utilizado nas seguintes páginas:';
 $lang['ref_hidden']            = 'Algumas referências estão em páginas que você não tem permissão para ler';
 $lang['hits']                  = 'Resultados';
 $lang['quickhits']             = 'Nomes de páginas coincidentes';
-$lang['toc']                   = 'Tabela de Conteúdos';
+$lang['toc']                   = 'Tabela de conteúdos';
 $lang['current']               = 'atual';
 $lang['yours']                 = 'Sua versão';
-$lang['diff']                  = 'Mostrar diferenças com a versão atual';
+$lang['diff']                  = 'Mostrar diferenças com a revisão atual';
 $lang['diff2']                 = 'Mostrar diferenças entre as revisões selecionadas';
 $lang['line']                  = 'Linha';
 $lang['breadcrumb']            = 'Visitou';
@@ -131,14 +145,14 @@ $lang['lastmod']               = 'Última modificação';
 $lang['by']                    = 'por';
 $lang['deleted']               = 'removida';
 $lang['created']               = 'criada';
-$lang['restored']              = 'revisão anterior restaurada.';
+$lang['restored']              = 'revisão anterior restaurada';
 $lang['external_edit']         = 'edição externa';
 $lang['summary']               = 'Resumo da edição';
+$lang['noflash']               = 'O <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a> é necessário para exibir este conteúdo.';
 $lang['mail_newpage']          = 'página adicionada:';
 $lang['mail_changed']          = 'página modificada:';
 $lang['mail_new_user']         = 'novo usuário:';
 $lang['mail_upload']           = 'arquivo enviado:';
-$lang['nosmblinks']            = 'Atalhos para pastas Windows compartilhadas funcionam apenas no Microsoft Internet Explorer.\nEntretanto, você ainda pode copiar e colar o atalho.';
 $lang['qb_alert']              = 'Por favor, insira o texto que você deseja formatar.\nEle será adicionado ao final do documento.';
 $lang['qb_bold']               = 'Texto em negrito';
 $lang['qb_italic']             = 'Texto em itálico';
@@ -150,9 +164,9 @@ $lang['qb_h2']                 = 'Cabeçalho de nível 2';
 $lang['qb_h3']                 = 'Cabeçalho de nível 3';
 $lang['qb_h4']                 = 'Cabeçalho de nível 4';
 $lang['qb_h5']                 = 'Cabeçalho de nível 5';
-$lang['qb_link']               = 'Linque interno';
-$lang['qb_extlink']            = 'Linque externo';
-$lang['qb_hr']                 = 'Barra horizontal';
+$lang['qb_link']               = 'Link interno';
+$lang['qb_extlink']            = 'Link externo';
+$lang['qb_hr']                 = 'Linha horizontal';
 $lang['qb_ol']                 = 'Item de lista ordenada';
 $lang['qb_ul']                 = 'Item de lista não ordenada';
 $lang['qb_media']              = 'Adicionar imagens e/ou outros arquivos';
@@ -171,7 +185,7 @@ $lang['img_date']              = 'Data';
 $lang['img_fname']             = 'Nome do arquivo';
 $lang['img_fsize']             = 'Tamanho';
 $lang['img_artist']            = 'Fotógrafo';
-$lang['img_copyr']             = 'Direitos de cópia';
+$lang['img_copyr']             = 'Direitos autorais';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Câmera';
 $lang['img_keywords']          = 'Palavras-chave';
@@ -180,27 +194,41 @@ $lang['subscribe_error']       = 'Ocorreu um erro ao tentar adicionar %s à list
 $lang['subscribe_noaddress']   = 'Não existe nenhum endereço de e-mail associado ao seu usuário, você não pode ser adicionado à lista de monitoramento.';
 $lang['unsubscribe_success']   = '%s foi removido da lista de monitoramento de %s';
 $lang['unsubscribe_error']     = 'Ocorreu um erro ao tentar remover %s da lista de monitoramento de %s';
-$lang['authmodfailed']         = 'A configuração da autenticação de usuário está com problemas. Por favor, informe o administrador do Wiki.';
-$lang['authtempfail']          = 'A autenticação de usuários está temporariamente desabilitada. Se essa situação persistir, por favor, informe o administrador do Wiki.';
+$lang['authmodfailed']         = 'A configuração da autenticação de usuário está com problemas. Por favor, informe ao administrador do wiki.';
+$lang['authtempfail']          = 'A autenticação de usuários está temporariamente desabilitada. Se essa situação persistir, por favor, informe ao administrador do Wiki.';
 $lang['i_chooselang']          = 'Selecione o seu idioma';
 $lang['i_installer']           = 'Instalador do DokuWiki';
 $lang['i_wikiname']            = 'Nome do Wiki';
 $lang['i_enableacl']           = 'Habilitar Lista de Controle de Acessos (recomendado)';
-$lang['i_superuser']           = 'Super-usuário';
+$lang['i_superuser']           = 'Superusuário';
 $lang['i_problems']            = 'O instalador encontrou alguns problemas, indicados abaixo. Você não pode continuar até corrigi-los.';
-$lang['i_modified']            = 'Por questões de segurança, esse script irá funcionar apenas em uma instalação nova e não modificada do DokuWiki.
-Você pode re-extrair os arquivos do pacote original ou consultar as <a href="http://wiki.splitbrain.org/wiki:install">instruções de instalação do DokuWiki</a>.';
+$lang['i_modified']            = 'Por questões de segurança, esse script funcionará apenas em uma instalação nova e não modificada do DokuWiki.
+Você pode extrair novamente os arquivos do pacote original ou consultar as <a href="http://dokuwiki.org/install">instruções de instalação do DokuWiki</a>.';
 $lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. O seu host a mantém desabilitada por algum motivo?';
 $lang['i_phpver']              = 'A sua versão do PHP (<code>%s</code>) é inferior à necessária (<code>%s</code>). Você precisa atualizar a sua instalação do PHP.';
-$lang['i_permfail']            = 'O DokiWiki não tem permissão de escrita em <code>%s</code>. Você precisa corrigir as configurações de permissão nesse diretório!';
+$lang['i_permfail']            = 'O DokuWiki não tem permissão de escrita em <code>%s</code>. Você precisa corrigir as configurações de permissão nesse diretório!';
 $lang['i_confexists']          = '<code>%s</code> já existe';
 $lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É necessário checar as permissões de arquivos/diretórios e criar o arquivo manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php não reconhecido ou modificado (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valor ilegal ou em branco';
-$lang['i_success']             = 'A configuração terminou com sucesso. Você pode excluir o arquivo install.php agora. Entre agora no seu <a href="doku.php">novo DokuWiki</a>';
+$lang['i_success']             = 'A configuração terminou com sucesso. Agora você deve excluir o arquivo install.php. Conheça o seu <a href="doku.php">novo DokuWiki</a>!';
 $lang['i_failure']             = 'Ocorreram alguns erros durante a escrita dos arquivos de configuração. É necessário corrigi-los manualmente antes de usar seu <a href="doku.php">novo DokuWiki</a>';
 $lang['i_policy']              = 'Política inicial de permissões';
 $lang['i_pol0']                = 'Wiki aberto (leitura, escrita e envio de arquivos por todos)';
 $lang['i_pol1']                = 'Wiki público (leitura por todos, escrita e envio de arquivos por usuários registrados)';
 $lang['i_pol2']                = 'Wiki fechado (leitura, escrita e envio de arquivos somente por usuários registrados)';
 $lang['i_retry']               = 'Tentar novamente';
+$lang['mu_intro']              = 'Aqui você pode enviar vários arquivos de uma só vez. Clique no botão de navegação e adicione-os à fila. Pressione Enviar quando estiver pronto.';
+$lang['mu_gridname']           = 'Nome do arquivo';
+$lang['mu_gridsize']           = 'Tamanho';
+$lang['mu_gridstat']           = 'Status';
+$lang['mu_namespace']          = 'Espaço de nomes';
+$lang['mu_browse']             = 'Navegar';
+$lang['mu_toobig']             = 'muito grande';
+$lang['mu_ready']              = 'pronto para enviar';
+$lang['mu_done']               = 'completo';
+$lang['mu_fail']               = 'falhou';
+$lang['mu_authfail']           = 'a sessão expirou';
+$lang['mu_progress']           = '@PCT@% enviado';
+$lang['mu_filetypes']          = 'Tipos de arquivo permitidos';
+$lang['recent_global']         = 'Você está observando as alterações dentro do espaço de nomes <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
