@@ -8,8 +8,11 @@
  * @author Denis Simakov <akinoame1@gmail.com>
  * @author Kaens Bard <kaens@mail.ru>
  * @author Andrew Pleshakov <beotiger@mail.ru>
+ * @author Змей Этерийский evil_snake@eternion.ru
+ * @author Hikaru Nakajima <jisatsu@mail.ru>
+ * @author Alexei Tereschenko <alexeitlex@yahoo.com>
  */
-$lang['encoding']              = 'utf-8';
+$lang['encoding']              = ' utf-8';
 $lang['direction']             = 'ltr';
 $lang['doublequoteopening']    = '«';
 $lang['doublequoteclosing']    = '»';
@@ -42,13 +45,15 @@ $lang['btn_backlink']          = 'Ссылки сюда';
 $lang['btn_backtomedia']       = 'Вернуться к выбору медиа-файла';
 $lang['btn_subscribe']         = 'Подписаться';
 $lang['btn_unsubscribe']       = 'Отписаться';
+$lang['btn_subscribens']       = 'Подписаться на уведомления об изменениях в пространстве имён';
+$lang['btn_unsubscribens']     = 'Отказаться от подписки на уведомления об изменениях в пространстве имён';
 $lang['btn_profile']           = 'Профиль';
 $lang['btn_reset']             = 'Сброс';
 $lang['btn_resendpwd']         = 'Послать новый пароль';
 $lang['btn_draft']             = 'Править черновик';
 $lang['btn_recover']           = 'Восстановить черновик';
 $lang['btn_draftdel']          = 'Удалить черновик';
-$lang['loggedinas']            = 'Вы';
+$lang['loggedinas']            = 'Зашли как';
 $lang['user']                  = 'Логин';
 $lang['pass']                  = 'Пароль';
 $lang['newpass']               = 'Новый пароль';
@@ -62,6 +67,7 @@ $lang['profile']               = 'Профиль пользователя';
 $lang['badlogin']              = 'Извините, неверное имя пользователя или пароль.';
 $lang['minoredit']             = 'Небольшие изменения';
 $lang['draftdate']             = 'Черновик сохранён';
+$lang['nosecedit']             = 'За это время страница была изменена, и информация о секции устарела. Загружена полная версия страницы.';
 $lang['regmissing']            = 'Извините, вам следует заполнить все поля.';
 $lang['reguexists']            = 'Извините, пользователь с таким логином уже существует.';
 $lang['regsuccess']            = 'Пользователь создан, пароль выслан на e-mail.';
@@ -83,6 +89,8 @@ $lang['resendpwdnouser']       = 'Пользователь с таким лог
 $lang['resendpwdbadauth']      = 'Извините, неверный код авторизации. Убедитесь, что Вы полностью скопировали ссылку. ';
 $lang['resendpwdconfirm']      = 'Ссылка для подтверждения пароля была выслана по e-mail. ';
 $lang['resendpwdsuccess']      = 'Ваш новый пароль был выслан по e-mail.';
+$lang['license']               = 'За исключением случаев, когда указано иное, содержимое этой вики предоставляется на условиях следующей лицензии:';
+$lang['licenseok']             = 'Примечание: редактируя эту страницу, Вы соглашаетесь на использование вашего вклада на условиях следующей лицензии:';
 $lang['txt_upload']            = 'Выберите файл для закачки';
 $lang['txt_filename']          = 'Введите имя файла в вики (необязательно)';
 $lang['txt_overwrt']           = 'Перезаписать существующий файл';
@@ -101,6 +109,7 @@ $lang['uploadexist']           = 'Файл с таким именем сущес
 $lang['uploadbadcontent']      = 'Содержание файла не соответствует расширению %s.';
 $lang['uploadspam']            = 'Закачка заблокирована спам-фильтром.';
 $lang['uploadxss']             = 'Закачка заблокирована по соображениям безопасности.';
+$lang['uploadsize']            = 'Загруженный файл был слишком большой. (макс. %s)';
 $lang['deletesucc']            = 'Файл "%s" был удалён.';
 $lang['deletefail']            = 'Невозможно удалить файл "%s". Проверьте права доступа к файлу.';
 $lang['mediainuse']            = 'Файл "%s" не был удалён - файл всё ещё используется.';
@@ -108,6 +117,9 @@ $lang['namespaces']            = 'Пространства имён';
 $lang['mediafiles']            = 'Доступные файлы';
 $lang['js']['keepopen']        = 'Не закрывать окно после выбора';
 $lang['js']['hidedetails']     = 'Скрыть детали';
+$lang['js']['nosmblinks']      = 'Ссылка на сетевые каталоги Windows работает только из Интернет Эксплорера
+Но Вы можете скопировать ссылку.';
+$lang['js']['mu_btn']          = 'Загрузить несколько файлов одновременно';
 $lang['mediausage']            = 'Для ссылки на этот файл используйте следующий синтаксис:';
 $lang['mediaview']             = 'Посмотреть исходный файл';
 $lang['mediaroot']             = 'корень';
@@ -122,21 +134,22 @@ $lang['toc']                   = 'Содержание';
 $lang['current']               = 'текущий';
 $lang['yours']                 = 'Ваша версия';
 $lang['diff']                  = 'показать отличия от текущей версии';
+$lang['diff2']                 = 'Показать различия между ревизиями  ';
 $lang['line']                  = 'Строка';
 $lang['breadcrumb']            = 'Вы посетили';
 $lang['youarehere']            = 'Вы находитесь здесь';
 $lang['lastmod']               = 'Последние изменения';
-$lang['by']                    = ' ';
+$lang['by']                    = ' От';
 $lang['deleted']               = 'удалено';
 $lang['created']               = 'создано';
 $lang['restored']              = 'старая ревизия восстановлена';
 $lang['external_edit']         = 'внешнее изменение';
 $lang['summary']               = 'Сводка изменений';
+$lang['noflash']               = 'Для просмотра этого содержимого требуется <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['mail_newpage']          = 'страница добавлена:';
 $lang['mail_changed']          = 'страница изменена:';
 $lang['mail_new_user']         = 'новый пользователь:';
 $lang['mail_upload']           = 'файл закачан:';
-$lang['nosmblinks']            = 'Ссылка на сетевые каталоги Windows работает только из Интернет Эксплорера\nНо Вы можете скопировать ссылку.';
 $lang['qb_alert']              = 'Пожалуйста, введите текст, который хотите отформатировать.\nОн будет добавлен в конец документа.';
 $lang['qb_bold']               = 'Полужирный шрифт';
 $lang['qb_italic']             = 'Курсивный шрифт';
@@ -188,7 +201,7 @@ $lang['i_superuser']           = 'Суперюзер';
 $lang['i_problems']            = 'Программа установки столкнулась с проблемами, перечисленными ниже. Чтобы продолжить, вам необходимо их устранить. ';
 $lang['i_modified']            = 'Из соображений безопасности эта программа запускается только на новой, неизменённой установке DokuWiki. 
                          Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
-                         <a href="http://wiki.splitbrain.org/wiki:install">инструкции по установке DokuWiki</a>';
+                         <a href="http://dokuwiki.org/install">инструкции по установке DokuWiki</a>';
 $lang['i_funcna']              = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована Вашим хостингом?';
 $lang['i_phpver']              = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
 $lang['i_permfail']            = '<code>%s</code> недоступна для записи DokuWiki. Вам необходимо исправить системные права доступа для этой директории!';
@@ -204,3 +217,17 @@ $lang['i_pol0']                = 'Открытая вики (чтение, за
 $lang['i_pol1']                = 'Общедоступная вики (чтение для всех, запись и загрузка файлов для зарегистрированных пользователей)';
 $lang['i_pol2']                = 'Закрытая вики (чтение, запись и загрузка файлов только для зарегистрированных пользователей)';
 $lang['i_retry']               = 'Повторить попытку';
+$lang['mu_intro']              = 'Здесь Вы можете загрузить несколько файлов сразу. Кликните на "обзор", чтобы добавить их в список. Нажмите "загрузить" когда будете готовы.';
+$lang['mu_gridname']           = 'Имя файла';
+$lang['mu_gridsize']           = 'Размер';
+$lang['mu_gridstat']           = 'Статус';
+$lang['mu_namespace']          = 'Пространство имён';
+$lang['mu_browse']             = 'Обзор';
+$lang['mu_toobig']             = 'Слишком большой';
+$lang['mu_ready']              = 'Готово к загрузке';
+$lang['mu_done']               = 'Завершено';
+$lang['mu_fail']               = 'Провалено';
+$lang['mu_authfail']           = 'Истекло время сессии';
+$lang['mu_progress']           = '@PCT@% загружено';
+$lang['mu_filetypes']          = 'Допустимые типы файлов';
+$lang['recent_global']         = 'Вы просматриваете изменения в пространстве имён <b>%s</b>. Вы можете также <a href="%s">просмотреть недавние изменения на всей вики</a>.';
