@@ -5,6 +5,8 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Ondrej Vegh <ov@vsieti.sk> with help of the scholars from Zdruzena stredna skola polygraficka in Bratislava
  * @author Michal Mesko <michal.mesko@gmail.com>
+ * @author exusik@gmail.com
+ * @author Martin Michalek <michalek.dev@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -25,7 +27,7 @@ $lang['btn_newer']             = '<< novšie';
 $lang['btn_older']             = 'staršie >>';
 $lang['btn_revs']              = 'Staršia verzia';
 $lang['btn_recent']            = 'Posledné úpravy';
-$lang['btn_upload']            = 'Priložiť';
+$lang['btn_upload']            = 'Nahrať';
 $lang['btn_cancel']            = 'Storno';
 $lang['btn_index']             = 'Index';
 $lang['btn_secedit']           = 'Upraviť';
@@ -61,6 +63,7 @@ $lang['profile']               = 'Užívateľský profil';
 $lang['badlogin']              = 'Zadané užívateľské meno a heslo nie je správne.';
 $lang['minoredit']             = 'Menšie zmeny';
 $lang['draftdate']             = 'Koncept automaticky uložený';
+$lang['nosecedit']             = 'Skránka bola medzičasom zmenená, informácie o sekcii sú zastaralé a z tohto dôvodu bola nahraná celá stránka.';
 $lang['regmissing']            = 'Musíte vyplniť všetky údaje.';
 $lang['reguexists']            = 'Užívateľ s rovnakým menom je už zaregistrovaný.';
 $lang['regsuccess']            = 'Užívateľský účet bol vytvorený a heslo zaslané mailom.';
@@ -82,6 +85,8 @@ $lang['resendpwdnouser']       = 'Prepáčte, nemôžeme nájsť zadaného uží
 $lang['resendpwdbadauth']      = 'Prepáčte, tento autorizačný kód nie je platný. Uistite sa, či ste použili celý autorizačný odkaz.';
 $lang['resendpwdconfirm']      = 'Autorizačný odkaz bol zaslaný na e-mail.';
 $lang['resendpwdsuccess']      = 'Vaše nové heslo bolo zaslané na e-mail.';
+$lang['license']               = 'Ak nie je uvedené inak, obsah tejto wiki je uverejnený pod nasledujúcou licenciou:';
+$lang['licenseok']             = 'Poznámka: Zmenou tejto stránky súhlasíte s uverejnením obsahu pod nasledujúcou licenciou:';
 $lang['txt_upload']            = 'Vyberte súbor ako prílohu';
 $lang['txt_filename']          = 'Wiki meno (volitelné)';
 $lang['txt_overwrt']           = 'Prepísať existujúci súbor';
@@ -95,22 +100,26 @@ $lang['mediaselect']           = 'Výber dokumentu';
 $lang['fileupload']            = 'Nahrávanie dokumentu';
 $lang['uploadsucc']            = 'Prenos prebehol v poriadku';
 $lang['uploadfail']            = 'Chyba pri nahrávaní. Možno kvôli zle nastaveným právam?';
-$lang['uploadwrong']           = 'Priloženie súboru s takouto príponou není dovolené.';
+$lang['uploadwrong']           = 'Prenos súboru s takouto príponou nie je dovolený.';
 $lang['uploadexist']           = 'Súbor skutočne existuje. Nie je čo robiť.';
 $lang['uploadbadcontent']      = 'Nahraný obsah sa nezhoduje s príponou súboru %s.';
 $lang['uploadspam']            = 'Nahrávanie bolo zablokované spamovým blacklistom.';
 $lang['uploadxss']             = 'Nahrávanie bolo zablokované kvôli potenciálnemu škodlivému obsahu.';
-$lang['deletesucc']            = 'Súbor "%s" bol zmazený.';
+$lang['uploadsize']            = 'Nahraný súbor bol príliš veľký. (max %s)';
+$lang['deletesucc']            = 'Súbor "%s" bol zmazaný.';
 $lang['deletefail']            = '"%s" nie je možné zmazať - skontrolujte oprávnenia.';
 $lang['mediainuse']            = 'Súbor "%s" nebol zmazaný - je stále používaný.';
 $lang['namespaces']            = 'Menné priestory';
 $lang['mediafiles']            = 'Dostupné súbory';
 $lang['js']['keepopen']        = 'Po vybraní súboru ponechať okno otvorené';
 $lang['js']['hidedetails']     = 'Skryť detaily';
+$lang['js']['nosmblinks']      = 'Odkazovanie na zdielané prostriedky Windows funguje len v Internet Explorer.
+Aj napriek tomu tento odkaz môžete skopírovat a vložit inde.';
+$lang['js']['mu_btn']          = 'Nahrať viac súborov naraz';
 $lang['mediausage']            = 'Pre odkázanie na súbor použite nasledujúcu syntax:';
 $lang['mediaview']             = 'Zobraziť pôvodný súbor';
 $lang['mediaroot']             = 'root';
-$lang['mediaupload']           = 'Priložiť súbor do aktuálneho menného priestoru. Pre vytvorenie menného podpriestoru, pridajte jeho názov na začiatok wiki mena (oddelený dvojbodkou)';
+$lang['mediaupload']           = 'Nahrať súbor do aktuálneho menného priestoru. Pre vytvorenie menného podpriestoru, pridajte jeho názov na začiatok wiki mena (oddelený dvojbodkou)';
 $lang['mediaextchange']        = 'Prípona súboru bola zmenená z .%s na .%s!';
 $lang['reference']             = 'Referencie pre';
 $lang['ref_inuse']             = 'Súbor nemôže byť zmazaný, pretože je stále používaný nasledujúcimi stránkami:';
@@ -132,11 +141,11 @@ $lang['created']               = 'vytvorené';
 $lang['restored']              = 'stará verzia bola obnovena';
 $lang['external_edit']         = 'externá úprava';
 $lang['summary']               = 'Komentár k úpravám';
+$lang['noflash']               = 'Pre zobrazenie tohto obsahu potrebujete <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['mail_newpage']          = 'stránka pridaná:';
 $lang['mail_changed']          = 'stránka zmenená:';
 $lang['mail_new_user']         = 'Nový užívateľ:';
 $lang['mail_upload']           = 'nahraný súbor:';
-$lang['nosmblinks']            = 'Odkazovanie na zdielané prostriedky Windows funguje len v Internet Explorer.\nAj napriek tomu tento odkaz môžete skopírovat a vložit inde.';
 $lang['qb_alert']              = 'Vložte prosím text, ktorý chcete formátovať.\nTen bude pridaný na koniec dokumentu.';
 $lang['qb_bold']               = 'Tučné';
 $lang['qb_italic']             = 'Kurzíva';
@@ -184,12 +193,13 @@ $lang['i_chooselang']          = 'Zvoľte váš jazyk';
 $lang['i_installer']           = 'DokuWiki inštalátor';
 $lang['i_wikiname']            = 'Názov Wiki';
 $lang['i_enableacl']           = 'Aktivovať ACL (doporučené)';
-$lang['i_superuser']           = 'Superužívateľ';
-$lang['i_problems']            = 'Inštalátor narazil na nižšie uvedené problémy. Nemôžte pokračovať, pokým ich neodstránite.';
-$lang['i_modified']            = 'Z bezpečnostných dôvodov bude tento skript fungovať iba s novou, neupravenou inštaláciou Dokuwiki. Môžete buď znovu rozbaliť stiahnutý inštalačný balíček, alebo preštudovať <a href="http://wiki.splitbrain.org/wiki:install"> inštalačné inštrukcie Dokuwiki</a>';
+$lang['i_superuser']           = 'Správca';
+$lang['i_problems']            = 'Inštalátor narazil na nižšie uvedené problémy. Nemôžete pokračovať, pokiaľ ich neodstránite.';
+$lang['i_modified']            = 'Z bezpečnostných dôvodov bude tento skript fungovať iba s novou, neupravenou inštaláciou Dokuwiki. Môžete buď znovu rozbaliť stiahnutý inštalačný balíček, alebo preštudovať <a href="http://dokuwiki.org/install"> inštalačné inštrukcie Dokuwiki</a>';
 $lang['i_funcna']              = 'PHP funkcia <code>%s</code> nie je dostupná. Je možné, že ju z určitých dôvodov zablokoval váš poskytovateľ webhostingu?';
+$lang['i_phpver']              = 'Vaša verzia PHP <code>%s</code> je nižšia ako požadovaná <code>%s</code>. Potrebujete aktualizovať Vašu instaláciu PHP.';
 $lang['i_permfail']            = '<code>%s</code> nie je zapisovateľný pre DokuWiki. Musíte zmeniť prístupové práva pre tento adresár!';
-$lang['i_confexists']          = '<code>%s</code> skutočne existuje';
+$lang['i_confexists']          = '<code>%s</code> už existuje';
 $lang['i_writeerr']            = 'Nie je možné vytvoriť <code>%s</code>. Potrebujete skontrolovať prístupové práva pre adresár/súbor a vytvoriť ho manuálne.';
 $lang['i_badhash']             = 'nerozpoznaný, alebo zmenený súbor dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - bola zadaná nesprávna, alebo žiadna hodnota';
@@ -202,3 +212,14 @@ $lang['i_pol0']                = 'Otvorená Wiki (čítanie, zápis a nahrávani
 $lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných užívateľov)';
 $lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných užívateľov)';
 $lang['i_retry']               = 'Skúsiť znovu';
+$lang['mu_intro']              = 'Na tomto mieste môžete nahrávať viac súborov naraz. Tlačidlom Prehľadávať pridáte súbory do zoznamu. Tlačidlom Nahrať vykonáte prenos súborov.';
+$lang['mu_gridname']           = 'Názov súboru';
+$lang['mu_gridsize']           = 'Veľkosť';
+$lang['mu_gridstat']           = 'Status';
+$lang['mu_namespace']          = 'Oblasť mien';
+$lang['mu_browse']             = 'Prehľadávať';
+$lang['mu_toobig']             = 'príliš veľký';
+$lang['mu_done']               = 'dokončený';
+$lang['mu_fail']               = 'neúspešný';
+$lang['mu_filetypes']          = 'Povolené typy súborov';
+$lang['recent_global']         = 'Práve prehliadate zmeny v mennom priestore <b>%s</b>. Môžete si tiež pozrieť <a href="%s">aktuálne zmeny celej wiki</a>.';
