@@ -6,9 +6,8 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
+if(!defined('DOKU_INC')) die('meh.');
 if(!defined('NL')) define('NL',"\n");
-
 require_once(DOKU_INC.'inc/html.php');
 require_once(DOKU_INC.'inc/search.php');
 require_once(DOKU_INC.'inc/JpegMeta.php');
@@ -81,15 +80,20 @@ function media_metasave($id,$auth,$data){
  */
 function media_metaform($id,$auth){
     if($auth < AUTH_UPLOAD) return false;
-    global $lang;
+    global $lang, $config_cascade;
 
     // load the field descriptions
     static $fields = null;
     if(is_null($fields)){
-        include(DOKU_CONF.'mediameta.php');
-        if(@file_exists(DOKU_CONF.'mediameta.local.php')){
-            include(DOKU_CONF.'mediameta.local.php');
+
+      foreach (array('default','local') as $config_group) {
+        if (empty($config_cascade['mediameta'][$config_group])) continue;
+        foreach ($config_cascade['mediameta'][$config_group] as $config_file) {
+          if(@file_exists($config_file)){
+            include($config_file);
+          }
         }
+      }
     }
 
     $src = mediaFN($id);
@@ -132,13 +136,33 @@ function media_metaform($id,$auth){
     echo '<div class="buttons">'.NL;
     echo '<input type="hidden" name="img" value="'.hsc($id).'" />'.NL;
     echo '<input name="do[save]" type="submit" value="'.$lang['btn_save'].
-         '" title="ALT+S" accesskey="s" class="button" />'.NL;
+         '" title="'.$lang['btn_save'].' [S]" accesskey="s" class="button" />'.NL;
     echo '<input name="do[cancel]" type="submit" value="'.$lang['btn_cancel'].
-         '" title="ALT+C" accesskey="c" class="button" />'.NL;
+         '" title="'.$lang['btn_cancel'].' [C]" accesskey="c" class="button" />'.NL;
     echo '</div>'.NL;
     echo '</form>'.NL;
 }
 
+/**
+ * Conveinience function to check if a media file is still in use
+ *
+ * @author Michael Klier <chi@chimeric.de>
+ */
+function media_inuse($id) {
+    global $conf;
+    $mediareferences = array();
+    if($conf['refcheck']){
+        require_once(DOKU_INC.'inc/fulltext.php');
+        $mediareferences = ft_mediause($id,$conf['refshow']);
+        if(!count($mediareferences)) {
+            return false;
+        } else {
+            return $mediareferences;
+        }
+    } else {
+        return false;
+    }
+}
 
 /**
  * Handles media file deletions
@@ -154,42 +178,41 @@ function media_delete($id,$auth){
     global $conf;
     global $lang;
 
-    // check for references if needed
-    $mediareferences = array();
-    if($conf['refcheck']){
-        require_once(DOKU_INC.'inc/fulltext.php');
-        $mediareferences = ft_mediause($id,$conf['refshow']);
-    }
+    $file = mediaFN($id);
 
-    if(!count($mediareferences)){
-        $file = mediaFN($id);
-        if(@unlink($file)){
-            msg(str_replace('%s',noNS($id),$lang['deletesucc']),1);
-            $del = io_sweepNS($id,'mediadir');
-            if($del){
-                // current namespace was removed. redirecting to root ns passing msg along
-                header('Location: '.DOKU_URL.'lib/exe/mediamanager.php?msg1='.
-                        rawurlencode(str_replace('%s',noNS($id),$lang['deletesucc'])));
-                exit;
-            }
-            return true;
+    // trigger an event - MEDIA_DELETE_FILE
+    $data['id']   = $id;
+    $data['name'] = basename($file);
+    $data['path'] = $file;
+    $data['size'] = (@file_exists($file)) ? filesize($file) : 0;
+
+    $data['unl'] = false;
+    $data['del'] = false;
+    $evt = new Doku_Event('MEDIA_DELETE_FILE',$data);
+    if ($evt->advise_before()) {
+        $data['unl'] = @unlink($file);
+        if($data['unl']){
+            addMediaLogEntry(time(), $id, DOKU_CHANGE_TYPE_DELETE);
+            $data['del'] = io_sweepNS($id,'mediadir');
         }
-        //something went wrong
-        msg(str_replace('%s',$file,$lang['deletefail']),-1);
-        return false;
-    }elseif(!$conf['refshow']){
-        msg(str_replace('%s',noNS($id),$lang['mediainuse']),0);
-        return false;
+    }
+    $evt->advise_after();
+    unset($evt);
+
+    if($data['unl'] && $data['del']){
+        // current namespace was removed. redirecting to root ns passing msg along
+        send_redirect(DOKU_URL.'lib/exe/mediamanager.php?msg1='.
+                rawurlencode(sprintf(noNS($id),$lang['deletesucc'])));
     }
 
-    return $mediareferences;
+    return $data['unl'];
 }
 
 /**
  * Handles media file uploads
  *
  * This generates an action event and delegates to _media_upload_action().
- * Action plugins are allowed to pre/postprocess the uploaded file. 
+ * Action plugins are allowed to pre/postprocess the uploaded file.
  * (The triggered event is preventable.)
  *
  * Event data:
@@ -197,6 +220,7 @@ function media_delete($id,$auth){
  * $data[1]     fn: the file name of the uploaded file
  * $data[2]     id: the future directory id of the uploaded file
  * $data[3]     imime: the mimetype of the uploaded file
+ * $data[4]     overwrite: if an existing file is going to be overwritten
  *
  * @triggers MEDIA_UPLOAD_FINISH
  * @author Andreas Gohr <andi@splitbrain.org>
@@ -215,9 +239,15 @@ function media_upload($ns,$auth){
     $file = $_FILES['upload'];
     if(empty($id)) $id = $file['name'];
 
+    // check for data
+    if(!@filesize($file['tmp_name'])){
+        msg('No data uploaded. Disk full?',-1);
+        return false;
+    }
+
     // check extensions
-    list($fext,$fmime) = mimetype($file['name']);
-    list($iext,$imime) = mimetype($id);
+    list($fext,$fmime,$dl) = mimetype($file['name']);
+    list($iext,$imime,$dl) = mimetype($id);
     if($fext && !$iext){
         // no extension specified in id - read original one
         $id   .= '.'.$fext;
@@ -228,7 +258,7 @@ function media_upload($ns,$auth){
     }
 
     // get filename
-    $id   = cleanID($ns.':'.$id);
+    $id   = cleanID($ns.':'.$id,false,true);
     $fn   = mediaFN($id);
 
     // get filetype regexp
@@ -239,7 +269,8 @@ function media_upload($ns,$auth){
     // because a temp file was created already
     if(preg_match('/\.('.$regex.')$/i',$fn)){
         //check for overwrite
-        if(@file_exists($fn) && (!$_POST['ow'] || $auth < AUTH_DELETE)){
+        $overwrite = @file_exists($fn);
+        if($overwrite && (!$_REQUEST['ow'] || $auth < AUTH_DELETE)){
             msg($lang['uploadexist'],0);
             return false;
         }
@@ -261,6 +292,7 @@ function media_upload($ns,$auth){
         $data[1] = $fn;
         $data[2] = $id;
         $data[3] = $imime;
+        $data[4] = $overwrite;
 
         // trigger event
         return trigger_event('MEDIA_UPLOAD_FINISH', $data, '_media_upload_action', true);
@@ -277,8 +309,8 @@ function media_upload($ns,$auth){
  */
 function _media_upload_action($data) {
     // fixme do further sanity tests of given data?
-    if(is_array($data) && count($data)===4) {
-        return media_upload_finish($data[0], $data[1], $data[2], $data[3]);
+    if(is_array($data) && count($data)===5) {
+        return media_upload_finish($data[0], $data[1], $data[2], $data[3], $data[4]);
     } else {
         return false; //callback error
     }
@@ -290,7 +322,7 @@ function _media_upload_action($data) {
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Michael Klier <chi@chimeric.de>
  */
-function media_upload_finish($fn_tmp, $fn, $id, $imime) {
+function media_upload_finish($fn_tmp, $fn, $id, $imime, $overwrite) {
     global $conf;
     global $lang;
 
@@ -304,6 +336,12 @@ function media_upload_finish($fn_tmp, $fn, $id, $imime) {
         chmod($fn, $conf['fmode']);
         msg($lang['uploadsucc'],1);
         media_notify($id,$fn,$imime);
+        // add a log entry to the media changelog
+        if ($overwrite) {
+            addMediaLogEntry(time(), $id, DOKU_CHANGE_TYPE_EDIT);
+        } else {
+            addMediaLogEntry(time(), $id, DOKU_CHANGE_TYPE_CREATE);
+        }
         return $id;
     }else{
         msg($lang['uploadfail'],-1);
@@ -439,12 +477,8 @@ function media_fileactions($item,$auth){
 
     // delete button
     if($auth >= AUTH_DELETE){
-        $ask  = addslashes($lang['del_confirm']).'\\n';
-        $ask .= addslashes($item['id']);
-
         echo ' <a href="'.DOKU_BASE.'lib/exe/mediamanager.php?delete='.rawurlencode($item['id']).
-             '&amp;sectok='.getSecurityToken().'" '.
-             'onclick="return confirm(\''.$ask.'\')" onkeypress="return confirm(\''.$ask.'\')">'.
+             '&amp;sectok='.getSecurityToken().'" class="btn_media_delete" title="'.$item['id'].'">'.
              '<img src="'.DOKU_BASE.'lib/images/trash.png" alt="'.$lang['btn_delete'].'" '.
              'title="'.$lang['btn_delete'].'" class="btn" /></a>';
     }
@@ -479,7 +513,7 @@ function media_printfile($item,$auth,$jump){
     }
 
     // Prepare fileicons
-    list($ext,$mime) = mimetype($item['file']);
+    list($ext,$mime,$dl) = mimetype($item['file']);
     $class = preg_replace('/[^_\-a-z0-9]+/i','_',$ext);
     $class = 'select mediafile mf_'.$class;
 
@@ -540,12 +574,12 @@ function media_printimgdetail($item){
     echo '</div>';
 
     // read EXIF/IPTC data
-    $t = $item['meta']->getField('IPTC.Headline');
+    $t = $item['meta']->getField(array('IPTC.Headline','xmp.dc:title'));
     $d = $item['meta']->getField(array('IPTC.Caption','EXIF.UserComment',
                                        'EXIF.TIFFImageDescription',
                                        'EXIF.TIFFUserComment'));
     if(utf8_strlen($d) > 250) $d = utf8_substr($d,0,250).'...';
-    $k = $item['meta']->getField(array('IPTC.Keywords','IPTC.Category'));
+    $k = $item['meta']->getField(array('IPTC.Keywords','IPTC.Category','xmp.dc:subject'));
 
     // print EXIF/IPTC data
     if($t || $d || $k ){
@@ -568,8 +602,9 @@ function media_uploadform($ns, $auth){
 
     if($auth < AUTH_UPLOAD) return; //fixme print info on missing permissions?
 
-    print '<div class="upload">' . $lang['mediaupload'] . '</div>';
+    // The default HTML upload form
     $form = new Doku_Form('dw__upload', DOKU_BASE.'lib/exe/mediamanager.php', false, 'multipart/form-data');
+    $form->addElement('<div class="upload">' . $lang['mediaupload'] . '</div>');
     $form->addElement(formSecurityToken());
     $form->addHidden('ns', hsc($ns));
     $form->addElement(form_makeOpenTag('p'));
@@ -585,8 +620,41 @@ function media_uploadform($ns, $auth){
       $form->addElement(form_makeCheckboxField('ow', 1, $lang['txt_overwrt'], 'dw__ow', 'check'));
       $form->addElement(form_makeCloseTag('p'));
     }
-
     html_form('upload', $form);
+
+    // prepare flashvars for multiupload
+    $opt = array(
+        'L_gridname'  => $lang['mu_gridname'] ,
+        'L_gridsize'  => $lang['mu_gridsize'] ,
+        'L_gridstat'  => $lang['mu_gridstat'] ,
+        'L_namespace' => $lang['mu_namespace'] ,
+        'L_overwrite' => $lang['txt_overwrt'],
+        'L_browse'    => $lang['mu_browse'],
+        'L_upload'    => $lang['btn_upload'],
+        'L_toobig'    => $lang['mu_toobig'],
+        'L_ready'     => $lang['mu_ready'],
+        'L_done'      => $lang['mu_done'],
+        'L_fail'      => $lang['mu_fail'],
+        'L_authfail'  => $lang['mu_authfail'],
+        'L_progress'  => $lang['mu_progress'],
+        'L_filetypes' => $lang['mu_filetypes'],
+
+        'O_ns'        => ":$ns",
+        'O_backend'   => 'mediamanager.php?'.session_name().'='.session_id(),
+        'O_size'      => php_to_byte(ini_get('upload_max_filesize')),
+        'O_extensions'=> join('|',array_keys(getMimeTypes())),
+        'O_overwrite' => ($auth >= AUTH_DELETE),
+        'O_sectok'    => getSecurityToken(),
+        'O_authtok'   => auth_createToken(),
+    );
+    $var = buildURLparams($opt);
+    // output the flash uploader
+    ?>
+    <div id="dw__flashupload" style="display:none">
+    <div class="upload"><?php echo $lang['mu_intro']?></div>
+    <?php echo html_flashobject('multipleUpload.swf','500','190',null,$opt); ?>
+    </div>
+    <?php
 }
 
 /**
@@ -661,3 +729,309 @@ function media_nstree_li($item){
     return '<li class="'.$class.'">'.
            '<img src="'.$img.'" alt="'.$alt.'" />';
 }
+
+/**
+ * Resizes the given image to the given size
+ *
+ * @author  Andreas Gohr <andi@splitbrain.org>
+ */
+function media_resize_image($file, $ext, $w, $h=0){
+  global $conf;
+
+  $info = @getimagesize($file); //get original size
+  if($info == false) return $file; // that's no image - it's a spaceship!
+
+  if(!$h) $h = round(($w * $info[1]) / $info[0]);
+
+  // we wont scale up to infinity
+  if($w > 2000 || $h > 2000) return $file;
+
+  //cache
+  $local = getCacheName($file,'.media.'.$w.'x'.$h.'.'.$ext);
+  $mtime = @filemtime($local); // 0 if not exists
+
+  if( $mtime > filemtime($file) ||
+      media_resize_imageIM($ext,$file,$info[0],$info[1],$local,$w,$h) ||
+      media_resize_imageGD($ext,$file,$info[0],$info[1],$local,$w,$h) ){
+    if($conf['fperm']) chmod($local, $conf['fperm']);
+    return $local;
+  }
+  //still here? resizing failed
+  return $file;
+}
+
+/**
+ * Crops the given image to the wanted ratio, then calls media_resize_image to scale it
+ * to the wanted size
+ *
+ * Crops are centered horizontally but prefer the upper third of an vertical
+ * image because most pics are more interesting in that area (rule of thirds)
+ *
+ * @author  Andreas Gohr <andi@splitbrain.org>
+ */
+function media_crop_image($file, $ext, $w, $h=0){
+  global $conf;
+
+  if(!$h) $h = $w;
+  $info = @getimagesize($file); //get original size
+  if($info == false) return $file; // that's no image - it's a spaceship!
+
+  // calculate crop size
+  $fr = $info[0]/$info[1];
+  $tr = $w/$h;
+  if($tr >= 1){
+    if($tr > $fr){
+        $cw = $info[0];
+        $ch = (int) $info[0]/$tr;
+    }else{
+        $cw = (int) $info[1]*$tr;
+        $ch = $info[1];
+    }
+  }else{
+    if($tr < $fr){
+        $cw = (int) $info[1]*$tr;
+        $ch = $info[1];
+    }else{
+        $cw = $info[0];
+        $ch = (int) $info[0]/$tr;
+    }
+  }
+  // calculate crop offset
+  $cx = (int) ($info[0]-$cw)/2;
+  $cy = (int) ($info[1]-$ch)/3;
+
+  //cache
+  $local = getCacheName($file,'.media.'.$cw.'x'.$ch.'.crop.'.$ext);
+  $mtime = @filemtime($local); // 0 if not exists
+
+  if( $mtime > filemtime($file) ||
+      media_crop_imageIM($ext,$file,$info[0],$info[1],$local,$cw,$ch,$cx,$cy) ||
+      media_resize_imageGD($ext,$file,$cw,$ch,$local,$cw,$ch,$cx,$cy) ){
+    if($conf['fperm']) chmod($local, $conf['fperm']);
+    return media_resize_image($local,$ext, $w, $h);
+  }
+
+  //still here? cropping failed
+  return media_resize_image($file,$ext, $w, $h);
+}
+
+/**
+ * Download a remote file and return local filename
+ *
+ * returns false if download fails. Uses cached file if available and
+ * wanted
+ *
+ * @author  Andreas Gohr <andi@splitbrain.org>
+ * @author  Pavel Vitis <Pavel.Vitis@seznam.cz>
+ */
+function media_get_from_URL($url,$ext,$cache){
+  global $conf;
+
+  // if no cache or fetchsize just redirect
+  if ($cache==0)           return false;
+  if (!$conf['fetchsize']) return false;
+
+  $local = getCacheName(strtolower($url),".media.$ext");
+  $mtime = @filemtime($local); // 0 if not exists
+
+  //decide if download needed:
+  if( ($mtime == 0) ||                           // cache does not exist
+      ($cache != -1 && $mtime < time()-$cache)   // 'recache' and cache has expired
+    ){
+      if(media_image_download($url,$local)){
+        return $local;
+      }else{
+        return false;
+      }
+  }
+
+  //if cache exists use it else
+  if($mtime) return $local;
+
+  //else return false
+  return false;
+}
+
+/**
+ * Download image files
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function media_image_download($url,$file){
+  global $conf;
+  $http = new DokuHTTPClient();
+  $http->max_bodysize = $conf['fetchsize'];
+  $http->timeout = 25; //max. 25 sec
+  $http->header_regexp = '!\r\nContent-Type: image/(jpe?g|gif|png)!i';
+
+  $data = $http->get($url);
+  if(!$data) return false;
+
+  $fileexists = @file_exists($file);
+  $fp = @fopen($file,"w");
+  if(!$fp) return false;
+  fwrite($fp,$data);
+  fclose($fp);
+  if(!$fileexists and $conf['fperm']) chmod($file, $conf['fperm']);
+
+  // check if it is really an image
+  $info = @getimagesize($file);
+  if(!$info){
+    @unlink($file);
+    return false;
+  }
+
+  return true;
+}
+
+/**
+ * resize images using external ImageMagick convert program
+ *
+ * @author Pavel Vitis <Pavel.Vitis@seznam.cz>
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function media_resize_imageIM($ext,$from,$from_w,$from_h,$to,$to_w,$to_h){
+  global $conf;
+
+  // check if convert is configured
+  if(!$conf['im_convert']) return false;
+
+  // prepare command
+  $cmd  = $conf['im_convert'];
+  $cmd .= ' -resize '.$to_w.'x'.$to_h.'!';
+  if ($ext == 'jpg' || $ext == 'jpeg') {
+      $cmd .= ' -quality '.$conf['jpg_quality'];
+  }
+  $cmd .= " $from $to";
+
+  @exec($cmd,$out,$retval);
+  if ($retval == 0) return true;
+  return false;
+}
+
+/**
+ * crop images using external ImageMagick convert program
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function media_crop_imageIM($ext,$from,$from_w,$from_h,$to,$to_w,$to_h,$ofs_x,$ofs_y){
+  global $conf;
+
+  // check if convert is configured
+  if(!$conf['im_convert']) return false;
+
+  // prepare command
+  $cmd  = $conf['im_convert'];
+  $cmd .= ' -crop '.$to_w.'x'.$to_h.'+'.$ofs_x.'+'.$ofs_y;
+  if ($ext == 'jpg' || $ext == 'jpeg') {
+      $cmd .= ' -quality '.$conf['jpg_quality'];
+  }
+  $cmd .= " $from $to";
+
+  @exec($cmd,$out,$retval);
+  if ($retval == 0) return true;
+  return false;
+}
+
+/**
+ * resize or crop images using PHP's libGD support
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ * @author Sebastian Wienecke <s_wienecke@web.de>
+ */
+function media_resize_imageGD($ext,$from,$from_w,$from_h,$to,$to_w,$to_h,$ofs_x=0,$ofs_y=0){
+  global $conf;
+
+  if($conf['gdlib'] < 1) return false; //no GDlib available or wanted
+
+  // check available memory
+  if(!is_mem_available(($from_w * $from_h * 4) + ($to_w * $to_h * 4))){
+    return false;
+  }
+
+  // create an image of the given filetype
+  if ($ext == 'jpg' || $ext == 'jpeg'){
+    if(!function_exists("imagecreatefromjpeg")) return false;
+    $image = @imagecreatefromjpeg($from);
+  }elseif($ext == 'png') {
+    if(!function_exists("imagecreatefrompng")) return false;
+    $image = @imagecreatefrompng($from);
+
+  }elseif($ext == 'gif') {
+    if(!function_exists("imagecreatefromgif")) return false;
+    $image = @imagecreatefromgif($from);
+  }
+  if(!$image) return false;
+
+  if(($conf['gdlib']>1) && function_exists("imagecreatetruecolor") && $ext != 'gif'){
+    $newimg = @imagecreatetruecolor ($to_w, $to_h);
+  }
+  if(!$newimg) $newimg = @imagecreate($to_w, $to_h);
+  if(!$newimg){
+    imagedestroy($image);
+    return false;
+  }
+
+  //keep png alpha channel if possible
+  if($ext == 'png' && $conf['gdlib']>1 && function_exists('imagesavealpha')){
+    imagealphablending($newimg, false);
+    imagesavealpha($newimg,true);
+  }
+
+  //keep gif transparent color if possible
+  if($ext == 'gif' && function_exists('imagefill') && function_exists('imagecolorallocate')) {
+    if(function_exists('imagecolorsforindex') && function_exists('imagecolortransparent')) {
+      $transcolorindex = @imagecolortransparent($image);
+      if($transcolorindex >= 0 ) { //transparent color exists
+        $transcolor = @imagecolorsforindex($image, $transcolorindex);
+        $transcolorindex = @imagecolorallocate($newimg, $transcolor['red'], $transcolor['green'], $transcolor['blue']);
+        @imagefill($newimg, 0, 0, $transcolorindex);
+        @imagecolortransparent($newimg, $transcolorindex);
+      }else{ //filling with white
+        $whitecolorindex = @imagecolorallocate($newimg, 255, 255, 255);
+        @imagefill($newimg, 0, 0, $whitecolorindex);
+      }
+    }else{ //filling with white
+      $whitecolorindex = @imagecolorallocate($newimg, 255, 255, 255);
+      @imagefill($newimg, 0, 0, $whitecolorindex);
+    }
+  }
+
+  //try resampling first
+  if(function_exists("imagecopyresampled")){
+    if(!@imagecopyresampled($newimg, $image, 0, 0, $ofs_x, $ofs_y, $to_w, $to_h, $from_w, $from_h)) {
+      imagecopyresized($newimg, $image, 0, 0, $ofs_x, $ofs_y, $to_w, $to_h, $from_w, $from_h);
+    }
+  }else{
+    imagecopyresized($newimg, $image, 0, 0, $ofs_x, $ofs_y, $to_w, $to_h, $from_w, $from_h);
+  }
+
+  $okay = false;
+  if ($ext == 'jpg' || $ext == 'jpeg'){
+    if(!function_exists('imagejpeg')){
+      $okay = false;
+    }else{
+      $okay = imagejpeg($newimg, $to, $conf['jpg_quality']);
+    }
+  }elseif($ext == 'png') {
+    if(!function_exists('imagepng')){
+      $okay = false;
+    }else{
+      $okay =  imagepng($newimg, $to);
+    }
+  }elseif($ext == 'gif') {
+    if(!function_exists('imagegif')){
+      $okay = false;
+    }else{
+      $okay = imagegif($newimg, $to);
+    }
+  }
+
+  // destroy GD image ressources
+  if($image) imagedestroy($image);
+  if($newimg) imagedestroy($newimg);
+
+  return $okay;
+}
+
+/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
