@@ -68,7 +68,7 @@ function getID($param='id',$clean=true){
       // fall back to default
       $id = $id.$conf['start'];
     }
-    header("Location: ".wl($id,'',true));
+    send_redirect(wl($id,'',true));
   }
 
   if($clean) $id = cleanID($id);
@@ -86,8 +86,9 @@ function getID($param='id',$clean=true){
  * @author Andreas Gohr <andi@splitbrain.org>
  * @param  string  $raw_id    The pageid to clean
  * @param  boolean $ascii     Force ASCII
+ * @param  boolean $media     Allow leading or trailing _ for media files
  */
-function cleanID($raw_id,$ascii=false){
+function cleanID($raw_id,$ascii=false,$media=false){
   global $conf;
   global $lang;
   static $sepcharpat = null;
@@ -96,15 +97,15 @@ function cleanID($raw_id,$ascii=false){
   $cache = & $cache_cleanid;
 
   // check if it's already in the memory cache
-  if (isset($cache[$raw_id])) {
-    return $cache[$raw_id];
+  if (isset($cache[(string)$raw_id])) {
+    return $cache[(string)$raw_id];
     }
 
   $sepchar = $conf['sepchar'];
   if($sepcharpat == null) // build string only once to save clock cycles
     $sepcharpat = '#\\'.$sepchar.'+#';
 
-  $id = trim($raw_id);
+  $id = trim((string)$raw_id);
   $id = utf8_strtolower($id);
 
   //alternative namespace seperator
@@ -126,10 +127,10 @@ function cleanID($raw_id,$ascii=false){
   //clean up
   $id = preg_replace($sepcharpat,$sepchar,$id);
   $id = preg_replace('#:+#',':',$id);
-  $id = trim($id,':._-');
+  $id = ($media ? trim($id,':.-') : trim($id,':._-'));
   $id = preg_replace('#:[:\._\-]+#',':',$id);
 
-  $cache[$raw_id] = $id;
+  $cache[(string)$raw_id] = $id;
   return($id);
 }
 
@@ -139,9 +140,9 @@ function cleanID($raw_id,$ascii=false){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function getNS($id){
-  $pos = strrpos($id,':');
+  $pos = strrpos((string)$id,':');
   if($pos!==false){
-    return substr($id,0,$pos);
+    return substr((string)$id,0,$pos);
   }
   return false;
 }
@@ -161,19 +162,19 @@ function noNS($id) {
 }
 
 /**
-* Returns the current namespace
-*
-* @author Nathan Fritz <fritzn@crown.edu>
-*/
+ * Returns the current namespace
+ *
+ * @author Nathan Fritz <fritzn@crown.edu>
+ */
 function curNS($id) {
     return noNS(getNS($id));
 }
 
 /**
-* Returns the ID without the namespace or current namespace for 'start' pages
-*
-* @author Nathan Fritz <fritzn@crown.edu>
-*/
+ * Returns the ID without the namespace or current namespace for 'start' pages
+ *
+ * @author Nathan Fritz <fritzn@crown.edu>
+ */
 function noNSorNS($id) {
     global $conf;
 
@@ -187,6 +188,36 @@ function noNSorNS($id) {
     return $p;
 }
 
+/**
+ * Creates a XHTML valid linkid from a given headline title
+ *
+ * @param string  $title   The headline title
+ * @param array   $check   List of existing IDs
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function sectionID($title,&$check) {
+    $title = str_replace(':','',cleanID($title));
+    $new = ltrim($title,'0123456789._-');
+    if(empty($new)){
+        $title = 'section'.preg_replace('/[^0-9]+/','',$title); //keep numbers from headline
+    }else{
+        $title = $new;
+    }
+
+    if(is_array($check)){
+        // make sure tiles are unique
+        $num = '';
+        while(in_array($title.$num,$check)){
+            ($num) ? $num++ : $num = 1;
+        }
+        $title = $title.$num;
+        $check[] = $title;
+    }
+
+    return $title;
+}
+
+
 /**
  *  Wiki page existence check
  *
@@ -478,7 +509,9 @@ function getCacheName($data,$ext=''){
  */
 function isHiddenPage($id){
   global $conf;
+  global $ACT;
   if(empty($conf['hidepages'])) return false;
+  if($ACT == 'admin') return false;
 
   if(preg_match('/'.$conf['hidepages'].'/ui',':'.$id)){
     return true;
@@ -501,7 +534,7 @@ function isVisiblePage($id){
  * @author   Simon Willison <swillison@gmail.com>
  * @link     http://simon.incutio.com/archive/2003/04/23/conditionalGet
  * @param    timestamp $timestamp lastmodified time of the cache file
- * @returns  void or void with previously header() commands executed
+ * @returns  void or exits with previously header() commands executed
  */
 function http_conditionalRequest($timestamp){
   // A PHP implementation of conditional get, see
@@ -545,4 +578,47 @@ function http_conditionalRequest($timestamp){
   exit;
 }
 
+/**
+ * Let the webserver send the given file vi x-sendfile method
+ *
+ * @author Chris Smith <chris.eureka@jalakai.co.uk>
+ * @returns  void or exits with previously header() commands executed
+ */
+function http_sendfile($file) {
+  global $conf;
+
+  //use x-sendfile header to pass the delivery to compatible webservers
+  if($conf['xsendfile'] == 1){
+    header("X-LIGHTTPD-send-file: $file");
+    ob_end_clean();
+    exit;
+  }elseif($conf['xsendfile'] == 2){
+    header("X-Sendfile: $file");
+    ob_end_clean();
+    exit;
+  }elseif($conf['xsendfile'] == 3){
+    header("X-Accel-Redirect: $file");
+    ob_end_clean();
+    exit;
+  }
+
+  return false;
+}
+
+/**
+ * Check for a gzipped version and create if necessary
+ *
+ * return true if there exists a gzip version of the uncompressed file
+ * (samepath/samefilename.sameext.gz) created after the uncompressed file
+ *
+ * @author Chris Smith <chris.eureka@jalakai.co.uk>
+ */
+function http_gzip_valid($uncompressed_file) {
+  $gzip = $uncompressed_file.'.gz';
+  if (filemtime($gzip) < filemtime($uncompressed_file)) {    // filemtime returns false (0) if file doesn't exist
+    return copy($uncompressed_file, 'compress.zlib://'.$gzip);
+  }
+
+  return true;
+}
 //Setup VIM: ex: et ts=2 enc=utf-8 :
