@@ -1,6 +1,5 @@
 <?php
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../../').'/');
-
+if(!defined('DOKU_INC')) die('meh.');
 if (!defined('DOKU_PARSER_EOL')) define('DOKU_PARSER_EOL',"\n");   // add this to make handling test cases simpler
 
 class Doku_Handler {
@@ -29,8 +28,8 @@ class Doku_Handler {
         $this->CallWriter->writeCall($call);
     }
 
-    function addPluginCall($plugin, $args, $state, $pos) {
-        $call = array('plugin',array($plugin, $args, $state), $pos);
+    function addPluginCall($plugin, $args, $state, $pos, $match) {
+        $call = array('plugin',array($plugin, $args, $state, $match), $pos);
         $this->CallWriter->writeCall($call);
     }
 
@@ -82,7 +81,9 @@ class Doku_Handler {
         if($plugin != null){
             $data = $plugin->handle($match, $state, $pos, $this);
         }
-        $this->addPluginCall($pluginname,$data,$state,$pos);
+        if ($data !== false) {
+          $this->addPluginCall($pluginname,$data,$state,$pos,$match);
+        }
         return true;
     }
 
@@ -92,7 +93,6 @@ class Doku_Handler {
                 $this->_addCall('cdata',array($match), $pos);
                 return true;
             break;
-
         }
     }
 
