@@ -1,7 +1,5 @@
 <?php
-
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../../').'/');
-
+if(!defined('DOKU_INC')) die('meh.');
 require_once DOKU_INC . 'inc/parser/lexer.php';
 require_once DOKU_INC . 'inc/parser/handler.php';
 
@@ -310,7 +308,7 @@ class Doku_Parser_Mode_formatting extends Doku_Parser_Mode {
             ),
 
         'emphasis'=> array (
-            'entry'=>'//(?=[^\x00]*[^:]//)', //hack for bug #384
+            'entry'=>'//(?=[^\x00]*[^:])', //hack for bugs #384 #763 #1468
             'exit'=>'//',
             'sort'=>80
             ),
@@ -652,7 +650,7 @@ class Doku_Parser_Mode_smiley extends Doku_Parser_Mode {
 
         $sep = '';
         foreach ( $this->smileys as $smiley ) {
-            $this->pattern .= $sep.Doku_Lexer_Escape($smiley);
+            $this->pattern .= $sep.'(?<=\W|^)'.Doku_Lexer_Escape($smiley).'(?=\W|$)';
             $sep = '|';
         }
     }
@@ -845,7 +843,7 @@ class Doku_Parser_Mode_rss extends Doku_Parser_Mode {
 
 //-------------------------------------------------------------------
 class Doku_Parser_Mode_externallink extends Doku_Parser_Mode {
-    var $schemes = array('http','https','telnet','gopher','wais','ftp','ed2k','irc','ldap');
+    var $schemes = array();
     var $patterns = array();
 
     function preConnect() {
@@ -857,13 +855,13 @@ class Doku_Parser_Mode_externallink extends Doku_Parser_Mode {
         $host = $ltrs.$punc;
         $any  = $ltrs.$gunk.$punc;
 
+        $this->schemes = getSchemes();
         foreach ( $this->schemes as $scheme ) {
             $this->patterns[] = '\b(?i)'.$scheme.'(?-i)://['.$any.']+?(?=['.$punc.']*[^'.$any.'])';
         }
 
         $this->patterns[] = '\b(?i)www?(?-i)\.['.$host.']+?\.['.$host.']+?['.$any.']+?(?=['.$punc.']*[^'.$any.'])';
         $this->patterns[] = '\b(?i)ftp?(?-i)\.['.$host.']+?\.['.$host.']+?['.$any.']+?(?=['.$punc.']*[^'.$any.'])';
-
     }
 
     function connectTo($mode) {
