@@ -5,8 +5,7 @@
  * @author Harry Fuecks <hfuecks@gmail.com>
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-
-if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../../').'/');
+if(!defined('DOKU_INC')) die('meh.');
 
 if ( !defined('DOKU_LF') ) {
     // Some whitespace to help View > Source
@@ -85,7 +84,8 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         }
 
         // Prepare the TOC
-        if($this->info['toc'] && is_array($this->toc) && count($this->toc) > 2){
+        global $conf;
+        if($this->info['toc'] && is_array($this->toc) && $conf['tocminheads'] && count($this->toc) >= $conf['tocminheads']){
             global $TOC;
             $TOC = $this->toc;
         }
@@ -104,6 +104,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     }
 
     function header($text, $level, $pos) {
+        if(!$text) return; //skip empty headlines
 
         $hid = $this->_headerToLink($text,true);
 
@@ -472,12 +473,12 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     /**
      * Render an internal Wiki Link
      *
-     * $search and $returnonly are not for the renderer but are used
+     * $search,$returnonly & $linktype are not for the renderer but are used
      * elsewhere - no need to implement them in other renderers
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function internallink($id, $name = NULL, $search=NULL,$returnonly=false) {
+    function internallink($id, $name = NULL, $search=NULL,$returnonly=false,$linktype='content') {
         global $conf;
         global $ID;
         // default name is based on $id as given
@@ -485,7 +486,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
 
         // now first resolve and clean up the $id
         resolve_pageid(getNS($ID),$id,$exists);
-        $name = $this->_getLinkTitle($name, $default, $isImage, $id);
+        $name = $this->_getLinkTitle($name, $default, $isImage, $id, $linktype);
         if ( !$isImage ) {
             if ( $exists ) {
                 $class='wikilink1';
@@ -579,7 +580,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $link['name']   = $this->_getLinkTitle($name, $wikiUri, $isImage);
 
         //get interwiki URL
-        $url = $this-> _resolveInterWiki($wikiName,$wikiUri);
+        $url = $this->_resolveInterWiki($wikiName,$wikiUri);
 
         if ( !$isImage ) {
             $class = preg_replace('/[^_\-a-z0-9]+/i','_',$wikiName);
@@ -610,11 +611,6 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $link['pre']    = '';
         $link['suf']   = '';
         $link['style']  = '';
-        //Display error on browsers other than IE
-        $link['more'] = 'onclick="if(document.all == null){alert(\''.
-                        str_replace('\\\\n','\\n',addslashes($lang['nosmblinks'])).
-                        '\');}" onkeypress="if(document.all == null){alert(\''.
-                        str_replace('\\\\n','\\n',addslashes($lang['nosmblinks'])).'\');}"';
 
         $link['name'] = $this->_getLinkTitle($name, $url, $isImage);
         if ( !$isImage ) {
@@ -643,7 +639,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $link['style']  = '';
         $link['more']   = '';
 
-        $name = $this->_getLinkTitle($name, '', $isImage);
+        $name = $this->_getLinkTitle($name, $address, $isImage);
         if ( !$isImage ) {
             $link['class']='mail JSnocheck';
         } else {
@@ -674,16 +670,17 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
     function internalmedia ($src, $title=NULL, $align=NULL, $width=NULL,
                             $height=NULL, $cache=NULL, $linking=NULL) {
         global $ID;
+        list($src,$hash) = explode('#',$src,2);
         resolve_mediaid(getNS($ID),$src, $exists);
 
         $noLink = false;
         $render = ($linking == 'linkonly') ? false : true;
         $link = $this->_getMediaLinkConf($src, $title, $align, $width, $height, $cache, $render);
 
-        list($ext,$mime) = mimetype($src);
+        list($ext,$mime,$dl) = mimetype($src);
         if(substr($mime,0,5) == 'image' && $render){
             $link['url'] = ml($src,array('id'=>$ID,'cache'=>$cache),($linking=='direct'));
-        }elseif($mime == 'application/x-shockwave-flash'){
+        }elseif($mime == 'application/x-shockwave-flash' && $render){
             // don't link flash movies
             $noLink = true;
         }else{
@@ -693,33 +690,39 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
             $link['url'] = ml($src,array('id'=>$ID,'cache'=>$cache),true);
         }
 
+        if($hash) $link['url'] .= '#'.$hash;
+
+        //markup non existing files
+        if (!$exists)
+          $link['class'] .= ' wikilink2';
+
         //output formatted
         if ($linking == 'nolink' || $noLink) $this->doc .= $link['name'];
         else $this->doc .= $this->_formatLink($link);
     }
 
-    /**
-     * @todo don't add link for flash
-     */
     function externalmedia ($src, $title=NULL, $align=NULL, $width=NULL,
                             $height=NULL, $cache=NULL, $linking=NULL) {
+        list($src,$hash) = explode('#',$src,2);
         $noLink = false;
         $render = ($linking == 'linkonly') ? false : true;
         $link = $this->_getMediaLinkConf($src, $title, $align, $width, $height, $cache, $render);
 
         $link['url']    = ml($src,array('cache'=>$cache));
 
-        list($ext,$mime) = mimetype($src);
+        list($ext,$mime,$dl) = mimetype($src);
         if(substr($mime,0,5) == 'image' && $render){
              // link only jpeg images
              // if ($ext != 'jpg' && $ext != 'jpeg') $noLink = true;
-        }elseif($mime == 'application/x-shockwave-flash'){
+        }elseif($mime == 'application/x-shockwave-flash' && $render){
              // don't link flash movies
              $noLink = true;
         }else{
              // add file icons
              $link['class'] .= ' mediafile mf_'.$ext;
-         }
+        }
+
+        if($hash) $link['url'] .= '#'.$hash;
 
         //output formatted
         if ($linking == 'nolink' || $noLink) $this->doc .= $link['name'];
@@ -762,8 +765,14 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
             for ($x = $start; $x != $end; $x += $mod) {
                 $item = $feed->get_item($x);
                 $this->doc .= '<li><div class="li">';
-                $this->externallink($item->get_permalink(),
-                                    $item->get_title());
+                // support feeds without links
+                $lnkurl = $item->get_permalink();
+                if($lnkurl){
+                    $this->externallink($item->get_permalink(),
+                                        $item->get_title());
+                }else{
+                    $this->doc .= ' '.$item->get_title();
+                }
                 if($params['author']){
                     $author = $item->get_author(0);
                     if($author){
@@ -829,7 +838,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $class .= '"';
         $this->doc .= '<th ' . $class;
         if ( $colspan > 1 ) {
-            $this->_counter['cell_counter'] += $colspan;
+            $this->_counter['cell_counter'] += $colspan-1;
             $this->doc .= ' colspan="'.$colspan.'"';
         }
         $this->doc .= '>';
@@ -847,7 +856,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
         $class .= '"';
         $this->doc .= '<td '.$class;
         if ( $colspan > 1 ) {
-            $this->_counter['cell_counter'] += $colspan;
+            $this->_counter['cell_counter'] += $colspan-1;
             $this->doc .= ' colspan="'.$colspan.'"';
         }
         $this->doc .= '>';
@@ -907,7 +916,7 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
 
         $ret = '';
 
-        list($ext,$mime) = mimetype($src);
+        list($ext,$mime,$dl) = mimetype($src);
         if(substr($mime,0,5) == 'image'){
             // first get the $title
             if (!is_null($title)) {
@@ -954,21 +963,25 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
             $ret .= ' />';
 
         }elseif($mime == 'application/x-shockwave-flash'){
-            $ret .= '<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"'.
-                    ' codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,40,0"';
-            if ( !is_null($width) ) $ret .= ' width="'.$this->_xmlEntities($width).'"';
-            if ( !is_null($height) ) $ret .= ' height="'.$this->_xmlEntities($height).'"';
-            $ret .= '>'.DOKU_LF;
-            $ret .= '<param name="movie" value="'.ml($src).'" />'.DOKU_LF;
-            $ret .= '<param name="quality" value="high" />'.DOKU_LF;
-            $ret .= '<embed src="'.ml($src).'"'.
-                    ' quality="high"';
-            if ( !is_null($width) ) $ret .= ' width="'.$this->_xmlEntities($width).'"';
-            if ( !is_null($height) ) $ret .= ' height="'.$this->_xmlEntities($height).'"';
-            $ret .= ' type="application/x-shockwave-flash"'.
-                    ' pluginspage="http://www.macromedia.com/go/getflashplayer"></embed>'.DOKU_LF;
-            $ret .= '</object>'.DOKU_LF;
+            if (!$render) {
+                // if the flash is not supposed to be rendered
+                // return the title of the flash
+                if (!$title) {
+                    // just show the sourcename
+                    $title = basename(noNS($src));
+                }
+                return $this->_xmlEntities($title);
+            }
 
+            $att = array();
+            $att['class'] = "media$align";
+            if($align == 'right') $att['align'] = 'right';
+            if($align == 'left')  $att['align'] = 'left';
+            $ret .= html_flashobject(ml($src,array('cache'=>$cache)),$width,$height,
+                                     array('quality' => 'high'),
+                                     null,
+                                     $att,
+                                     $this->_xmlEntities($title));
         }elseif($title){
             // well at least we have a title to display
             $ret .= $this->_xmlEntities($title);
@@ -992,21 +1005,12 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
      * @author Andreas Gohr <andi@splitbrain.org>
      */
     function _headerToLink($title,$create=false) {
-        $title = str_replace(':','',cleanID($title));
-        $title = ltrim($title,'0123456789._-');
-        if(empty($title)) $title='section';
-
         if($create){
-            // make sure tiles are unique
-            $num = '';
-            while(in_array($title.$num,$this->headers)){
-                ($num) ? $num++ : $num = 1;
-            }
-            $title = $title.$num;
-            $this->headers[] = $title;
+            return sectionID($title,$this->headers);
+        }else{
+            $check = false;
+            return sectionID($title,$check);
         }
-
-        return $title;
     }
 
     /**
@@ -1014,12 +1018,12 @@ class Doku_Renderer_xhtml extends Doku_Renderer {
      *
      * @author Harry Fuecks <hfuecks@gmail.com>
      */
-    function _getLinkTitle($title, $default, & $isImage, $id=NULL) {
+    function _getLinkTitle($title, $default, & $isImage, $id=NULL, $linktype='content') {
         global $conf;
 
         $isImage = false;
-        if ( is_null($title) ) {
-            if ($conf['useheading'] && $id) {
+        if ( is_null($title) || trim($title)=='') {
+            if (useHeading($linktype) && $id) {
                 $heading = p_get_first_heading($id,true);
                 if ($heading) {
                     return $this->_xmlEntities($heading);
