@@ -7,12 +7,11 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-  if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
-
-  require_once(DOKU_INC.'inc/confutils.php');
-  require_once(DOKU_INC.'inc/pageutils.php');
-  require_once(DOKU_INC.'inc/pluginutils.php');
-  require_once(DOKU_INC.'inc/cache.php');
+if(!defined('DOKU_INC')) die('meh.');
+require_once(DOKU_INC.'inc/confutils.php');
+require_once(DOKU_INC.'inc/pageutils.php');
+require_once(DOKU_INC.'inc/pluginutils.php');
+require_once(DOKU_INC.'inc/cache.php');
 
 /**
  * Returns the parsed Wikitext in XHTML for the given id and revision.
@@ -359,7 +358,7 @@ function p_purge_metadata($id) {
 function p_read_metadata($id,$cache=false) {
   global $cache_metadata;
 
-  if (isset($cache_metadata[$id])) return $cache_metadata[$id];
+  if (isset($cache_metadata[(string)$id])) return $cache_metadata[(string)$id];
 
   $file = metaFN($id, '.meta');
   $meta = @file_exists($file) ? unserialize(io_readFile($file, false)) : array('current'=>array(),'persistent'=>array());
@@ -385,7 +384,7 @@ function p_read_metadata($id,$cache=false) {
   }
 
   if ($cache) {
-    $cache_metadata[$id] = $meta;
+    $cache_metadata[(string)$id] = $meta;
   }
 
   return $meta;
@@ -594,7 +593,7 @@ function & p_get_renderer($mode) {
     $Renderer = & new $rclass();
   }else{
     // Maybe a plugin is available?
-    $Renderer =& plugin_load('renderer',$rname);
+    $Renderer =& plugin_load('renderer',$rname, true);
     if(is_null($Renderer)){
       msg("No renderer '$rname' found for mode '$mode'",-1);
       return null;
@@ -618,8 +617,7 @@ function & p_get_renderer($mode) {
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function p_get_first_heading($id, $render=true){
-  global $conf;
-  return $conf['useheading'] ? p_get_metadata($id,'title',$render) : null;
+  return p_get_metadata($id,'title',$render);
 }
 
 /**
@@ -633,7 +631,7 @@ function p_get_first_heading($id, $render=true){
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function p_xhtml_cached_geshi($code, $language, $wrapper='pre') {
-  global $conf;
+  global $conf, $config_cascade;
   $language = strtolower($language);
 
   // remove any leading or trailing blank lines
@@ -642,9 +640,9 @@ function p_xhtml_cached_geshi($code, $language, $wrapper='pre') {
   $cache = getCacheName($language.$code,".code");
   $ctime = @filemtime($cache);
   if($ctime && !$_REQUEST['purge'] &&
-     $ctime > filemtime(DOKU_INC.'inc/geshi.php') &&
-     $ctime > @filemtime(DOKU_INC.'inc/geshi/'.$language.'.php') &&
-     $ctime > filemtime(DOKU_CONF.'dokuwiki.php')){
+     $ctime > filemtime(DOKU_INC.'inc/geshi.php') &&                 // geshi changed
+     $ctime > @filemtime(DOKU_INC.'inc/geshi/'.$language.'.php') &&  // language syntax definition changed
+     $ctime > filemtime(reset($config_cascade['main']['default']))){ // dokuwiki changed
     $highlighted_code = io_readFile($cache, false);
 
   } else {
