@@ -6,8 +6,7 @@
  * @author     Andreas Gohr <andi@splitbrain.org>
  */
 
-  if(!defined('DOKU_INC')) define('DOKU_INC',fullpath(dirname(__FILE__).'/../').'/');
-  require_once(DOKU_CONF.'dokuwiki.php');
+if(!defined('DOKU_INC')) die('meh.');
 
 /**
  * Returns the path to the given template, uses
@@ -88,6 +87,10 @@ function tpl_content_core(){
       html_diff();
       break;
     case 'recent':
+      if (is_array($_REQUEST['first'])) {
+        $_REQUEST['first'] = array_keys($_REQUEST['first']);
+        $_REQUEST['first'] = $_REQUEST['first'][0];
+      }
       $first = is_numeric($_REQUEST['first']) ? intval($_REQUEST['first']) : 0;
       html_recent($first);
       break;
@@ -103,6 +106,7 @@ function tpl_content_core(){
       break;
     case 'locked':
       html_locked();
+      html_edit();
       break;
     case 'login':
       html_login();
@@ -147,6 +151,7 @@ function tpl_toc($return=false){
     global $ID;
     global $REV;
     global $INFO;
+    global $conf;
     $toc = array();
 
     if(is_array($TOC)){
@@ -161,7 +166,7 @@ function tpl_toc($return=false){
             $tocok = true;
         }
         $toc   = $meta['description']['tableofcontents'];
-        if(!$tocok || !is_array($toc) || count($toc) < 3){
+        if(!$tocok || !is_array($toc) || !$conf['tocminheads'] || count($toc) < $conf['tocminheads']){
             $toc = array();
         }
     }elseif($ACT == 'admin'){
@@ -181,6 +186,7 @@ function tpl_toc($return=false){
         }
     }
 
+    trigger_event('TPL_TOC_RENDER', $toc, NULL, false);
     $html = html_TOC($toc);
     if($return) return $html;
     echo $html;
@@ -249,8 +255,10 @@ function tpl_metaheaders($alt=true){
   $head['link'][] = array( 'rel'=>'search', 'type'=>'application/opensearchdescription+xml',
                            'href'=>DOKU_BASE.'lib/exe/opensearch.php', 'title'=>$conf['title'] );
   $head['link'][] = array( 'rel'=>'start', 'href'=>DOKU_BASE );
-  $head['link'][] = array( 'rel'=>'contents', 'href'=> wl($ID,'do=index',false,'&'),
+  if(actionOK('index')){
+    $head['link'][] = array( 'rel'=>'contents', 'href'=> wl($ID,'do=index',false,'&'),
                            'title'=>$lang['btn_index'] );
+  }
 
   if($alt){
     $head['link'][] = array( 'rel'=>'alternate', 'type'=>'application/rss+xml',
@@ -258,6 +266,12 @@ function tpl_metaheaders($alt=true){
     $head['link'][] = array( 'rel'=>'alternate', 'type'=>'application/rss+xml',
                              'title'=>'Current Namespace',
                              'href'=>DOKU_BASE.'feed.php?mode=list&ns='.$INFO['namespace']);
+    if(($ACT == 'show' || $ACT == 'search') && $INFO['writable']){
+        $head['link'][] = array( 'rel'=>'alternate', 'type'=>'application/wiki',
+                                 'title'=>$lang['btn_edit'],
+                                 'href'=> wl($ID,'do=edit',false,'&'));
+    }
+
     if($ACT == 'search'){
       $head['link'][] = array( 'rel'=>'alternate', 'type'=>'application/rss+xml',
                                'title'=>'Search Result',
@@ -477,12 +491,18 @@ function tpl_button($type){
       }
       return true;
     case 'history':
+      if(!actionOK('revisions'))
+        return false;
       print html_btn('revs',$ID,'o',array('do' => 'revisions'));
       return true;
     case 'recent':
-      print html_btn('recent','','r',array('do' => 'recent'));
+      if(!actionOK('recent'))
+        return false;
+      print html_btn('recent',$ID,'r',array('do' => 'recent'));
       return true;
     case 'index':
+      if(!actionOK('index'))
+        return false;
       print html_btn('index',$ID,'x',array('do' => 'index'));
       return true;
     case 'back':
@@ -510,17 +530,34 @@ function tpl_button($type){
         return true;
       }
       return false;
+    case 'subscribe':
     case 'subscription':
       if($conf['useacl'] && $auth && $ACT == 'show' && $conf['subscribers'] == 1){
         if($_SERVER['REMOTE_USER']){
           if($INFO['subscribed']){
+            if(!actionOK('unsubscribe'))
+              return false;
             print html_btn('unsubscribe',$ID,'',array('do' => 'unsubscribe',));
           } else {
+            if(!actionOK('subscribe'))
+              return false;
             print html_btn('subscribe',$ID,'',array('do' => 'subscribe',));
           }
+          if($type == 'subscribe') return true;
+        }
+      }
+      if($type == 'subscribe') return false;
+      // fall through for backward compatibility
+    case 'subscribens':
+      if($conf['useacl'] && $auth && $ACT == 'show' && $conf['subscribers'] == 1){
+        if($_SERVER['REMOTE_USER']){
           if($INFO['subscribedns']){
+            if(!actionOK('unsubscribens'))
+              return false;
             print html_btn('unsubscribens',$ID,'',array('do' => 'unsubscribens',));
           } else {
+            if(!actionOK('subscribens'))
+              return false;
             print html_btn('subscribens',$ID,'',array('do' => 'subscribens',));
           }
           return true;
@@ -528,6 +565,8 @@ function tpl_button($type){
       }
       return false;
     case 'backlink':
+      if(!actionOK('backlink'))
+        return false;
       print html_btn('backlink',$ID,'',array('do' => 'backlink'));
       return true;
     case 'profile':
@@ -611,16 +650,22 @@ function tpl_actionlink($type,$pre='',$suf='',$inner=''){
       }
       return true;
     case 'history':
+      if(!actionOK('revisions'))
+        return false;
       tpl_link(wl($ID,'do=revisions'),
                $pre.(($inner)?$inner:$lang['btn_revs']).$suf,
                'class="action revisions" accesskey="o" rel="nofollow"');
       return true;
     case 'recent':
-      tpl_link(wl('','do=recent'),
+      if(!actionOK('recent'))
+        return false;
+      tpl_link(wl($ID,'do=recent'),
                $pre.(($inner)?$inner:$lang['btn_recent']).$suf,
               'class="action recent" accesskey="r" rel="nofollow"');
       return true;
     case 'index':
+      if(!actionOK('index'))
+        return false;
       tpl_link(wl($ID,'do=index'),
                $pre.(($inner)?$inner:$lang['btn_index']).$suf,
               'class="action index" accesskey="x" rel="nofollow"');
@@ -664,10 +709,14 @@ function tpl_actionlink($type,$pre='',$suf='',$inner=''){
       if($conf['useacl'] && $auth && $ACT == 'show' && $conf['subscribers'] == 1){
         if($_SERVER['REMOTE_USER']){
           if($INFO['subscribed']) {
+            if(!actionOK('unsubscribe'))
+              return false;
             tpl_link(wl($ID,'do=unsubscribe'),
                      $pre.(($inner)?$inner:$lang['btn_unsubscribe']).$suf,
                      'class="action unsubscribe" rel="nofollow"');
           } else {
+            if(!actionOK('subscribe'))
+              return false;
             tpl_link(wl($ID,'do=subscribe'),
                      $pre.(($inner)?$inner:$lang['btn_subscribe']).$suf,
                      'class="action subscribe" rel="nofollow"');
@@ -680,10 +729,14 @@ function tpl_actionlink($type,$pre='',$suf='',$inner=''){
       if($conf['useacl'] && $auth && $ACT == 'show' && $conf['subscribers'] == 1){
         if($_SERVER['REMOTE_USER']){
           if($INFO['subscribedns']) {
+            if(!actionOK('unsubscribens'))
+              return false;
             tpl_link(wl($ID,'do=unsubscribens'),
                      $pre.(($inner)?$inner:$lang['btn_unsubscribens']).$suf,
                      'class="action unsubscribens" rel="nofollow"');
           } else {
+            if(!actionOK('subscribens'))
+              return false;
             tpl_link(wl($ID,'do=subscribens'),
                      $pre.(($inner)?$inner:$lang['btn_subscribens']).$suf,
                      'class="action subscribens" rel="nofollow"');
@@ -693,6 +746,8 @@ function tpl_actionlink($type,$pre='',$suf='',$inner=''){
       }
       return false;
     case 'backlink':
+      if(!actionOK('backlink'))
+        return false;
       tpl_link(wl($ID,'do=backlink'),
                $pre.(($inner)?$inner:$lang['btn_backlink']).$suf,
                'class="action backlink" rel="nofollow"');
@@ -736,7 +791,7 @@ function tpl_searchform($ajax=true,$autocomplete=true){
   print '<input type="text" ';
   if($ACT == 'search') print 'value="'.htmlspecialchars($_REQUEST['id']).'" ';
   if(!$autocomplete) print 'autocomplete="off" ';
-  print 'id="qsearch__in" accesskey="f" name="id" class="edit" title="[ALT+F]" />';
+  print 'id="qsearch__in" accesskey="f" name="id" class="edit" title="[F]" />';
   print '<input type="submit" value="'.$lang['btn_search'].'" class="button" title="'.$lang['btn_search'].'" />';
   if($ajax) print '<div id="qsearch__out" class="ajax_qsearch JSpopup"></div>';
   print '</div></form>';
@@ -788,7 +843,7 @@ function tpl_breadcrumbs($sep='&raquo;'){
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Nigel McNie <oracle.shinoda@gmail.com>
  * @author Sean Coates <sean@caedmon.net>
- * @link   http://wiki.splitbrain.org/wiki:tipsandtricks:hierarchicalbreadcrumbs
+ * @author <fredrik@averpil.com>
  * @todo   May behave strangely in RTL languages
  */
 function tpl_youarehere($sep=' &raquo; '){
@@ -805,7 +860,7 @@ function tpl_youarehere($sep=' &raquo; '){
   echo '<span class="bchead">'.$lang['youarehere'].': </span>';
 
   // always print the startpage
-  $title = p_get_first_heading($conf['start']);
+  $title = useHeading('navigation') ? p_get_first_heading($conf['start']) : $conf['start'];
   if(!$title) $title = $conf['start'];
   tpl_link(wl($conf['start']),hsc($title),'title="'.$conf['start'].'"');
 
@@ -815,12 +870,12 @@ function tpl_youarehere($sep=' &raquo; '){
     $part .= $parts[$i].':';
     $page = $part;
     resolve_pageid('',$page,$exists);
-    if ($page == $conf['start']) continue; // Skip startpage 
+    if ($page == $conf['start']) continue; // Skip startpage
 
     // output
     echo $sep;
     if($exists){
-      $title = p_get_first_heading($page);
+      $title = useHeading('navigation') ? p_get_first_heading($page) : $page;
       if(!$title) $title = $parts[$i];
       tpl_link(wl($page),hsc($title),'title="'.$page.'"');
     }else{
@@ -834,7 +889,7 @@ function tpl_youarehere($sep=' &raquo; '){
   if($page == $conf['start']) return;
   echo $sep;
   if(page_exists($page)){
-    $title = p_get_first_heading($page);
+    $title = useHeading('navigation') ? p_get_first_heading($page) : $page;
     if(!$title) $title = $parts[$i];
     tpl_link(wl($page),hsc($title),'title="'.$page.'"');
   }else{
@@ -855,7 +910,7 @@ function tpl_userinfo(){
   global $lang;
   global $INFO;
   if($_SERVER['REMOTE_USER']){
-    print $lang['loggedinas'].': '.$INFO['userinfo']['name'];
+    print $lang['loggedinas'].': '.$INFO['userinfo']['name'].' ('.$_SERVER['REMOTE_USER'].')';
     return true;
   }
   return false;
@@ -866,16 +921,16 @@ function tpl_userinfo(){
  *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
-function tpl_pageinfo(){
+function tpl_pageinfo($ret=false){
   global $conf;
   global $lang;
   global $INFO;
   global $REV;
   global $ID;
-  
+
   // return if we are not allowed to view the page
-  if (!auth_quickaclcheck($ID)) { return; }
-  
+  if (!auth_quickaclcheck($ID)) { return false; }
+
   // prepare date and path
   $fn = $INFO['filepath'];
   if(!$conf['fullpath']){
@@ -890,24 +945,30 @@ function tpl_pageinfo(){
 
   // print it
   if($INFO['exists']){
-    print $fn;
-    print ' &middot; ';
-    print $lang['lastmod'];
-    print ': ';
-    print $date;
+    $out = '';
+    $out .= $fn;
+    $out .= ' &middot; ';
+    $out .= $lang['lastmod'];
+    $out .= ': ';
+    $out .= $date;
     if($INFO['editor']){
-      print ' '.$lang['by'].' ';
-      print $INFO['editor'];
+      $out .= ' '.$lang['by'].' ';
+      $out .= editorinfo($INFO['editor']);
     }else{
-      print ' ('.$lang['external_edit'].')';
+      $out .= ' ('.$lang['external_edit'].')';
     }
     if($INFO['locked']){
-      print ' &middot; ';
-      print $lang['lockedby'];
-      print ': ';
-      print $INFO['locked'];
+      $out .= ' &middot; ';
+      $out .= $lang['lockedby'];
+      $out .= ': ';
+      $out .= editorinfo($INFO['locked']);
+    }
+    if($ret){
+        return $out;
+    }else{
+        echo $out;
+        return true;
     }
-    return true;
   }
   return false;
 }
@@ -928,7 +989,7 @@ function tpl_pagetitle($id=null, $ret=false){
   }
 
   $name = $id;
-  if ($conf['useheading']) {
+  if (useHeading('navigation')) {
     $title = p_get_first_heading($id);
     if ($title) $name = $title;
   }
@@ -1136,4 +1197,140 @@ function tpl_mediaTree(){
   ptln('</div>');
 }
 
+
+/**
+ * Print a dropdown menu with all DokuWiki actions
+ *
+ * Note: this will not use any pretty URLs
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function tpl_actiondropdown($empty='',$button='&gt;'){
+    global $ID;
+    global $INFO;
+    global $REV;
+    global $ACT;
+    global $conf;
+    global $lang;
+    global $auth;
+
+
+    echo '<form method="post" accept-charset="utf-8">'; #FIXME action
+    echo '<input type="hidden" name="id" value="'.$ID.'" />';
+    if($REV) echo '<input type="hidden" name="rev" value="'.$REV.'" />';
+    echo '<input type="hidden" name="sectok" value="'.getSecurityToken().'" />';
+
+    echo '<select name="do" id="action__selector" class="edit">';
+    echo '<option value="">'.$empty.'</option>';
+
+    echo '<optgroup label=" &mdash; ">';
+        // 'edit' - most complicated type, we need to decide on current action
+        if($ACT == 'show' || $ACT == 'search'){
+            if($INFO['writable']){
+                if(!empty($INFO['draft'])) {
+                    echo '<option value="edit">'.$lang['btn_draft'].'</option>';
+                } else {
+                    if($INFO['exists']){
+                        echo '<option value="edit">'.$lang['btn_edit'].'</option>';
+                    }else{
+                        echo '<option value="edit">'.$lang['btn_create'].'</option>';
+                    }
+                }
+            }else if(actionOK('source')) { //pseudo action
+                echo '<option value="edit">'.$lang['btn_source'].'</option>';
+            }
+        }else{
+            echo '<option value="show">'.$lang['btn_show'].'</option>';
+        }
+
+        echo '<option value="revisions">'.$lang['btn_revs'].'</option>';
+        echo '<option value="backlink">'.$lang['btn_backlink'].'</option>';
+    echo '</optgroup>';
+
+    echo '<optgroup label=" &mdash; ">';
+        echo '<option value="recent">'.$lang['btn_recent'].'</option>';
+        echo '<option value="index">'.$lang['btn_index'].'</option>';
+    echo '</optgroup>';
+
+    echo '<optgroup label=" &mdash; ">';
+        if($conf['useacl'] && $auth){
+            if($_SERVER['REMOTE_USER']){
+                echo '<option value="logout">'.$lang['btn_logout'].'</option>';
+            }else{
+                echo '<option value="login">'.$lang['btn_login'].'</option>';
+            }
+        }
+
+        if($conf['useacl'] && $auth && $_SERVER['REMOTE_USER'] &&
+             $auth->canDo('Profile') && ($ACT!='profile')){
+            echo '<option value="profile">'.$lang['btn_profile'].'</option>';
+        }
+
+        if($conf['useacl'] && $auth && $ACT == 'show' && $conf['subscribers'] == 1){
+            if($_SERVER['REMOTE_USER']){
+                if($INFO['subscribed']) {
+                    echo '<option value="unsubscribe">'.$lang['btn_unsubscribe'].'</option>';
+                } else {
+                    echo '<option value="subscribe">'.$lang['btn_subscribe'].'</option>';
+                }
+            }
+        }
+
+        if($conf['useacl'] && $auth && $ACT == 'show' && $conf['subscribers'] == 1){
+            if($_SERVER['REMOTE_USER']){
+                if($INFO['subscribedns']) {
+                    echo '<option value="unsubscribens">'.$lang['btn_unsubscribens'].'</option>';
+                } else {
+                    echo '<option value="subscribens">'.$lang['btn_subscribens'].'</option>';
+                }
+            }
+        }
+
+        if($INFO['ismanager']){
+            echo '<option value="admin">'.$lang['btn_admin'].'</option>';
+        }
+    echo '</optgroup>';
+
+    echo '</select>';
+    echo '<input type="submit" value="'.$button.'" id="action__selectorbtn" />';
+    echo '</form>';
+}
+
+/**
+ * Print a informational line about the used license
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ * @param  string $img    - print image? (|button|badge)
+ * @param  bool   $return - when true don't print, but return HTML
+ */
+function tpl_license($img='badge',$imgonly=false,$return=false){
+    global $license;
+    global $conf;
+    global $lang;
+    if(!$conf['license']) return '';
+    if(!is_array($license[$conf['license']])) return '';
+    $lic = $license[$conf['license']];
+
+    $out  = '<div class="license">';
+    if($img){
+        $src = license_img($img);
+        if($src){
+            $out .= '<a href="'.$lic['url'].'" rel="license"';
+            if($conf['target']['external']) $out .= ' target="'.$conf['target']['external'].'"';
+            $out .= '><img src="'.DOKU_BASE.$src.'" class="medialeft lic'.$img.'" alt="'.$lic['name'].'" /></a> ';
+        }
+    }
+    if(!$imgonly) {
+        $out .= $lang['license'];
+        $out .= '<a href="'.$lic['url'].'" rel="license" class="urlextern"';
+        if($conf['target']['external']) $out .= ' target="'.$conf['target']['external'].'"';
+        $out .= '>'.$lic['name'].'</a>';
+        $out .= '</div>';
+    }
+
+    if($return) return $out;
+    echo $out;
+}
+
 //Setup VIM: ex: et ts=4 enc=utf-8 :
+
