@@ -9,6 +9,7 @@
 if(!defined('DOKU_INC')) define('DOKU_INC',dirname(__FILE__).'/../../');
 if(!defined('NOSESSION')) define('NOSESSION',true); // we do not use a session or authentication here (better caching)
 if(!defined('NL')) define('NL',"\n");
+if(!defined('DOKU_DISABLE_GZIP_OUTPUT')) define('DOKU_DISABLE_GZIP_OUTPUT',1); // we gzip ourself here
 require_once(DOKU_INC.'inc/init.php');
 require_once(DOKU_INC.'inc/pageutils.php');
 require_once(DOKU_INC.'inc/io.php');
@@ -35,7 +36,7 @@ function js_out(){
     $write = (bool) $_REQUEST['write'];  // writable?
 
     // The generated script depends on some dynamic options
-    $cache = getCacheName('scripts'.$edit.'x'.$write,'.js');
+    $cache = getCacheName('scripts'.$_SERVER['HTTP_HOST'].$_SERVER['SERVER_PORT'].$edit.'x'.$write,'.js');
 
     // Array of needed files
     $files = array(
@@ -64,7 +65,16 @@ function js_out(){
     if(js_cacheok($cache,array_merge($files,$plugins))){
         http_conditionalRequest(filemtime($cache));
         if($conf['allowdebug']) header("X-CacheUsed: $cache");
-        readfile($cache);
+
+        // finally send output
+        if ($conf['gzip_output'] && http_gzip_valid($cache)) {
+          header('Vary: Accept-Encoding');
+          header('Content-Encoding: gzip');
+          readfile($cache.".gz");
+        } else {
+          if (!http_sendfile($cache)) readfile($cache);
+        }
+
         return;
     } else {
         http_conditionalRequest(time());
@@ -84,7 +94,7 @@ function js_out(){
 
     // load JS strings form plugins
     $lang['js']['plugins'] = js_pluginstrings();
-    
+
     // load JS specific translations
     $json = new JSON();
     echo 'LANG = '.$json->encode($lang['js']).";\n";
@@ -131,7 +141,6 @@ function js_out(){
     @readfile(DOKU_CONF.'userscript.js');
 
     // add scroll event and tooltip rewriting
-    js_runonstart('updateAccessKeyTooltip()');
     js_runonstart('scrollToMarker()');
     js_runonstart('focusMarker()');
 
@@ -148,9 +157,16 @@ function js_out(){
 
     // save cache file
     io_saveFile($cache,$js);
+    copy($cache,"compress.zlib://$cache.gz");
 
     // finally send output
-    print $js;
+    if ($conf['gzip_output']) {
+      header('Vary: Accept-Encoding');
+      header('Content-Encoding: gzip');
+      print gzencode($js,9,FORCE_GZIP);
+    } else {
+      print $js;
+    }
 }
 
 /**
@@ -197,8 +213,7 @@ function js_cacheok($cache,$files){
     if(!$ctime) return false; //There is no cache
 
     // some additional files to check
-    $files[] = DOKU_CONF.'dokuwiki.php';
-    $files[] = DOKU_CONF.'local.php';
+    $files = array_merge($files, getConfigFiles('main'));
     $files[] = DOKU_CONF.'userscript.js';
     $files[] = __FILE__;
 
@@ -228,7 +243,7 @@ function js_pluginscripts(){
 /**
  * Return an two-dimensional array with strings from the language file of each plugin.
  *
- * - $lang['js'] must be an array. 
+ * - $lang['js'] must be an array.
  * - Nothing is returned for plugins without an entry for $lang['js']
  *
  * @author Gabriel Birke <birke@d-scribe.de>
