@@ -4,7 +4,7 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author     Andreas Gohr <andi@splitbrain.org>
- * @author     Anika Henke <a.c.henke@arcor.de> (concepts)
+ * @author     Anika Henke <anika@selfthinker.org> (concepts)
  * @author     Frank Schubert <frank@schokilade.de> (old version)
  */
 // must be run within Dokuwiki
@@ -22,7 +22,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
     var $ns  = null;
     var $who = '';
     var $usersgroups = array();
-
+    var $specials = array();
 
     /**
      * return some info
@@ -31,10 +31,10 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         return array(
             'author' => 'Andreas Gohr',
             'email'  => 'andi@splitbrain.org',
-            'date'   => '2008-03-15',
+            'date'   => '2008-12-16',
             'name'   => 'ACL',
             'desc'   => 'Manage Page Access Control Lists',
-            'url'    => 'http://wiki.splitbrain.org/wiki:acl',
+            'url'    => 'http://dokuwiki.org/plugin:acl',
         );
     }
 
@@ -63,6 +63,9 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         global $AUTH_ACL;
         global $ID;
 
+        // fresh 1:1 copy without replacements
+        $AUTH_ACL = file(DOKU_CONF.'acl.auth.php');
+
         // namespace given?
         if($_REQUEST['ns'] == '*'){
             $this->ns = '*';
@@ -106,9 +109,10 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
                 $this->_acl_del($scope, $this->who);
             }elseif(isset($_REQUEST['cmd']['update'])){
                 // handle update of the whole file
-                foreach((array) $_REQUEST['del'] as $where => $who){
+                foreach((array) $_REQUEST['del'] as $where => $names){
                     // remove all rules marked for deletion
-                    unset($_REQUEST['acl'][$where][$who]);
+                    foreach($names as $who)
+                        unset($_REQUEST['acl'][$where][$who]);
                 }
                 // prepare lines
                 $lines = array();
@@ -170,6 +174,11 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         $this->_html_table();
         echo '</div>'.NL;
 
+        echo '<div class="footnotes"><div class="fn">'.NL;
+        echo '<sup><a id="fn__1" class="fn_bot" name="fn__1" href="#fnt__1">1)</a></sup>'.NL;
+        echo $this->getLang('p_include');
+        echo '</div></div>';
+
         echo '</div>'.NL;
     }
 
@@ -351,7 +360,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
             if($info === false){
                 $groups = array();
             }else{
-                $groups = $info['groups'];
+                $groups = $info['grps'];
             }
         }
 
@@ -418,9 +427,8 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         }
 
         // highlight?
-        if(($item['type']=='d' &&
-            $item['id'] == $this->ns) ||
-            $item['id'] == $ID) $cl = ' cur';
+        if( ($item['type']=='d' && $item['id'] == $this->ns) ||
+            ($item['type']!='d' && $item['id'] == $ID)) $cl = ' cur';
 
         // namespace or page?
         if($item['type']=='d'){
@@ -460,6 +468,18 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         $acl_config=array();
         $usersgroups = array();
 
+        // get special users and groups
+        $this->specials[] = '@ALL';
+        $this->specials[] = '@'.$conf['defaultgroup'];
+        if($conf['manager'] != '!!not set!!'){
+            $this->specials = array_merge($this->specials,
+                                          array_map('trim',
+                                                    explode(',',$conf['manager'])));
+        }
+        $this->specials = array_filter($this->specials);
+        $this->specials = array_unique($this->specials);
+        sort($this->specials);
+
         foreach($AUTH_ACL as $line){
             $line = trim(preg_replace('/#.*$/','',$line)); //ignore comments
             if(!$line) continue;
@@ -472,37 +492,18 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
 
             // store non-special users and groups for later selection dialog
             $ug = $acl[1];
-            if($ug == '@ALL') continue;
-            if($ug == $conf['superuser']) continue;
-            if($ug == $conf['manager']) continue;
+            if(in_array($ug,$this->specials)) continue;
             $usersgroups[] = $ug;
         }
 
         $usersgroups = array_unique($usersgroups);
         sort($usersgroups);
-        uksort($acl_config,array($this,'_sort_names'));
+        ksort($acl_config);
 
         $this->acl = $acl_config;
         $this->usersgroups = $usersgroups;
     }
 
-    /**
-     * Custom function to sort the ACLs by namespace names
-     *
-     * @todo This maybe could be improved to resemble the real tree structure?
-     */
-    function _sort_names($a,$b){
-        $ca = substr_count($a,':');
-        $cb = substr_count($b,':');
-        if($ca < $cb){
-            return -1;
-        }elseif($ca > $cb){
-            return 1;
-        }else{
-            return strcmp($a,$b);
-        }
-    }
-
     /**
      * Display all currently set permissions in a table
      *
@@ -525,7 +526,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         echo '<tr>';
         echo '<th>'.$this->getLang('where').'</th>';
         echo '<th>'.$this->getLang('who').'</th>';
-        echo '<th>'.$this->getLang('perm').'</th>';
+        echo '<th>'.$this->getLang('perm').'<sup><a id="fnt__1" class="fn_top" name="fnt__1" href="#fn__1">1)</a></sup></th>';
         echo '<th>'.$lang['btn_delete'].'</th>';
         echo '</tr>';
         foreach($this->acl as $where => $set){
@@ -550,11 +551,11 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
                 echo '</td>';
 
                 echo '<td>';
-                echo $this->_html_checkboxes($perm,$ispage,'acl['.hsc($where).']['.hsc($who).']');
+                echo $this->_html_checkboxes($perm,$ispage,'acl['.$where.']['.$who.']');
                 echo '</td>';
 
                 echo '<td align="center">';
-                echo '<input type="checkbox" name="del['.hsc($where).']" value="'.hsc($who).'" />';
+                echo '<input type="checkbox" name="del['.hsc($where).'][]" value="'.hsc($who).'" />';
                 echo '</td>';
                 echo '</tr>';
             }
@@ -588,8 +589,8 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
             $check = $ID;
         }
 
-        if(isset($this->acl[$check][auth_nameencode($this->who,true)])){
-            return $this->acl[$check][auth_nameencode($this->who,true)];
+        if(isset($this->acl[$check][$this->who])){
+            return $this->acl[$check][$this->who];
         }else{
             return null;
         }
@@ -683,13 +684,9 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         global $conf;
         $inlist = false;
 
-        $specials = array('@ALL','@'.$conf['defaultgroup']);
-        if($conf['manager'] && $conf['manager'] != '!!not set!!') $specials[] = $conf['manager'];
-
-
         if($this->who &&
            !in_array($this->who,$this->usersgroups) &&
-           !in_array($this->who,$specials)){
+           !in_array($this->who,$this->specials)){
 
             if($this->who{0} == '@'){
                 $gsel = ' selected="selected"';
@@ -707,7 +704,7 @@ class admin_plugin_acl extends DokuWiki_Admin_Plugin {
         echo '  <option value="__g__" class="aclgroup"'.$gsel.'>'.$this->getLang('acl_group').':</option>'.NL;
         echo '  <option value="__u__"  class="acluser"'.$usel.'>'.$this->getLang('acl_user').':</option>'.NL;
         echo '  <optgroup label="&nbsp;">'.NL;
-        foreach($specials as $ug){
+        foreach($this->specials as $ug){
             if($ug == $this->who){
                 $sel    = ' selected="selected"';
                 $inlist = true;
