@@ -43,6 +43,7 @@ $lang['savedir']               = 'Adresář pro ukládání dat';
 $lang['start']                 = 'Název úvodních stránek';
 $lang['title']                 = 'Název celé wiki';
 $lang['template']              = 'Šablona';
+$lang['license']               = 'Pod jakou licencí má být tento obsah publikován?';
 $lang['fullpath']              = 'Ukazovat plnou cestu ke stránkám v patičce';
 $lang['recent']                = 'Nedávné změny';
 $lang['breadcrumbs']           = 'Počet odkazů na navštívené stránky';
@@ -53,6 +54,7 @@ $lang['phpok']                 = 'Povolit vložené PHP';
 $lang['dformat']               = 'Formát data (viz PHP funkci <a href="http://www.php.net/strftime">strftime</a>)';
 $lang['signature']             = 'Podpis';
 $lang['toptoclevel']           = 'Nejvyšší úroveň, kterou začít automaticky generovaný obsah';
+$lang['tocminheads']           = 'Nejnižší počet hlavních nadpisů, aby se vygeneroval obsah';
 $lang['maxtoclevel']           = 'Maximální počet úrovní v automaticky generovaném obsahu';
 $lang['maxseclevel']           = 'Nejnižší úroveň pro editaci i po sekcích';
 $lang['camelcase']             = 'Používat CamelCase v odkazech';
@@ -64,8 +66,9 @@ $lang['allowdebug']            = 'Povolit debugování. <b>Vypněte, pokud to ne
 $lang['usewordblock']          = 'Blokovat spam za použítí seznamu známých spamových slov';
 $lang['indexdelay']            = 'Časová prodleva před indexací (v sekundách)';
 $lang['relnofollow']           = 'Používat rel="nofollow" na externí odkazy';
-$lang['mailguard']             = 'Metoda "zašifrování" emailových addres';
+$lang['mailguard']             = 'Metoda "zamaskování" emailových addres';
 $lang['iexssprotect']          = 'Zkontrolovat nahrané soubory vůči možnému škodlivému JavaScriptu či HTML';
+$lang['showuseras']            = 'Co se má přesně zobrazit, když se ukazuje uživatel, který naposledy editoval stránku';
 $lang['useacl']                = 'Používat přístupová práva (ACL)';
 $lang['autopasswd']            = 'Generovat hesla automaticky';
 $lang['authtype']              = 'Metoda autentizace';
@@ -87,6 +90,7 @@ vnořené jmenné prostory, k nimž právo má, budou přesto skryty.
 To může mít za následek, že index bude při některých
 nastaveních ACL nepoužitelný.';
 $lang['auth_security_timeout'] = 'Časový limit pro autentikaci (v sekundách)';
+$lang['securecookie']          = 'Má prohlížeč posílat cookies nastavené přes HTTPS opět jen přes HTTPS? Vypňete tuto volbu, pokud chcete, aby bylo pomocí SSL zabezpečeno pouze přihlašování do wiki, ale obsah budete prohlížet nezabezpečeně.';
 $lang['updatecheck']           = 'Kontrolovat aktualizace a bezpečnostní varování? DokuWiki potřebuje pro tuto funkci přístup k splitbrain.org';
 $lang['userewrite']            = 'Používat "pěkná" URL';
 $lang['useslash']              = 'Používat lomítko jako oddělovač jmenných prostorů v URL';
@@ -116,6 +120,7 @@ $lang['xmlrpc']                = 'Povolit/Zakázat rozhraní XML-RPC.';
 $lang['renderer_xhtml']        = 'Vykreslovací jádro pro hlavní (xhtml) výstup wiki';
 $lang['renderer__core']        = '%s (jádro DokuWiki)';
 $lang['renderer__plugin']      = '%s (plugin)';
+$lang['rememberme']            = 'Povolit trvaté přihlašovací cookies (zapamatuj si mě)';
 $lang['rss_type']              = 'Typ XML kanálu';
 $lang['rss_linkto']            = 'XML kanál odkazuje na';
 $lang['rss_content']           = 'Co zobrazovat v položkách XML kanálu?';
@@ -138,6 +143,7 @@ $lang['ftp____port']           = 'FTP port pro safemode hack';
 $lang['ftp____user']           = 'FTP uživatelské jméno pro safemode hack';
 $lang['ftp____pass']           = 'FTP heslo pro safemode hack';
 $lang['ftp____root']           = 'FTP kořenový adresář pro safemode hack';
+$lang['license_o_']            = 'Nic nevybráno';
 $lang['typography_o_0']        = 'vypnuto';
 $lang['typography_o_1']        = 'Pouze uvozovky';
 $lang['typography_o_2']        = 'Všechny typy uvozovek a apostrofů (nemusí vždy fungovat)';
@@ -167,5 +173,14 @@ $lang['compression_o_0']       = 'vypnuto';
 $lang['compression_o_gz']      = 'gzip';
 $lang['compression_o_bz2']     = 'bz2';
 $lang['xsendfile_o_0']         = 'nepoužívat';
-$lang['xsendfile_o_1']         = 'Proprietární lighttpd hlavička (před releasem 1.5)';
-$lang['xsendfile_o_2']         = 'Standardní X-Sendfile hlavička';
+$lang['xsendfile_o_1']         = 'Proprietární hlavička lighttpd (před releasem 1.5)';
+$lang['xsendfile_o_2']         = 'Standardní hlavička X-Sendfile';
+$lang['xsendfile_o_3']         = 'Proprietární hlavička Nginx X-Accel-Redirect';
+$lang['showuseras_o_loginname'] = 'Přihlašovací jméno';
+$lang['showuseras_o_username'] = 'Celé jméno uživatele';
+$lang['showuseras_o_email']    = 'E-mailová adresa uživatele ("zamaskována" aktuálně nastavenou metodou)';
+$lang['showuseras_o_email_link'] = 'E-mailová adresa uživatele jako mailto: odkaz';
+$lang['useheading_o_0']        = 'Nikdy';
+$lang['useheading_o_navigation'] = 'Pouze pro navigaci';
+$lang['useheading_o_content']  = 'Pouze pro wiki obsah';
+$lang['useheading_o_1']        = 'Vždy';
