@@ -7,6 +7,8 @@
  * @author Delassaux Julien <julien@delassaux.fr>
  * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
  * @author gb@isis.u-strasbg.fr
+ * @author stephane.gully@gmail.com
+ * @author Guillaume Turri <guillaume.turri@gmail.com>
  */
 $lang['menu']                  = 'Paramètres de configuration';
 $lang['error']                 = 'Paramètres non modifiés en raison d\'une valeur non valide, vérifiez vos réglages et réessayez. <br />La valeur(s) erronée(s) est entourée d\'une bordure rouge.';
@@ -41,6 +43,7 @@ $lang['savedir']               = 'Répertoire de stockage';
 $lang['start']                 = 'Nom de la page d\'accueil';
 $lang['title']                 = 'Titre du wiki';
 $lang['template']              = 'Template';
+$lang['license']               = 'Sous quelle licence doit être placée votre contribution ?';
 $lang['fullpath']              = 'Utiliser le chemin complet dans le pied de page';
 $lang['recent']                = 'Nombre de derniers changements à afficher';
 $lang['breadcrumbs']           = 'Nombre de traces à afficher';
@@ -51,6 +54,7 @@ $lang['phpok']                 = 'Permettre php dans les pages';
 $lang['dformat']               = 'Format de date (cf. fonction <a href="http://www.php.net/strftime">strftime</a> de PHP)';
 $lang['signature']             = 'Signature';
 $lang['toptoclevel']           = 'Niveau supérieur pour figurer dans la table des matières';
+$lang['tocminheads']           = 'Nombre minimum de titres pour qu\'une table des matières soit construite';
 $lang['maxtoclevel']           = 'Niveau maximum pour figurer dans la table des matières';
 $lang['maxseclevel']           = 'Niveau maximum pour éditer des sections';
 $lang['camelcase']             = 'Utiliser CamelCase pour les liens';
@@ -64,6 +68,7 @@ $lang['indexdelay']            = 'Délai avant l\'indexation (sec)';
 $lang['relnofollow']           = 'Utiliser rel="nofollow" sur les liens extérieurs';
 $lang['mailguard']             = 'Brouiller les adresses de courriel';
 $lang['iexssprotect']          = 'Vérifier la présence de code JavaScript ou HTML malveillant dans les fichiers envoyés';
+$lang['showuseras']            = 'Qu\'afficher en montrant les utilisateurs qui ont récemment édité la page';
 $lang['useacl']                = 'Utiliser les listes de contrôle d\'accès (ACL)';
 $lang['autopasswd']            = 'Auto-générer les mots de passe';
 $lang['authtype']              = 'Mécanisme d\'authentification';
@@ -80,6 +85,7 @@ $lang['disableactions_wikicode'] = 'Afficher source';
 $lang['disableactions_other']  = 'Autres actions (séparées par des virgules)';
 $lang['sneaky_index']          = 'Par défaut, DokuWiki affichera toutes les catégories dans la vue par index. Activer cette option permet de cacher celles pour lesquelles l\'utilisateur n\'a pas la permission de lecture. Il peut en résulter le masquage de sous-catégories accessibles. Ceci peut rendre l\'index inutilisable avec certaines ACL.';
 $lang['auth_security_timeout'] = 'Délai d\'expiration de sécurité (secondes)';
+$lang['securecookie']          = 'Les cookies mis via HTTPS doivent-ils n\'être envoyé par le navigateur que via HTTPS ? Ne désactivez cette option que si la connexion à votre wiki est sécurisée avec SSL mais que la navigation sur le wiki n\'est pas sécurisée';
 $lang['updatecheck']           = 'Vérifier les mises à jour ? DokuWiki doit pouvoir contacter splitbrain.org.';
 $lang['userewrite']            = 'URLs esthétiques';
 $lang['useslash']              = 'Utiliser slash comme séparateur de catégorie dans les URLs';
@@ -110,6 +116,7 @@ $lang['xmlrpc']                = 'Activer l\'interface XML-RPC.';
 $lang['renderer_xhtml']        = 'Moteur de rendu du format de sortie principal (xhtml)';
 $lang['renderer__core']        = '%s (dokuwiki core)';
 $lang['renderer__plugin']      = '%s (plugin)';
+$lang['rememberme']            = 'Permettre de conserver de manière permanente les cookies de connexion (mémoriser)';
 $lang['rss_type']              = 'Type de flux RSS';
 $lang['rss_linkto']            = 'Lien du flux RSS vers';
 $lang['rss_content']           = 'Quel contenu afficher dans le flux RSS ?';
@@ -132,6 +139,7 @@ $lang['ftp____port']           = 'FTP - port pour safemode';
 $lang['ftp____user']           = 'FTP - identifiant pour safemode';
 $lang['ftp____pass']           = 'FTP - mot de passe pour safemode';
 $lang['ftp____root']           = 'FTP - répertoire racine pour safemode';
+$lang['license_o_']            = 'Aucune choisie';
 $lang['typography_o_0']        = 'aucun';
 $lang['typography_o_1']        = 'guillemets uniquement';
 $lang['typography_o_2']        = 'tout signe typographique (peut ne pas fonctionner)';
@@ -164,3 +172,11 @@ $lang['xsendfile_o_0']         = 'ne pas utiliser';
 $lang['xsendfile_o_1']         = 'Entête propriétaire lighttpd (avant la version 1.5)';
 $lang['xsendfile_o_2']         = 'Entête standard X-Sendfile';
 $lang['xsendfile_o_3']         = 'En-tête propriétaire Nginx X-Accel-Redirect';
+$lang['showuseras_o_loginname'] = 'Nom d\'utilisateur';
+$lang['showuseras_o_username'] = 'Nom de l\'utilisateur';
+$lang['showuseras_o_email']    = 'Le courriel de l\'utilisateur (obfusqué suivant les paramètres de brouillage sélectionnés)';
+$lang['showuseras_o_email_link'] = 'Courriel de l\'utilisateur en tant que lien mailto:';
+$lang['useheading_o_0']        = 'Jamais';
+$lang['useheading_o_navigation'] = 'Navigation seulement';
+$lang['useheading_o_content']  = 'Contenu du wiki seulement';
+$lang['useheading_o_1']        = 'Toujours';
