@@ -39,6 +39,7 @@ $lang['savedir']               = 'Directorio no que se gardarán os datos';
 $lang['start']                 = 'Nome da páxina inicial';
 $lang['title']                 = 'Título do Wiki';
 $lang['template']              = 'Sobreplanta';
+$lang['license']               = 'Baixo de que licenza será ceibado o teu contido?';
 $lang['fullpath']              = 'Amosar a ruta completa das páxinas no pé das mesmas';
 $lang['recent']                = 'Trocos recentes';
 $lang['breadcrumbs']           = 'Número de niveis da estrutura de navegación';
@@ -49,6 +50,7 @@ $lang['phpok']                 = 'Permitir a inserción de PHP';
 $lang['dformat']               = 'Formato de Data (bótalle un ollo á función <a href="http://www.php.net/strftime">strftime</a> do PHP)';
 $lang['signature']             = 'Sinatura';
 $lang['toptoclevel']           = 'Nivel superior para a táboa de contidos';
+$lang['tocminheads']           = 'Cantidade mínima de liñas de cabeceira que determinará se a TDC vai ser xerada';
 $lang['maxtoclevel']           = 'Nivel máximo para a táboa de contidos';
 $lang['maxseclevel']           = 'Nivel máximo de edición da sección';
 $lang['camelcase']             = 'Utilizar CamelCase para as ligazóns';
@@ -62,6 +64,7 @@ $lang['indexdelay']            = 'Retardo denantes de indexar (seg)';
 $lang['relnofollow']           = 'Utilizar rel="nofollow" nas ligazóns externas';
 $lang['mailguard']             = 'Ofuscar enderezos de correo-e';
 $lang['iexssprotect']          = 'Comprobar arquivos subidos na procura de posible código JavaScript ou HTML malicioso';
+$lang['showuseras']            = 'Que amosar cando se informe do usuario que fixo a última modificación dunha páxina';
 $lang['useacl']                = 'Utilizar lista de control de acceso';
 $lang['autopasswd']            = 'Xerar contrasinais automaticamente';
 $lang['authtype']              = 'Backend de autenticación';
@@ -78,6 +81,7 @@ $lang['disableactions_wikicode'] = 'Ver fonte/Exportar Datos Raw';
 $lang['disableactions_other']  = 'Outras accións (separadas por comas)';
 $lang['sneaky_index']          = 'O DokuWiki amosará por defecto todos os nomes de espazo na vista de índice. Se activas isto agocharanse aqueles onde o usuario non teña permisos de lectura.';
 $lang['auth_security_timeout'] = 'Tempo Límite de Seguridade de Autenticación (segundos)';
+$lang['securecookie']          = 'Deben enviarse só vía HTTPS polo navegador as cookies configuradas vía HTTPS? Desactiva esta opción cando só o inicio de sesión do teu wiki estea asegurado con SSL pero a nevegación do mesmo se faga de xeito inseguro.';
 $lang['updatecheck']           = 'Comprobar se hai actualizacións e avisos de seguridade? O DokuWiki precisa contactar con splitbrain.org para executar esta característica.';
 $lang['userewrite']            = 'Utilizar URLs amigables';
 $lang['useslash']              = 'Utilizar a barra inclinada (slash) como separador de nome de espazo nos URLs';
@@ -107,6 +111,7 @@ $lang['xmlrpc']                = 'Activar/desactivar interface XML-RPC';
 $lang['renderer_xhtml']        = 'Intérprete a empregar para a saída principal (xhtml) do wiki';
 $lang['renderer__core']        = '%s (núcleo do dokuwiki)';
 $lang['renderer__plugin']      = '%s (plugin)';
+$lang['rememberme']            = 'Permitir cookies permanentes de inicio de sesión (lembrarme)';
 $lang['rss_type']              = 'Tipo de corrente XML';
 $lang['rss_linkto']            = 'A corrente XML liga a';
 $lang['rss_content']           = 'Que queres amosar nos elementos da corrente XML?';
@@ -129,6 +134,7 @@ $lang['ftp____port']           = 'Porto FTP para o hack de modo seguro(safemode)
 $lang['ftp____user']           = 'Nome de usuario FTP para o hack de modo seguro(safemode)';
 $lang['ftp____pass']           = 'Contrasinal FTP para o hack de modo seguro(safemode)';
 $lang['ftp____root']           = 'Directorio raigaña do FTP para o hack de modo seguro(safemode)';
+$lang['license_o_']            = 'Non se escolleu nada';
 $lang['typography_o_0']        = 'ningunha';
 $lang['typography_o_1']        = 'Só dobres aspas';
 $lang['typography_o_2']        = 'Todas as aspas (pode que non funcione sempre)';
@@ -161,3 +167,11 @@ $lang['xsendfile_o_0']         = 'non o empregues';
 $lang['xsendfile_o_1']         = 'Cabeceira lighttpd propietaria (denantes da versión 1.5)';
 $lang['xsendfile_o_2']         = 'Cabeceira X-Sendfile estándar';
 $lang['xsendfile_o_3']         = 'Cabeceira X-Accel-Redirect propia de Nginx';
+$lang['showuseras_o_loginname'] = 'Nome de inicio de sesión';
+$lang['showuseras_o_username'] = 'Nome completo do usuario';
+$lang['showuseras_o_email']    = 'Enderezo de correo-e do usuario (ofuscado segundo a configuración mailguard)';
+$lang['showuseras_o_email_link'] = 'Enderezo de correo-e do usuario como ligazón mailto:';
+$lang['useheading_o_0']        = 'Endexamais';
+$lang['useheading_o_navigation'] = 'Só Navegación';
+$lang['useheading_o_content']  = 'Só Contido do Wiki';
+$lang['useheading_o_1']        = 'Sempre';
