@@ -5,6 +5,7 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Yuji Takenaka <webmaster@davilin.com>
  * @author Christopher Smith <chris@jalakai.co.uk>
+ * @author Ikuo Obataya <i.obataya@gmail.com>
  */
 $lang['menu']                  = 'サイト設定';
 $lang['error']                 = '不正な値が存在するため、設定は更新されませんでした。入力値を確認してから、再度更新してください。
@@ -41,6 +42,7 @@ $lang['savedir']               = '保存ディレクトリ';
 $lang['start']                 = 'スタートページ名';
 $lang['title']                 = 'WIKIタイトル';
 $lang['template']              = 'テンプレート';
+$lang['license']               = '作成した内容をどのライセンスでリリースしますか？';
 $lang['fullpath']              = 'ページのフッターに絶対パスを表示';
 $lang['recent']                = '最近の変更表示数';
 $lang['breadcrumbs']           = 'トレース（パンくず）表示数';
@@ -51,6 +53,7 @@ $lang['phpok']                 = 'PHP埋め込み';
 $lang['dformat']               = '日付フォーマット（PHPの<a href="http://www.php.net/strftime">strftime</a>関数を参照）';
 $lang['signature']             = '署名';
 $lang['toptoclevel']           = '目次 トップレベル見出し';
+$lang['tocminheads']           = '目次を生成するための最小見出し数';
 $lang['maxtoclevel']           = '目次 表示限度見出し';
 $lang['maxseclevel']           = '編集可能見出し';
 $lang['camelcase']             = 'キャメルケースリンク';
@@ -64,6 +67,7 @@ $lang['indexdelay']            = 'インデックスを許可（何秒後）';
 $lang['relnofollow']           = 'rel="nofollow"を付加';
 $lang['mailguard']             = 'メールアドレス保護';
 $lang['iexssprotect']          = 'アップロードファイルに悪意のあるJavaScriptやHTMLが含まれていないかチェックする';
+$lang['showuseras']            = '最終編集者の情報として表示する内容';
 $lang['useacl']                = 'アクセス管理を行う（ACL）';
 $lang['autopasswd']            = 'パスワードの自動生成（ACL）';
 $lang['authtype']              = '認証方法（ACL）';
@@ -80,6 +84,7 @@ $lang['disableactions_wikicode'] = 'ソース閲覧 / 生データ出力';
 $lang['disableactions_other']  = 'その他の動作（カンマ区切り）';
 $lang['sneaky_index']          = 'デフォルトでは索引にすべての名前空間を表示しますが、この機能はユーザーに閲覧権限のない名前空間を非表示にします。ただし、閲覧が可能な副名前空間まで表示されなくなるため、ACLの設定が適正でない場合は索引機能が使えなくなる場合があります。';
 $lang['auth_security_timeout'] = '認証タイムアウト設定（秒）';
+$lang['securecookie']          = 'クッキーをHTTPSにてセットする場合は、ブラウザよりHTTPS経由で送信された場合にみに制限しますか？ログインのみをSSLで行う場合は、この機能を無効にしてください。';
 $lang['updatecheck']           = 'DokuWikiの更新とセキュリティに関する情報をチェックしますか？ この機能は splitbrain.org への接続が必要です。';
 $lang['userewrite']            = 'URLの書き換え';
 $lang['useslash']              = 'URL上の名前空間の区切りにスラッシュを使用';
@@ -109,6 +114,7 @@ $lang['xmlrpc']                = 'XML-RPCインターフェースを有効/無
 $lang['renderer_xhtml']        = 'Wikiの出力（xhtml）にレンダラーを使用する';
 $lang['renderer__core']        = '%s （Dokuwikiコア）';
 $lang['renderer__plugin']      = '%s （プラグイン）';
+$lang['rememberme']            = 'ログイン用クッキーを永久に保持することを許可（ログインを保持）';
 $lang['rss_type']              = 'RSSフィード形式';
 $lang['rss_linkto']            = 'RSS内リンク先';
 $lang['rss_content']           = 'XMLフィードに何を表示させますか？';
@@ -131,6 +137,7 @@ $lang['ftp____port']           = 'FTP ポート（セーフモード対策）';
 $lang['ftp____user']           = 'FTP ユーザー名（セーフモード対策）';
 $lang['ftp____pass']           = 'FTP パスワード（セーフモード対策）';
 $lang['ftp____root']           = 'FTP ルートディレクトリ（セーフモード対策）';
+$lang['license_o_']            = '選択されていません';
 $lang['typography_o_0']        = '無し';
 $lang['typography_o_1']        = '二重引用符（ダブルクオート）のみ';
 $lang['typography_o_2']        = 'すべての引用符（動作しない場合があります）';
@@ -163,3 +170,11 @@ $lang['xsendfile_o_0']         = '使用しない';
 $lang['xsendfile_o_1']         = 'lighttpd ヘッダー（リリース1.5以前）';
 $lang['xsendfile_o_2']         = '標準 X-Sendfile ヘッダー';
 $lang['xsendfile_o_3']         = 'Nginx X-Accel-Redirect ヘッダー';
+$lang['showuseras_o_loginname'] = 'ログイン名';
+$lang['showuseras_o_username'] = 'ユーザーのフルネーム';
+$lang['showuseras_o_email']    = 'ユーザーのメールアドレス（メールガード設定による難読化）';
+$lang['showuseras_o_email_link'] = 'ユーザーのメールアドレスをリンクにする';
+$lang['useheading_o_0']        = '使用しない';
+$lang['useheading_o_navigation'] = 'ナビゲーションのみ';
+$lang['useheading_o_content']  = 'Wikiの内容のみ';
+$lang['useheading_o_1']        = '常に使用する';
