@@ -4,6 +4,8 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Grzegorz Żur <grzegorz.zur@gmail.com>
+ * @author Mariusz Kujawski <marinespl@gmail.com>
+ * @author Maciej Kurczewski <pipijajko@gmail.com>
  */
 $lang['menu']                  = 'Ustawienia';
 $lang['error']                 = 'Ustawienia nie zostały zapisane z powodu błędnych wartości, przejrzyj je i ponów próbę zapisu. <br/> Niepoprawne wartości są wyróżnione kolorem czerwonym.';
@@ -38,6 +40,7 @@ $lang['savedir']               = 'Katalog z danymi';
 $lang['start']                 = 'Tytuł strony początkowej';
 $lang['title']                 = 'Tytuł wiki';
 $lang['template']              = 'Motyw';
+$lang['license']               = 'Pod jaką licencją publikować treści wiki?';
 $lang['fullpath']              = 'Wyświetlanie pełnych ścieżek';
 $lang['recent']                = 'Ilość ostatnich zmian';
 $lang['breadcrumbs']           = 'Długość śladu';
@@ -48,6 +51,7 @@ $lang['phpok']                 = 'Wstawki PHP';
 $lang['dformat']               = 'Format daty';
 $lang['signature']             = 'Podpis';
 $lang['toptoclevel']           = 'Minimalny poziom spisu treści';
+$lang['tocminheads']           = 'Minimalna liczba nagłówków niezbędna do wytworzenia spisu treści.';
 $lang['maxtoclevel']           = 'Maksymalny poziom spisu treści';
 $lang['maxseclevel']           = 'Maksymalny poziom podziału na sekcje edycyjne';
 $lang['camelcase']             = 'Bikapitalizacja odnośników (CamelCase)';
@@ -61,6 +65,7 @@ $lang['indexdelay']            = 'Okres indeksowania w sekundach';
 $lang['relnofollow']           = 'Nagłówek rel="nofollow" dla odnośników zewnętrznych';
 $lang['mailguard']             = 'Utrudnianie odczytu adresów e-mail';
 $lang['iexssprotect']          = 'Wykrywanie złośliwego kodu JavaScript i HTML w plikach';
+$lang['showuseras']            = 'Sposób wyświetlania nazwy użytkownika, który ostatnio edytował stronę';
 $lang['useacl']                = 'Kontrola uprawnień ACL';
 $lang['autopasswd']            = 'Automatyczne generowanie haseł';
 $lang['authtype']              = 'Typ autoryzacji';
@@ -77,6 +82,7 @@ $lang['disableactions_wikicode'] = 'Pokazywanie źródeł';
 $lang['disableactions_other']  = 'Inne akcje (oddzielone przecinkiem)';
 $lang['sneaky_index']          = 'Domyślnie, Dokuwiki pokazuje wszystkie katalogi w indeksie. Włączenie tej opcji ukryje katalogi, do których użytkownik nie ma praw. Może to spowodować ukrycie podkatalogów, do których użytkownik ma prawa. Ta opcja może spowodować błędne działanie indeksu w połączeniu z pewnymi konfiguracjami praw dostępu.';
 $lang['auth_security_timeout'] = 'Czas wygaśnięcia uwierzytelnienia (w sekundach)';
+$lang['securecookie']          = 'Czy ciasteczka wysłane do przeglądarki przez HTTPS powinny być przez nią odsyłane też tylko przez HTTPS? Odznacz tę opcję tylko wtedy, gdy logowanie użytkowników jest zabezpieczone SSL, ale przeglądanie stron odbywa się bez zabezpieczenia.';
 $lang['updatecheck']           = 'Sprawdzanie aktualizacji i bezpieczeństwa. DokuWiki będzie kontaktować się z serwerem splitbrain.org.';
 $lang['userewrite']            = 'Proste adresy URL';
 $lang['useslash']              = 'Używanie ukośnika jako separatora w adresie URL';
@@ -106,6 +112,7 @@ $lang['xmlrpc']                = 'Włącz/wyłącz interfejs XML-RPC';
 $lang['renderer_xhtml']        = 'Mechanizm renderowania głównej treści strony (xhtml)';
 $lang['renderer__core']        = '%s (dokuwiki)';
 $lang['renderer__plugin']      = '%s (wtyczka)';
+$lang['rememberme']            = 'Pozwól na ciasteczka automatycznie logujące (pamiętaj mnie)';
 $lang['rss_type']              = 'Typ RSS';
 $lang['rss_linkto']            = 'Odnośniki w RSS';
 $lang['rss_content']           = 'Rodzaj informacji wyświetlanych w RSS ';
@@ -128,6 +135,7 @@ $lang['ftp____port']           = 'FTP - port';
 $lang['ftp____user']           = 'FTP - nazwa użytkownika';
 $lang['ftp____pass']           = 'FTP - hasło';
 $lang['ftp____root']           = 'FTP - katalog główny';
+$lang['license_o_']            = 'Nie wybrano żadnej';
 $lang['typography_o_0']        = 'brak';
 $lang['typography_o_1']        = 'tylko podwójne cudzysłowy';
 $lang['typography_o_2']        = 'wszystkie cudzysłowy (nie działa we wszystkich przypadkach)';
@@ -160,3 +168,11 @@ $lang['xsendfile_o_0']         = 'nie używaj';
 $lang['xsendfile_o_1']         = 'Specyficzny nagłówek lightttpd (poniżej wersji 1.5)';
 $lang['xsendfile_o_2']         = 'Standardowy nagłówek HTTP X-Sendfile';
 $lang['xsendfile_o_3']         = 'Specyficzny nagłówek Nginx X-Accel-Redirect';
+$lang['showuseras_o_loginname'] = 'Login użytkownika';
+$lang['showuseras_o_username'] = 'Pełne nazwisko użytkownika';
+$lang['showuseras_o_email']    = 'E-mail użytkownika (ukrywanie według ustawień mailguard)';
+$lang['showuseras_o_email_link'] = 'Adresy e-mail użytkowników w formie linku mailto:';
+$lang['useheading_o_0']        = 'Nigdy';
+$lang['useheading_o_navigation'] = 'W nawigacji';
+$lang['useheading_o_content']  = 'W treści';
+$lang['useheading_o_1']        = 'Zawsze';
