@@ -18,16 +18,18 @@ if (!class_exists('configuration')) {
     var $setting = array();        // array of setting objects
     var $locked = false;           // configuration is considered locked if it can't be updated
 
-    // filenames, these will be eval()'d prior to use so maintain any constants in output
-    var $_default_file  = '';
-    var $_local_file = '';
-    var $_protected_file = '';
+    // configuration filenames
+    var $_default_files  = array();
+    var $_local_files = array();      // updated configuration is written to the first file
+    var $_protected_files = array();
+
+    var $_plugin_list = null;
 
     /**
      *  constructor
      */
     function configuration($datafile) {
-        global $conf;
+        global $conf, $config_cascade;
 
         if (!@file_exists($datafile)) {
           msg('No configuration metadata found at - '.htmlspecialchars($datafile),-1);
@@ -39,9 +41,13 @@ if (!class_exists('configuration')) {
         if (isset($config['format'])) $this->_format = $config['format'];
         if (isset($config['heading'])) $this->_heading = $config['heading'];
 
-        if (isset($file['default'])) $this->_default_file = $file['default'];
-        if (isset($file['local'])) $this->_local_file = $file['local'];
-        if (isset($file['protected'])) $this->_protected_file = $file['protected'];
+        $this->_default_files = $config_cascade['main']['default'];
+        $this->_local_files = $config_cascade['main']['local'];
+        $this->_protected_files = $config_cascade['main']['protected'];
+
+#        if (isset($file['default'])) $this->_default_file = $file['default'];
+#        if (isset($file['local'])) $this->_local_file = $file['local'];
+#        if (isset($file['protected'])) $this->_protected_file = $file['protected'];
 
         $this->locked = $this->_is_locked();
 
@@ -55,9 +61,9 @@ if (!class_exists('configuration')) {
         $no_default_check = array('setting_fieldset', 'setting_undefined', 'setting_no_class');
 
         if (!$this->_loaded) {
-          $default = array_merge($this->_read_config($this->_default_file), $this->get_plugintpl_default($conf['template']));
-          $local = $this->_read_config($this->_local_file);
-          $protected = $this->_read_config($this->_protected_file);
+          $default = array_merge($this->get_plugintpl_default($conf['template']), $this->_read_config_group($this->_default_files));
+          $local = $this->_read_config_group($this->_local_files);
+          $protected = $this->_read_config_group($this->_protected_files);
 
           $keys = array_merge(array_keys($this->_metadata),array_keys($default), array_keys($local), array_keys($protected));
           $keys = array_unique($keys);
@@ -90,10 +96,12 @@ if (!class_exists('configuration')) {
     }
 
     function save_settings($id, $header='', $backup=true) {
+      global $conf;
 
       if ($this->locked) return false;
 
-      $file = eval('return '.$this->_local_file.';');
+#      $file = eval('return '.$this->_local_file.';');
+      $file = $this->_local_files[0];
 
       // backup current file (remove any existing backup)
       if (@file_exists($file) && $backup) {
@@ -118,9 +126,19 @@ if (!class_exists('configuration')) {
 
       @fwrite($fh, $out);
       fclose($fh);
+      if($conf['fperm']) chmod($file, $conf['fperm']);
       return true;
     }
 
+    function _read_config_group($files) {
+      $config = array();
+      foreach ($files as $file) {
+        $config = array_merge($config, $this->_read_config($file));
+      }
+
+      return $config;
+    }
+
     /**
      * return an array of config settings
      */
@@ -129,7 +147,7 @@ if (!class_exists('configuration')) {
       if (!$file) return array();
 
       $config = array();
-      $file = eval('return '.$file.';');
+#      $file = eval('return '.$file.';');
 
       if ($this->_format == 'php') {
 
@@ -177,9 +195,9 @@ if (!class_exists('configuration')) {
     function _out_footer() {
       $out = '';
       if ($this->_format == 'php') {
-          if ($this->_protected_file) {
-            $out .= "\n@include(".$this->_protected_file.");\n";
-          }
+ #         if ($this->_protected_file) {
+ #           $out .= "\n@include(".$this->_protected_file.");\n";
+ #         }
           $out .= "\n// end auto-generated content\n";
       }
 
@@ -189,9 +207,10 @@ if (!class_exists('configuration')) {
     // configuration is considered locked if there is no local settings filename
     // or the directory its in is not writable or the file exists and is not writable
     function _is_locked() {
-      if (!$this->_local_file) return true;
+      if (!$this->_local_files) return true;
 
-      $local = eval('return '.$this->_local_file.';');
+#      $local = eval('return '.$this->_local_file.';');
+      $local = $this->_local_files[0];
 
       if (!is_writable(dirname($local))) return true;
       if (@file_exists($local) && !is_writable($local)) return true;
@@ -220,6 +239,21 @@ if (!class_exists('configuration')) {
         return $out;
     }
 
+    function get_plugin_list() {
+      if (is_null($this->_plugin_list)) {
+        $list = plugin_list('',true);     // all plugins, including disabled ones
+
+        // remove this plugin from the list
+        $idx = array_search('config',$list);
+        unset($list[$idx]);
+
+        trigger_event('PLUGIN_CONFIG_PLUGINLIST',$list);
+        $this->_plugin_list = $list;
+      }
+
+      return $this->_plugin_list;
+    }
+
     /**
      * load metadata for plugin and template settings
      */
@@ -228,25 +262,20 @@ if (!class_exists('configuration')) {
       $class    = '/conf/settings.class.php';
       $metadata = array();
 
-      if ($dh = opendir(DOKU_PLUGIN)) {
-        while (false !== ($plugin = readdir($dh))) {
-          if ($plugin == '.' || $plugin == '..' || $plugin == 'tmp' || $plugin == 'config') continue;
-          if (is_file(DOKU_PLUGIN.$plugin)) continue;
-
-          if (@file_exists(DOKU_PLUGIN.$plugin.$file)){
-            $meta = array();
-            @include(DOKU_PLUGIN.$plugin.$file);
-            @include(DOKU_PLUGIN.$plugin.$class);
-            if (!empty($meta)) {
-              $metadata['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.'plugin_settings_name'] = array('fieldset');
-            }
-            foreach ($meta as $key => $value){
-              if ($value[0]=='fieldset') { continue; } //plugins only get one fieldset
-              $metadata['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.$key] = $value;
-            }
+      foreach ($this->get_plugin_list() as $plugin) {
+        $plugin_dir = plugin_directory($plugin);
+        if (@file_exists(DOKU_PLUGIN.$plugin_dir.$file)){
+          $meta = array();
+          @include(DOKU_PLUGIN.$plugin_dir.$file);
+          @include(DOKU_PLUGIN.$plugin_dir.$class);
+          if (!empty($meta)) {
+             $metadata['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.'plugin_settings_name'] = array('fieldset');
+          }
+          foreach ($meta as $key => $value){
+            if ($value[0]=='fieldset') { continue; } //plugins only get one fieldset
+            $metadata['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.$key] = $value;
           }
         }
-        closedir($dh);
       }
 
       // the same for the active template
@@ -273,17 +302,15 @@ if (!class_exists('configuration')) {
       $file    = '/conf/default.php';
       $default = array();
 
-      if ($dh = opendir(DOKU_PLUGIN)) {
-        while (false !== ($plugin = readdir($dh))) {
-          if (@file_exists(DOKU_PLUGIN.$plugin.$file)){
-            $conf = array();
-            @include(DOKU_PLUGIN.$plugin.$file);
-            foreach ($conf as $key => $value){
-              $default['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.$key] = $value;
-            }
+      foreach ($this->get_plugin_list() as $plugin) {
+        $plugin_dir = plugin_directory($plugin);
+        if (@file_exists(DOKU_PLUGIN.$plugin_dir.$file)){
+          $conf = array();
+          @include(DOKU_PLUGIN.$plugin_dir.$file);
+          foreach ($conf as $key => $value){
+            $default['plugin'.CM_KEYMARKER.$plugin.CM_KEYMARKER.$key] = $value;
           }
         }
-        closedir($dh);
       }
 
       // the same for the active template
@@ -452,6 +479,8 @@ if (!class_exists('setting_string')) {
 if (!class_exists('setting_password')) {
   class setting_password extends setting_string {
 
+    var $_code = 'plain';  // mechanism to be used to obscure passwords
+
     function update($input) {
         if ($this->is_protected()) return false;
         if (!$input) return false;
@@ -462,7 +491,7 @@ if (!class_exists('setting_password')) {
           return false;
         }
 
-        $this->_local = $input;
+        $this->_local = conf_encodeString($input,$this->_code);
         return true;
     }
 
@@ -474,7 +503,7 @@ if (!class_exists('setting_password')) {
         $key = htmlspecialchars($this->_key);
 
         $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
-        $input = '<input id="config___'.$key.'" name="config['.$key.']" type="password" class="edit" value="" '.$disable.'/>';
+        $input = '<input id="config___'.$key.'" name="config['.$key.']" autocomplete="off" type="password" class="edit" value="" '.$disable.' />';
         return array($label,$input);
     }
   }
@@ -631,6 +660,7 @@ if (!class_exists('setting_multichoice')) {
         foreach ($this->_choices as $choice) {
             $selected = ($value == $choice) ? ' selected="selected"' : '';
             $option = $plugin->getLang($this->_key.'_o_'.$choice);
+            if (!$option && isset($this->lang[$this->_key.'_o_'.$choice])) $option = $this->lang[$this->_key.'_o_'.$choice];
             if (!$option) $option = $choice;
 
             $choice = htmlspecialchars($choice);
@@ -806,8 +836,7 @@ if (!class_exists('setting_multicheckbox')) {
         $input .= '<input id="config___'.$key.'_other" name="config['.$key.'][other]" type="text" class="edit" value="'.htmlspecialchars($other).'" '.$disable." />\n";
         $input .= "</div>\n";
 
-//        $label = '<label for="config___'.$key.'">'.$this->prompt($plugin).'</label>';
-        $label = $this->prompt($plugin);
+        $label = '<label>'.$this->prompt($plugin).'</label>';
         return array($label,$input);
     }
 
@@ -863,7 +892,6 @@ if (!class_exists('setting_multicheckbox')) {
   }
 }
 
-
 /**
  *  Provide php_strip_whitespace (php5 function) functionality
  *
