@@ -22,7 +22,8 @@
  *   'email'        - text input, input must conform to email address format, setting output in quotes
  *   'richemail'    - text input, input must conform to email address format but accepts variables and
  *                    emails with a real name prepended (when email address is given in <>)
- *   'password'     - password input, minimal input validation, setting output plain text in quotes
+ *   'password'     - password input, minimal input validation, setting output text in quotes, maybe encoded
+ *                    according to the _code parameter
  *   'dirchoice'    - as multichoice, selection choices based on folders found at location specified in _dir
  *                    parameter (required). A pattern can be used to restrict the folders to only those which
  *                    match the pattern.
@@ -52,6 +53,7 @@
  *                   required by 'dirchoice' class, ignored by other classes
  *   '_combine'    - complimentary output setting values which can be combined into a single display checkbox
  *                   optional for 'multicheckbox', ignored by other classes
+ *   '_code'       - encoding method to use, accepted values: 'base64','uuencode','plain'.  defaults to plain.
  *
  * @author    Chris Smith <chris@jalakai.co.uk>
  */
@@ -64,11 +66,13 @@ $config['varname'] = 'conf';     // name of the config variable, sans $
 // this value can be overriden when calling save_settings() method
 $config['heading'] = 'Dokuwiki\'s Main Configuration File - Local Settings';
 
+/* DEPRECATED
 // ---------------[ setting files ]--------------------------------------
 // these values can be string expressions, they will be eval'd before use
 $file['local']     = "DOKU_CONF.'local.php'";            // mandatory (file doesn't have to exist)
 $file['default']   = "DOKU_CONF.'dokuwiki.php'";         // optional
 $file['protected'] = "DOKU_CONF.'local.protected.php'";  // optional
+ */
 
 // test value (FIXME, remove before publishing)
 //$meta['test']     = array('multichoice','_choices' => array(''));
@@ -81,9 +85,10 @@ $file['protected'] = "DOKU_CONF.'local.protected.php'";  // optional
 
 $meta['_basic']   = array('fieldset');
 $meta['title']    = array('string');
-$meta['start']    = array('string');
+$meta['start']    = array('string','_pattern' => '!^[^:;/]+$!'); // don't accept namespaces
 $meta['lang']     = array('dirchoice','_dir' => DOKU_INC.'inc/lang/');
 $meta['template'] = array('dirchoice','_dir' => DOKU_INC.'lib/tpl/','_pattern' => '/^[\w-]+$/');
+$meta['license']  = array('license');
 $meta['savedir']  = array('savedir');
 $meta['basedir']  = array('string');
 $meta['baseurl']  = array('string');
@@ -99,12 +104,14 @@ $meta['fullpath']    = array('onoff');
 $meta['typography']  = array('multichoice','_choices' => array(0,1,2));
 $meta['dformat']     = array('string');
 $meta['signature']   = array('string');
+$meta['showuseras']  = array('multichoice','_choices' => array('loginname','username','email','email_link'));
 $meta['toptoclevel'] = array('multichoice','_choices' => array(1,2,3,4,5));   // 5 toc levels
+$meta['tocminheads'] = array('multichoice','_choices' => array(0,1,2,3,4,5,10,15,20));
 $meta['maxtoclevel'] = array('multichoice','_choices' => array(0,1,2,3,4,5));
 $meta['maxseclevel'] = array('multichoice','_choices' => array(0,1,2,3,4,5)); // 0 for no sec edit buttons
 $meta['camelcase']   = array('onoff');
 $meta['deaccent']    = array('multichoice','_choices' => array(0,1,2));
-$meta['useheading']  = array('onoff');
+$meta['useheading']  = array('multichoice','_choices' => array(0,'navigation','content',1));
 $meta['refcheck']    = array('onoff');
 $meta['refshow']     = array('numeric');
 
@@ -112,17 +119,19 @@ $meta['_authentication'] = array('fieldset');
 $meta['useacl']      = array('onoff');
 $meta['autopasswd']  = array('onoff');
 $meta['authtype']    = array('authtype');
-$meta['passcrypt']   = array('multichoice','_choices' => array('smd5','md5','sha1','ssha','crypt','mysql','my411'));
+$meta['passcrypt']   = array('multichoice','_choices' => array('smd5','md5','apr1','sha1','ssha','crypt','mysql','my411'));
 $meta['defaultgroup']= array('string');
 $meta['superuser']   = array('string');
 $meta['manager']     = array('string');
 $meta['profileconfirm'] = array('onoff');
+$meta['rememberme'] = array('onoff');
 $meta['registernotify'] = array('email');
 $meta['disableactions'] = array('disableactions',
                                 '_choices' => array('backlink','index','recent','revisions','search','subscription','nssubscription','register','resendpwd','profile','edit','wikicode','check'),
                                 '_combine' => array('subscription' => array('subscribe','unsubscribe'), 'wikicode' => array('source','export_raw'), 'nssubscription' => array('subscribens','unsubscribens')));
 $meta['sneaky_index'] = array('onoff');
 $meta['auth_security_timeout'] = array('numeric');
+$meta['securecookie'] = array('onoff');
 
 $meta['_anti_spam']  = array('fieldset');
 $meta['usewordblock']= array('onoff');
@@ -182,12 +191,12 @@ $meta['_network']    = array('fieldset');
 $meta['proxy____host'] = array('string','_pattern' => '#^(|[a-z0-9\-\.+]+)$#i');
 $meta['proxy____port'] = array('numericopt');
 $meta['proxy____user'] = array('string');
-$meta['proxy____pass'] = array('password');
+$meta['proxy____pass'] = array('password','_code' => 'base64');
 $meta['proxy____ssl']  = array('onoff');
 $meta['safemodehack'] = array('onoff');
 $meta['ftp____host']  = array('string','_pattern' => '#^(|[a-z0-9\-\.+]+)$#i');
 $meta['ftp____port']  = array('numericopt');
 $meta['ftp____user']  = array('string');
-$meta['ftp____pass']  = array('password');
+$meta['ftp____pass']  = array('password','_code' => 'base64');
 $meta['ftp____root']  = array('string');
 
