@@ -7,19 +7,21 @@
  * @author Delassaux Julien <julien@delassaux.fr>
  * @author Maurice A. LeBlanc <leblancma@cooptel.qc.ca>
  * @author gb@isis.u-strasbg.fr
+ * @author stephane.gully@gmail.com
+ * @author Guillaume Turri <guillaume.turri@gmail.com>
  */
 $lang['menu']                  = 'Gestion des plugins';
 $lang['download']              = 'Télécharger et installer un nouveau plugin';
 $lang['manage']                = 'Plugins installés';
 $lang['btn_info']              = 'info';
-$lang['btn_update']            = 'raffraîchir';
+$lang['btn_update']            = 'rafraîchir';
 $lang['btn_delete']            = 'effacer';
 $lang['btn_settings']          = 'paramètres';
 $lang['btn_download']          = 'Télécharger';
 $lang['btn_enable']            = 'Enregistrer';
 $lang['url']                   = 'URL';
 $lang['installed']             = 'Installé :';
-$lang['lastupdate']            = 'Dernière mise à jour:';
+$lang['lastupdate']            = 'Dernière mise à jour :';
 $lang['source']                = 'Source :';
 $lang['unknown']               = 'inconnu';
 $lang['updating']              = 'Mise à jour...';
@@ -45,6 +47,10 @@ $lang['error']                 = 'Une erreur inconnue est survenue.';
 $lang['error_download']        = 'Impossible de télécharger le fichier du plugin: %s';
 $lang['error_badurl']          = 'URL suspecte - impossible de déterminer le nom du fichier à partir de l\'URL';
 $lang['error_dircreate']       = 'Impossible de créer le répertoire temporaire pour réceptionner le téléchargement';
-$lang['error_decompress']      = 'Le gestionnaire de plugin était incapable de décompresser le fichier téléchargé. Ceci peut être le résultat d\'un mauvais téléchargement, auquel cas vous devriez réessayer ; ou bien le format de compression est inconnu, auquel cas vous devez télécharger et installer le plugin manuellement.';
-$lang['error_copy']            = 'Une erreur de copie est survenue lors de l\'installation des fichiers du plugin <em>%s</em>: votre disque est peut-être plein ou les droits d\'accès au fichier incorrects. Il a pu en résulter une installation partielle du plugin rendant votre installation du wiki instable.';
+$lang['error_decompress']      = 'Le gestionnaire de plugin a été incapable de décompresser le fichier téléchargé. Ceci peut être le résultat d\'un mauvais téléchargement, auquel cas vous devriez réessayer ; ou bien le format de compression est inconnu, auquel cas vous devez télécharger et installer le plugin manuellement.';
+$lang['error_copy']            = 'Une erreur de copie est survenue lors de l\'installation des fichiers du plugin <em>%s</em>: votre disque est peut-être plein ou les droits d\'accès au fichier sont incorrects. Il a pu en résulter une installation partielle du plugin rendant votre installation du wiki instable.';
 $lang['error_delete']          = 'Une erreur est survenue à la suppression du plugin <em>%s</em>.  La raison la plus probable est l\'insuffisance des droits sur les fichiers ou le répertoire';
+$lang['enabled']               = 'Plugin %s activé';
+$lang['notenabled']            = 'Le plugin %s n\'a pas pu être activé, vérifiez le fichier des permissions.';
+$lang['disabled']              = 'Plugin %s désactivé';
+$lang['notdisabled']           = 'Le plugin %s n\'a pas pu être désactivé, vérifiez le fichier des permissions.';
