@@ -5,6 +5,7 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Yuji Takenaka <webmaster@davilin.com>
  * @author Christopher Smith <chris@jalakai.co.uk>
+ * @author Ikuo Obataya <i.obataya@gmail.com>
  */
 $lang['menu']                  = 'プラグイン管理';
 $lang['download']              = 'プラグインのダウンロードとインストール';
@@ -46,3 +47,7 @@ $lang['error_dircreate']       = 'ダウンロードしたファイルを一時
 $lang['error_decompress']      = 'ダウンロードしたファイルを解凍できませんでした。ダウンロードに失敗した可能性があります（もう一度、実行してください）；もしくは、不明な圧縮形式であるかもしれません（手動でインストールする必要があります）';
 $lang['error_copy']            = 'プラグインをインストール中にファイルのコピーに失敗しました。<em>%s</em>：ディスク容量や書き込みの権限を確認してください。このエラーによりプラグインのインストールが完全に行われず、Wikiが不安定な状態です。';
 $lang['error_delete']          = 'プラグインの削除中にエラーが発生しました <em>%s</em>。プラグインが不完全なファイルであったか、ディレクトリの権限が正しくないことが原因であると考えられます。';
+$lang['enabled']               = 'プラグイン %s が有効です。';
+$lang['notenabled']            = 'プラグイン %s を有効にすることができません。権限を確認してください。';
+$lang['disabled']              = 'プラグイン %s が無効です。';
+$lang['notdisabled']           = 'プラグイン %s を無効にすることができません。権限を確認してください。';
