@@ -3,13 +3,14 @@
  * Finnish language file
  *
  * @author otto@valjakko.net
+ * @author Otto Vainio <otto@valjakko.net>
  */
 $lang['menu']                  = 'Palautuksenhallinta';
 $lang['filter']                = 'Etsi spammattyjä sivuja';
 $lang['revert']                = 'Palauta valitut sivut';
 $lang['reverted']              = '%s palautettu versioon %s';
 $lang['removed']               = '%s poistettu';
-$lang['revstart']              = 'Palautusprosessi käynnistetty. Tmä voi viedä pidemmän aikaa. Jos ajo katkeaa aikakatkaisuun ennen loppua, niin sinun pitää palauttaa pienemmissä osissa.';
+$lang['revstart']              = 'Palautusprosessi käynnistetty. Tämä voi viedä pidemmän aikaa. Jos ajo katkeaa aikakatkaisuun ennen loppua, niin sinun pitää palauttaa pienemmissä osissa.';
 $lang['revstop']               = 'Palautusprosessi lopetti onnistuneesti.';
 $lang['note1']                 = 'Huomioi: tämä haku on kirjainkoosta riippuva';
 $lang['note2']                 = 'Huomioi: tämä sivu palautetaan viimeiseen versioon, jossa ei ole annettua spamtermiä <i>%s</i>';
