@@ -61,10 +61,10 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         return array(
             'author' => 'Chris Smith',
             'email'  => 'chris@jalakai.co.uk',
-            'date'   => '2005-11-24',
+            'date'   => '2008-09-17',
             'name'   => 'User Manager',
             'desc'   => 'Manage users '.$this->disabled,
-            'url'    => 'http://wiki.splitbrain.org/plugin:usermanager',
+            'url'    => 'http://dokuwiki.org/plugin:usermanager',
         );
     }
      /**
@@ -150,13 +150,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         $page_buttons = $this->_pagination();
         $delete_disable = $this->_auth->canDo('delUser') ? '' : 'disabled="disabled"';
 
-        if ($this->_auth->canDo('UserMod')) {
-            $edit_disable = '';
-            $img_useredit = 'user_edit.png';
-        } else {
-            $edit_disable = 'disabled="disabled"';
-            $img_useredit = 'no_user_edit.png';
-        }
+        $editable = $this->_auth->canDo('UserMod');
 
         print $this->locale_xhtml('intro');
         print $this->locale_xhtml('list');
@@ -174,11 +168,11 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         ptln("  <table class=\"inline\">");
         ptln("    <thead>");
         ptln("      <tr>");
-        ptln("        <th colspan=\"2\">&nbsp;</th><th>".$this->lang["user_id"]."</th><th>".$this->lang["user_name"]."</th><th>".$this->lang["user_mail"]."</th><th>".$this->lang["user_groups"]."</th>");
+        ptln("        <th>&nbsp;</th><th>".$this->lang["user_id"]."</th><th>".$this->lang["user_name"]."</th><th>".$this->lang["user_mail"]."</th><th>".$this->lang["user_groups"]."</th>");
         ptln("      </tr>");
 
         ptln("      <tr>");
-        ptln("        <td colspan=\"2\" class=\"rightalign\"><input type=\"image\" src=\"".DOKU_PLUGIN_IMAGES."search.png\" name=\"fn[search][new]\" title=\"".$this->lang['search_prompt']."\" alt=\"".$this->lang['search']."\" /></td>");
+        ptln("        <td class=\"rightalign\"><input type=\"image\" src=\"".DOKU_PLUGIN_IMAGES."search.png\" name=\"fn[search][new]\" title=\"".$this->lang['search_prompt']."\" alt=\"".$this->lang['search']."\" class=\"button\" /></td>");
         ptln("        <td><input type=\"text\" name=\"userid\" class=\"edit\" value=\"".$this->_htmlFilter('user')."\" /></td>");
         ptln("        <td><input type=\"text\" name=\"username\" class=\"edit\" value=\"".$this->_htmlFilter('name')."\" /></td>");
         ptln("        <td><input type=\"text\" name=\"usermail\" class=\"edit\" value=\"".$this->_htmlFilter('mail')."\" /></td>");
@@ -193,15 +187,23 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
             $groups = join(', ',$grps);
             ptln("    <tr class=\"user_info\">");
             ptln("      <td class=\"centeralign\"><input type=\"checkbox\" name=\"delete[".$user."]\" ".$delete_disable." /></td>");
-            ptln("      <td class=\"centeralign\"><input type=\"image\" name=\"fn[edit][".$user."]\" ".$edit_disable." src=\"".DOKU_PLUGIN_IMAGES.$img_useredit."\" title=\"".$this->lang['edit_prompt']."\" alt=\"".$this->lang['edit']."\"/></td>");
-            ptln("      <td>".hsc($user)."</td><td>".hsc($name)."</td><td>".hsc($mail)."</td><td>".hsc($groups)."</td>");
+            if ($editable) {
+              ptln("    <td><a href=\"".wl($ID,array('fn[edit]['.hsc($user).']' => 1,
+                                                     'do' => 'admin',
+                                                     'page' => 'usermanager',
+                                                     'sectok' => getSecurityToken())).
+                   "\" title=\"".$this->lang['edit_prompt']."\">".hsc($user)."</a></td>");
+            } else {
+              ptln("    <td>".hsc($user)."</td>");
+            }
+            ptln("      <td>".hsc($name)."</td><td>".hsc($mail)."</td><td>".hsc($groups)."</td>");
             ptln("    </tr>");
           }
           ptln("    </tbody>");
         }
 
         ptln("    <tbody>");
-        ptln("      <tr><td colspan=\"6\" class=\"centeralign\">");
+        ptln("      <tr><td colspan=\"5\" class=\"centeralign\">");
         ptln("        <span class=\"medialeft\">");
         ptln("          <input type=\"submit\" name=\"fn[delete]\" ".$delete_disable." class=\"button\" value=\"".$this->lang['delete_selected']."\" id=\"usrmgr__del\" />");
         ptln("        </span>");
@@ -283,6 +285,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         $this->_htmlInputField($cmd."_usergroups","usergroups",$this->lang["user_groups"],$groups,$this->_auth->canDo("modGroups"),$indent+6);
 
         if ($this->_auth->canDo("modPass")) {
+          $notes[] = $this->lang['note_pass'];
           if ($user) {
             $notes[] = $this->lang['note_notify'];
           }
@@ -316,9 +319,21 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
     }
 
     function _htmlInputField($id, $name, $label, $value, $cando, $indent=0) {
-        $disabled = $cando ? "" : " disabled=\"disabled\"";
-        $class = $cando ? "" : " class=\"disabled\"";
-        ptln("<tr".$class."><td><label for=\"".$id."\" >".$label.": </label></td><td><input type=\"text\" id=\"".$id."\" name=\"".$name."\" value=\"".$value."\"".$disabled." class=\"edit\" /></td></tr>",$indent);
+        $class = $cando ? '' : ' class="disabled"';
+        $disabled = $cando ? '' : ' disabled="disabled"';
+        echo str_pad('',$indent);
+
+        echo "<tr $class>";
+        echo "<td><label for=\"$id\" >$label: </label></td>";
+        echo "<td>";
+        if($cando){
+            echo "<input type=\"text\" id=\"$id\" name=\"$name\" value=\"$value\" class=\"edit\" />";
+        }else{
+            echo "<input type=\"hidden\" name=\"$name\" value=\"$value\" />";
+            echo "<input type=\"text\" id=\"$id\" name=\"$name\" value=\"$value\" class=\"edit disabled\" disabled=\"disabled\" />";
+        }
+        echo "</td>";
+        echo "</tr>";
     }
 
     function _htmlFilter($key) {
@@ -341,12 +356,19 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
 
         list($user,$pass,$name,$mail,$grps) = $this->_retrieveUser();
         if (empty($user)) return false;
-        if (empty($pass) || empty($name) || empty($mail)){
+        if (empty($pass)){
+          if(!empty($_REQUEST['usernotify'])){
+            $pass = auth_pwgen();
+          } else {
+            return false;
+          }
+        }
+        if (empty($name) || empty($mail)){
           msg($this->lang['add_fail'], -1);
           return false;
         }
 
-        if ($ok = $this->_auth->createUser($user,$pass,$name,$mail,$grps)) {
+        if ($ok = $this->_auth->triggerUserMod('create', array($user,$pass,$name,$mail,$grps))) {
 
           msg($this->lang['add_ok'], 1);
 
@@ -373,7 +395,12 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         if (!is_array($selected) || empty($selected)) return false;
         $selected = array_keys($selected);
 
-        $count = $this->_auth->deleteUsers($selected);
+        if(in_array($_SERVER['REMOTE_USER'], $selected)) {
+            msg("You can't delete yourself!", -1);
+            return false;
+        }
+
+        $count = $this->_auth->triggerUserMod('delete', array($selected));
         if ($count == count($selected)) {
           $text = str_replace('%d', $count, $this->lang['delete_ok']);
           msg("$text.", 1);
@@ -454,7 +481,7 @@ class admin_plugin_usermanager extends DokuWiki_Admin_Plugin {
         if (!empty($newgrps) && $this->_auth->canDo('modGroups') && $newgrps != $oldinfo['grps'])
           $changes['grps'] = $newgrps;
 
-        if ($ok = $this->_auth->modifyUser($olduser, $changes)) {
+        if ($ok = $this->_auth->triggerUserMod('modify', array($olduser, $changes))) {
           msg($this->lang['update_ok'],1);
 
           if (!empty($_REQUEST['usernotify']) && $newpass) {
