@@ -5,15 +5,19 @@
  * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Michael Klier <chi@chimeric.de>
+ * @author Leo Moll <leo@yeasoft.com>
+ * @author Florian Anderiasch <fa@art-core.org>
+ * @author Robin Kluth <commi1993@gmail.com>
+ * @author Arne Pelka <mail@arnepelka.de>
  */
 $lang['menu']                  = 'Benutzerverwaltung';
 $lang['noauth']                = '(Authentifizierungssystem nicht verfügbar)';
 $lang['nosupport']             = '(Benutzerverwaltung nicht unterstützt)';
 $lang['badauth']               = 'Ungültige Methode zur Authentifizierung';
-$lang['user_id']               = 'Benutzer';
+$lang['user_id']               = 'Benutzername';
 $lang['user_pass']             = 'Passwort';
-$lang['user_name']             = 'Name';
-$lang['user_mail']             = 'Email';
+$lang['user_name']             = 'Voller Name';
+$lang['user_mail']             = 'E-Mail';
 $lang['user_groups']           = 'Gruppen';
 $lang['field']                 = 'Feld';
 $lang['value']                 = 'Wert';
@@ -42,6 +46,7 @@ $lang['edit_usermissing']      = 'Der ausgewählte Nutzer wurde nicht gefunden.
 $lang['user_notify']           = 'Nutzer benachrichtigen';
 $lang['note_notify']           = 'Benachrichtigungsmails werden nur versandt wenn ein neues Passwort vergeben wurde.';
 $lang['note_group']            = 'Neue Nutzer werden der Standard-Gruppe (%s) hinzugefügt, wenn keine Gruppe angegeben wurde.';
+$lang['note_pass']             = 'Das Password wird automatisch generiert wenn das entsprechende Feld leergelassen wird und die Benachrichtigung des Nutzers aktiviert ist.';
 $lang['add_ok']                = 'Nutzer erfolgreich angelegt';
 $lang['add_fail']              = 'Nutzer konnte nicht angelegt werden';
 $lang['notify_ok']             = 'Benachrichtigungsmail wurde versandt';
