@@ -20,7 +20,7 @@ function createToolButton(icon,label,key,id){
     btn.className = 'toolbutton';
     btn.title = label;
     if(key){
-        btn.title += ' [ALT+'+key.toUpperCase()+']';
+        btn.title += ' ['+key.toUpperCase()+']';
         btn.accessKey = key;
     }
 
@@ -389,6 +389,10 @@ function insertAtCarret(edid,value){
   if (field.createTextRange){
     field.caretPos = document.selection.createRange().duplicate();
   }
+  if(value){
+    window.textChanged = true;
+    summaryCheck();
+  }
 }
 
 
@@ -441,11 +445,6 @@ function initChangeCheck(msg){
                                     if(window.event) window.event.returnValue = rc;
                                     return rc;
                                };
-            links[i].onkeypress = function(){
-                                    var rc = changeCheck(msg);
-                                    if(window.event) window.event.returnValue = rc;
-                                    return rc;
-                               };
         }
     }
     // add change check for forms
@@ -463,10 +462,8 @@ function initChangeCheck(msg){
     // reset change memory var on submit
     var btn_save        = document.getElementById('edbtn__save');
     btn_save.onclick    = function(){ textChanged = false; };
-    btn_save.onkeypress = function(){ textChanged = false; };
     var btn_prev        = document.getElementById('edbtn__preview');
     btn_prev.onclick    = function(){ textChanged = false; };
-    btn_prev.onkeypress = function(){ textChanged = false; };
 
     // add change memory setter
     var edit_text   = document.getElementById('wiki__text');
