@@ -20,48 +20,6 @@ if (clientPC.indexOf('opera')!=-1) {
 // prepare empty toolbar for checks by lazy plugins
 var toolbar = '';
 
-/**
- * Rewrite the accesskey tooltips to be more browser and OS specific.
- *
- * Accesskey tooltips are still only a best-guess of what will work
- * on well known systems.
- *
- * @author Ben Coburn <btcoburn@silicodon.net>
- */
-function updateAccessKeyTooltip() {
-  // determin tooltip text (order matters)
-  var tip = 'ALT+'; //default
-  if (is_macos) { tip = 'CTRL+'; }
-  if (is_opera) { tip = 'SHIFT+ESC '; }
-  // add other cases here...
-
-  // do tooltip update
-  if (tip=='ALT+') { return; }
-  var exp = /\[ALT\+/i;
-  var rep = '['+tip;
-
-  var elements = document.getElementsByTagName('a');
-  for (var i=0; i<elements.length; i++) {
-    if (elements[i].accessKey.length==1 && elements[i].title.length>0) {
-      elements[i].title = elements[i].title.replace(exp, rep);
-    }
-  }
-
-  elements = document.getElementsByTagName('input');
-  for (var i=0; i<elements.length; i++) {
-    if (elements[i].accessKey.length==1 && elements[i].title.length>0) {
-      elements[i].title = elements[i].title.replace(exp, rep);
-    }
-  }
-
-  elements = document.getElementsByTagName('button');
-  for (var i=0; i<elements.length; i++) {
-    if (elements[i].accessKey.length==1 && elements[i].title.length>0) {
-      elements[i].title = elements[i].title.replace(exp, rep);
-    }
-  }
-}
-
 /**
  * Handy shortcut to document.getElementById
  *
@@ -358,7 +316,7 @@ function footnote(e){
     var content = new String (a.parentNode.parentNode.innerHTML);
 
     // strip the leading content anchors and their comma separators
-    content = content.replace(/<a\s.*?href=\".*\#fnt__\d+\".*?<\/a>/gi, '');
+    content = content.replace(/<sup>.*<\/sup>/gi, '');
     content = content.replace(/^\s+(,\s+)+/,'');
 
     // prefix ids on any elements with "insitu__" to ensure they remain unique
@@ -411,6 +369,11 @@ function initSizeCtl(ctlid,edid){
       textarea.style.height = '300px';
     }
 
+    var wrp = DokuCookie.getValue('wrapCtl');
+    if(wrp){
+      setWrap(textarea, wrp);
+    } // else use default value
+
     var l = document.createElement('img');
     var s = document.createElement('img');
     var w = document.createElement('img');
@@ -439,25 +402,35 @@ function sizeCtl(edid,val){
 
 /**
  * Toggle the wrapping mode of a textarea
- *
- * @author Fluffy Convict <fluffyconvict@hotmail.com>
- * @link   http://news.hping.org/comp.lang.javascript.archive/12265.html
- * @author <shutdown@flashmail.com>
- * @link   https://bugzilla.mozilla.org/show_bug.cgi?id=302710#c2
  */
 function toggleWrap(edid){
-    var txtarea = $(edid);
-    var wrap = txtarea.getAttribute('wrap');
+    var textarea = $(edid);
+    var wrap = textarea.getAttribute('wrap');
     if(wrap && wrap.toLowerCase() == 'off'){
-        txtarea.setAttribute('wrap', 'soft');
+        setWrap(textarea, 'soft');
     }else{
-        txtarea.setAttribute('wrap', 'off');
+        setWrap(textarea, 'off');
     }
+
+    DokuCookie.setValue('wrapCtl',textarea.getAttribute('wrap'));
+}
+
+/**
+ * Set the wrapping mode of a textarea
+ *
+ * @author Fluffy Convict <fluffyconvict@hotmail.com>
+ * @author <shutdown@flashmail.com>
+ * @link   http://news.hping.org/comp.lang.javascript.archive/12265.html
+ * @link   https://bugzilla.mozilla.org/show_bug.cgi?id=41464
+ */
+function setWrap(textarea, wrapAttrValue){
+    textarea.setAttribute('wrap', wrapAttrValue);
+
     // Fix display for mozilla
-    var parNod = txtarea.parentNode;
-    var nxtSib = txtarea.nextSibling;
-    parNod.removeChild(txtarea);
-    parNod.insertBefore(txtarea, nxtSib);
+    var parNod = textarea.parentNode;
+    var nxtSib = textarea.nextSibling;
+    parNod.removeChild(textarea);
+    parNod.insertBefore(textarea, nxtSib);
 }
 
 /**
@@ -501,3 +474,73 @@ function cleanMsgArea(){
         }
     }
 }
+
+/**
+ * disable multiple revisions checkboxes if two are checked
+ *
+ * @author Anika Henke <anika@selfthinker.org>
+ */
+addInitEvent(function(){
+    var revForm = $('page__revisions');
+    if (!revForm) return;
+    var elems = revForm.elements;
+    var countTicks = 0;
+    for (var i=0; i<elems.length; i++) {
+        var input1 = elems[i];
+        if (input1.type=='checkbox') {
+            addEvent(input1,'click',function(e){
+                if (this.checked) countTicks++;
+                else countTicks--;
+                for (var j=0; j<elems.length; j++) {
+                    var input2 = elems[j];
+                    if (countTicks >= 2) input2.disabled = (input2.type=='checkbox' && !input2.checked);
+                    else input2.disabled = (input2.type!='checkbox');
+                }
+            });
+        }
+    }
+});
+
+/**
+ * Add the event handler to the actiondropdown
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+addInitEvent(function(){
+    var selector = $('action__selector');
+    if(!selector) return;
+
+    addEvent(selector,'change',function(e){
+        this.form.submit();
+    });
+
+    $('action__selectorbtn').style.display = 'none';
+});
+
+/**
+ * Display error for Windows Shares on browsers other than IE
+ *
+ * Michael Klier <chi@chimeric.de>
+ */
+function checkWindowsShares() {
+    var elems = getElementsByClass('windows',document,'a');
+    if(elems){
+        for(var i=0; i<elems.length; i++){
+            var share = elems[i];
+            addEvent(share,'click',function(){
+                if(document.all == null) {
+                    alert(LANG['nosmblinks']);
+                }
+            });
+        }
+    }
+}
+
+/**
+ * Add the event handler for the Windows Shares check
+ *
+ * Michael Klier <chi@chimeric.de>
+ */
+addInitEvent(function(){
+    checkWindowsShares();
+});
